@@ -2,7 +2,7 @@
 
 # The return code will capture an error from ANY of the functions in the pipe
 set -o pipefail
-make VERBOSE=1 -j2 2>&1 | tee build.log | grep "Building"
+cmake --build . -- -j 2 VERBOSE=1 2>&1 | tee build.log | grep "Building"
 RESULT=$?
 
 if [ $RESULT -eq 0 ]; then
