@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2018 The Psi4 Developers.
+# Copyright (c) 2007-2019 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -34,8 +34,6 @@ Place in this file quickly defined procedures such as
    - simple modifications to existing methods
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
 import os
 import re
 import math
