@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2018 The Psi4 Developers.
+# Copyright (c) 2007-2019 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -25,9 +25,7 @@
 #
 # @END LICENSE
 #
-
 """Module with non-generic exceptions classes."""
-from __future__ import absolute_import
 
 from psi4 import core
 from psi4 import extras
@@ -44,47 +42,62 @@ class ValidationError(PsiException):
     error message *msg* to standard output stream and output file.
 
     """
+
     def __init__(self, msg):
         PsiException.__init__(self, msg)
         # print("%s" % repr(msg))
         self.message = '\nPsiException: %s\n\n' % repr(msg)
 
+
 class ParsingError(PsiException):
     """Error called for problems parsing a text file. Prints error message
     *msg* to standard output stream and output file.
 
     """
+
     def __init__(self, msg):
-        PsiException.__init__(self,msg)
+        PsiException.__init__(self, msg)
         self.message = '\nPsiException: %s\n\n' % msg
 
+
 class PsiImportError(PsiException):
     """Error called for problems import python dependencies. Prints error message
     *msg* to standard output stream and output file.
     """
+
     def __init__(self, msg):
-        PsiException.__init__(self,msg)
+        PsiException.__init__(self, msg)
         self.message = '\nPsiException: %s\n\n' % msg
 
+
 class TestComparisonError(PsiException):
     """Error called when a test case fails due to a failed
     compare_values() call. Prints error message *msg* to standard
     output stream and output file.
 
     """
+
     def __init__(self, msg):
         PsiException.__init__(self, msg)
         self.message = '\nPsiException: %s\n\n' % msg
 
 
 class ConvergenceError(PsiException):
-    """Error called for problems with converging and iterative method. Prints
-    error message *msg* to standard output stream and output file.
+    """Error called for problems with converging and iterative method.
+
+    Parameters
+    ----------
+    eqn_description : str
+        Type of QC routine that has failed (e.g., SCF)
+    iteration : int
+        What iteration we failed on
 
     """
-    def __init__(self, eqn_description, maxit):
-        msg = "Could not converge %s in %d iterations." % (eqn_description, maxit)
+
+    def __init__(self, eqn_description, iteration):
+        msg = "Could not converge %s in %d iterations." % (eqn_description, iteration)
         PsiException.__init__(self, msg)
+        self.iteration = iteration
         self.message = msg
         core.print_out('\nPsiException: %s\n\n' % (msg))
 
@@ -92,8 +105,29 @@ class ConvergenceError(PsiException):
 class OptimizationConvergenceError(ConvergenceError):
     """Error called for problems with geometry optimizer."""
 
-    def __init__(self, eqn_description, maxit, wfn):
-        ConvergenceError.__init__(self, eqn_description, maxit)
+    def __init__(self, eqn_description, iteration, wfn):
+        ConvergenceError.__init__(self, eqn_description, iteration)
+        self.wfn = wfn
+
+
+class SCFConvergenceError(ConvergenceError):
+    """Error called for problems with SCF iterations.
+
+    Parameters
+    ----------
+    wfn : psi4.core.Wavefunction
+        Wavefunction at time of exception
+    e_conv : float
+        Change in energy for last iteration
+    d_conv : float
+        RMS change in density for last iteration
+
+    """
+
+    def __init__(self, eqn_description, iteration, wfn, e_conv, d_conv):
+        ConvergenceError.__init__(self, eqn_description, iteration)
+        self.e_conv = e_conv
+        self.d_conv = d_conv
         self.wfn = wfn
 
 
@@ -101,6 +135,7 @@ class CSXError(PsiException):
     """Error called when CSX generation fails.
 
     """
+
     def __init__(self, msg):
         PsiException.__init__(self, msg)
         self.message = '\nCSXException: %s\n\n' % msg
@@ -111,7 +146,8 @@ class ManagedMethodError(PsiException):
         if circs[5] == '':
             msg = """{0}: Method '{1}' with {2} '{3}' and REFERENCE '{4}' not available{5}""".format(*circs)
         else:
-            msg = """{0}: Method '{1}' with {2} '{3}' and REFERENCE '{4}' not directable to QC_MODULE '{5}'""".format(*circs)
+            msg = """{0}: Method '{1}' with {2} '{3}' and REFERENCE '{4}' not directable to QC_MODULE '{5}'""".format(
+                *circs)
         PsiException.__init__(self, msg)
         self.message = '\nPsiException: %s\n\n' % msg
 
@@ -120,10 +156,12 @@ class Dftd3Error(PsiException):
     """
 
     """
+
     def __init__(self, msg):
         PsiException.__init__(self, msg)
         self.message = '\nDftd3Error: %s\n\n' % msg
 
+
 class PastureRequiredError(PsiException):
     """Error called when the specified value of *option* requires some
     module(s) from Psi4Pasture, but could not be imported.
@@ -155,16 +193,14 @@ class PastureRequiredError(PsiException):
          {module_args}
     to cmake command line when building psi4.
     """
-    pasture_required_modules = {
-            "RUN_CCTRANSORT": ["ccsort", "transqt2"]
-            }
+    pasture_required_modules = {"RUN_CCTRANSORT": ["ccsort", "transqt2"]}
 
     def __init__(self, option):
         mods_str = ", ".join([m for m in PastureRequiredError.pasture_required_modules[option]])
-        msg = PastureRequiredError.msg_tmpl.format(opt = option, modlist = mods_str)
+        msg = PastureRequiredError.msg_tmpl.format(opt=option, modlist=mods_str)
         PsiException.__init__(self, msg)
-        module_cmake_args = " ".join([ "-DENABLE_{}=ON".format(module)
-            for module in PastureRequiredError.pasture_required_modules[option]])
-        msg += PastureRequiredError.install_instructions.format(module_args = module_cmake_args)
+        module_cmake_args = " ".join(
+            ["-DENABLE_{}=ON".format(module) for module in PastureRequiredError.pasture_required_modules[option]])
+        msg += PastureRequiredError.install_instructions.format(module_args=module_cmake_args)
         self.message = '\nPsiException: {}\n\n'.format(msg)
         core.print_out(self.message)
