@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2018 The Psi4 Developers.
+# Copyright (c) 2007-2019 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -26,24 +26,17 @@
 # @END LICENSE
 #
 
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import division
 import time
 import itertools
 import collections
 
 import numpy as np
 
+import qcelemental as qcel
+
 from .molecule import Molecule
 from .util import *
 from .psiutil import *
-from .physconst import psi_bohr2angstroms
-
-try:
-    from itertools import izip as zip  # py2
-except ImportError:
-    pass  # py3
 
 
 class AlignmentMill(collections.namedtuple('AlignmentMill', 'shift rotation atommap mirror')):
@@ -303,7 +296,7 @@ def B787(cgeom,
             print(atomfmt2.format(cuniq[at][:6], *cgeom[at]))
 
     # start_rmsd is nonsense if not atoms_map
-    start_rmsd = np.linalg.norm(cgeom - rgeom) * psi_bohr2angstroms / np.sqrt(nat)
+    start_rmsd = np.linalg.norm(cgeom - rgeom) * qcel.constants.bohr2angstroms / np.sqrt(nat)
     if verbose >= 1:
         print('Start RMSD = {:8.4f} [A] (naive)'.format(start_rmsd))
 
@@ -331,7 +324,7 @@ def B787(cgeom,
         tgeom = temp_solution.align_coordinates(cgeom, reverse=False)
         if verbose >= 4:
             print('temp geom diff\n', tgeom - rgeom)
-        temp_rmsd = np.linalg.norm(tgeom - rgeom) * psi_bohr2angstroms / np.sqrt(rgeom.shape[0])
+        temp_rmsd = np.linalg.norm(tgeom - rgeom) * qcel.constants.bohr2angstroms / np.sqrt(rgeom.shape[0])
         temp_rmsd = np.around(temp_rmsd, decimals=8)
         t2 = time.time()
         tc += t2 - t1
@@ -359,7 +352,7 @@ def B787(cgeom,
             tgeom = temp_solution.align_coordinates(cgeom, reverse=False)
             if verbose >= 4:
                 print('temp geom diff\n', tgeom - rgeom)
-            temp_rmsd = np.linalg.norm(tgeom - rgeom) * psi_bohr2angstroms / np.sqrt(rgeom.shape[0])
+            temp_rmsd = np.linalg.norm(tgeom - rgeom) * qcel.constants.bohr2angstroms / np.sqrt(rgeom.shape[0])
             temp_rmsd = np.around(temp_rmsd, decimals=8)
             t2 = time.time()
             tc += t2 - t1
@@ -382,7 +375,7 @@ def B787(cgeom,
         print('Kabsch time [s] for mol alignment:    {:.3}'.format(tc))
 
     ageom, auniq = hold_solution.align_mini_system(cgeom, cuniq, reverse=False)
-    final_rmsd = np.linalg.norm(ageom - rgeom) * psi_bohr2angstroms / np.sqrt(nat)
+    final_rmsd = np.linalg.norm(ageom - rgeom) * qcel.constants.bohr2angstroms / np.sqrt(nat)
     assert (abs(best_rmsd - final_rmsd) < 1.e-3)
 
     if verbose >= 1:
@@ -510,7 +503,7 @@ def _plausible_atom_orderings(ref, current, rgeom, cgeom, algo='hunguno', verbos
         t00 = time.time()
         # exactly like `scipy.optimize.linear_sum_assignment(cost)` only with extra return
         #    import scipy.optimize
-        #    raise ImportError("Install scipy >=0.17! `conda install scipy` or `pip install scipy`")
+        #    raise ImportError("""Python module scipy >=0.17 not found. Solve by installing it: `conda install scipy` or `pip install scipy`""")
         (row_ind, col_ind), reducedcost = linear_sum_assignment(cost, return_cost=True)
         ptsCR = list(zip(row_ind, col_ind))
         ptsCR = sorted(ptsCR, key=lambda tup: tup[1])
@@ -539,17 +532,17 @@ def _plausible_atom_orderings(ref, current, rgeom, cgeom, algo='hunguno', verbos
             yield ans
 
     if algo == 'perm':
-        ccdistmat = distance_matrix(cgeom, cgeom)
-        rrdistmat = distance_matrix(rgeom, rgeom)
+        ccdistmat = qcel.util.distance_matrix(cgeom, cgeom)
+        rrdistmat = qcel.util.distance_matrix(rgeom, rgeom)
         algofn = filter_permutative
 
     if algo == 'hung':
-        crdistmat = distance_matrix(cgeom, rgeom)
+        crdistmat = qcel.util.distance_matrix(cgeom, rgeom)
         algofn = filter_hungarian
 
     if algo == 'hunguno':
-        ccdistmat = distance_matrix(cgeom, cgeom)
-        rrdistmat = distance_matrix(rgeom, rgeom)
+        ccdistmat = qcel.util.distance_matrix(cgeom, cgeom)
+        rrdistmat = qcel.util.distance_matrix(rgeom, rgeom)
         # TODO investigate soundness
         with np.errstate(divide='ignore'):
             ccnremat = np.reciprocal(ccdistmat)
@@ -638,7 +631,7 @@ def kabsch_align(rgeom, cgeom, weight=None):
     TT = Ccentroid - RR.dot(Rcentroid)
 
     C = C.dot(RR)
-    rmsd = np.linalg.norm(R - C) * psi_bohr2angstroms / np.sqrt(np.sum(w))
+    rmsd = np.linalg.norm(R - C) * qcel.constants.bohr2angstroms / np.sqrt(np.sum(w))
 
     return rmsd, RR, TT
 
