@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2018 The Psi4 Developers.
+# Copyright (c) 2007-2019 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -26,11 +26,9 @@
 # @END LICENSE
 #
 
-import fcntl
 import os
 import sys
 import struct
-import termios
 import textwrap
 
 if sys.version_info[0] == 2:
@@ -152,6 +150,8 @@ def terminal_size():
 
     def ioctl_GWINSZ(fd):
         try:
+            import fcntl # Not available on Windows
+            import termios # Not available on Windows
             rc = struct.unpack('hh', fcntl.ioctl(fd, termios.TIOCGWINSZ, '1234'))
         except:
             return
