@@ -3,7 +3,7 @@
 #
 # Psi4: an open-source quantum chemistry software package
 #
-# Copyright (c) 2007-2018 The Psi4 Developers.
+# Copyright (c) 2007-2019 The Psi4 Developers.
 #
 # The copyrights for code used from other parties are included in
 # the corresponding files.
@@ -26,9 +26,6 @@
 # @END LICENSE
 #
 
-from __future__ import print_function
-from __future__ import absolute_import
-
 from psi4 import core
 
 
