@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -33,22 +33,25 @@
 #include <string>
 #include <memory>
 
-///This is all defined in python.cc initialize
+/// This is all defined in python.cc initialize
 namespace psi {
 
-    class PsiOutStream;
-    extern PSI_API std::shared_ptr<PsiOutStream> outfile;
-    extern std::string outfile_name;
+class PsiOutStream;
+extern PSI_API std::shared_ptr<PsiOutStream> outfile;
+extern std::string outfile_name;
 
-    extern char *psi_file_prefix;
-    extern std::string restart_id; // Does not have a default
+extern char *psi_file_prefix;
+extern std::string restart_id;  // Does not have a default
 
-    enum PsiReturnType {Success, Failure, Balk, EndLoop};
+enum PsiReturnType { Success, Failure, Balk, EndLoop };
 
-    // Very useful regex for matching floating point numbers
-    #define NUMBER "((?:[-+]?\\d*\\.\\d+(?:[DdEe][-+]?\\d+)?)|(?:[-+]?\\d+\\.\\d*(?:[DdEe][-+]?\\d+)?))"
+// Very useful regex for matching floating point numbers
+#define NUMBER "((?:[-+]?\\d*\\.\\d+(?:[DdEe][-+]?\\d+)?)|(?:[-+]?\\d+\\.\\d*(?:[DdEe][-+]?\\d+)?))"
 
-    void die_if_not_converged();
+// Hard zero
+#define PSI_ZERO 1.0E-14
 
-}//End namespace psi
+void die_if_not_converged();
+
+}  // End namespace psi
 #endif
