@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,37 +29,35 @@
 #include <vector>
 #include "psi4/libmints/dimension.h"
 
-namespace psi { namespace cctransort {
+namespace psi {
+namespace cctransort {
 
-std::vector<int> pitzer2qt(std::vector<Dimension> &spaces)
-{
-  int nirreps = spaces[0].n();
+std::vector<int> pitzer2qt(std::vector<Dimension> &spaces) {
+    int nirreps = spaces[0].n();
 
-  Dimension total(nirreps);
-  for(int h=0; h < nirreps; h++)
-    for(int i=0; i < spaces.size(); i++)
-      total[h] += spaces[i][h];
-  int nmo = total.sum();
+    Dimension total(nirreps);
+    for (int h = 0; h < nirreps; h++)
+        for (int i = 0; i < spaces.size(); i++) total[h] += spaces[i][h];
+    int nmo = total.sum();
 
-  std::vector<int> order(nmo);
-  order.assign(nmo, 0);
+    std::vector<int> order(nmo);
+    order.assign(nmo, 0);
 
-  Dimension offset(nirreps);
-  offset[0] = 0;
-  for(int h=1; h < nirreps; h++)
-    offset[h] = offset[h-1] + total[h-1];
+    Dimension offset(nirreps);
+    offset[0] = 0;
+    for (int h = 1; h < nirreps; h++) offset[h] = offset[h - 1] + total[h - 1];
 
-  int count = 0;
+    int count = 0;
 
-  for(int j=0; j < spaces.size(); j++)
-    for(int h=0; h < nirreps; h++) {
-      int this_offset = offset[h];
-      for(int k=0; k < j; k++) this_offset += spaces[k][h];
-      for(int i=0; i < spaces[j][h]; i++)
-      order[this_offset + i] = count++;
-    }
+    for (int j = 0; j < spaces.size(); j++)
+        for (int h = 0; h < nirreps; h++) {
+            int this_offset = offset[h];
+            for (int k = 0; k < j; k++) this_offset += spaces[k][h];
+            for (int i = 0; i < spaces[j][h]; i++) order[this_offset + i] = count++;
+        }
 
-  return order;
+    return order;
 }
 
-}}
+}  // namespace cctransort
+}  // namespace psi
