@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -27,7 +27,7 @@
  */
 
 #include "dcft.h"
-#include "defines.h"
+#include "psi4/psifiles.h"
 
 #include "psi4/libdpd/dpd.h"
 #include "psi4/libpsio/psio.hpp"
@@ -220,8 +220,8 @@ void DCFTSolver::compute_F_intermediate_RHF() {
     psio_->open(PSIF_LIBTRANS_DPD, PSIO_OPEN_OLD);
 
     /*
-    * F_ijab += P(ab) F_ca lambda_ijcb - P(ij) F_ki lambda_jkab
-    */
+     * F_ijab += P(ab) F_ca lambda_ijcb - P(ij) F_ki lambda_jkab
+     */
     global_dpd_->buf4_init(&F, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
                            "F <OO|VV>");  // F <Oo|Vv>
     global_dpd_->buf4_init(&Lab, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
@@ -365,5 +365,5 @@ void DCFTSolver::form_density_weighted_fock_RHF() {
 
     psio_->close(PSIF_LIBTRANS_DPD, 1);
 }
-}
-}  // Namespace
+}  // namespace dcft
+}  // namespace psi
