@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -27,7 +27,7 @@
  */
 
 #include "dcft.h"
-#include "defines.h"
+#include "psi4/psifiles.h"
 
 #include "psi4/libtrans/integraltransform.h"
 #include "psi4/libpsio/psio.hpp"
@@ -45,19 +45,19 @@
 
 #include <cmath>
 
-namespace psi{ namespace dcft{
+namespace psi {
+namespace dcft {
 
-void
-DCFTSolver::run_simult_dcft_oo_RHF()
-{
+void DCFTSolver::run_simult_dcft_oo_RHF() {
     if (options_.get_bool("ODC_GUESS")) run_simult_dc_guess();
 
     // This is the simultaneous orbital/lambda update algorithm for the orbital-optimized methods
     int cycle = 0;
 
-    outfile->Printf( "\n\n\t*=================================================================================*\n"
-                         "\t* Cycle   Max Orb Grad    RMS Lambda Error   delta E        Total Energy     DIIS *\n"
-                         "\t*---------------------------------------------------------------------------------*\n");
+    outfile->Printf(
+        "\n\n\t*=================================================================================*\n"
+        "\t* Cycle   Max Orb Grad    RMS Lambda Error   delta E        Total Energy     DIIS *\n"
+        "\t*---------------------------------------------------------------------------------*\n");
 
     // Copy the reference orbitals and to use them as the reference for the orbital rotation
     old_ca_->copy(Ca_);
@@ -68,29 +68,22 @@ DCFTSolver::run_simult_dcft_oo_RHF()
 
     // DIIS on orbitals (AA and BB) and cumulants (AA, AB, BB)
     dpdbuf4 Laa, Lab, Lbb;
-    global_dpd_->buf4_init(&Laa, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Lambda <OO|VV>");
-    global_dpd_->buf4_init(&Lab, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Lambda SF <OO|VV>");
-    global_dpd_->buf4_init(&Lbb, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Lambda <oo|vv>");
-    diisManager.set_error_vector_size(5, DIISEntry::Matrix, orbital_gradient_a_.get(),
-                                         DIISEntry::Matrix, orbital_gradient_b_.get(),
-                                         DIISEntry::DPDBuf4, &Laa,
-                                         DIISEntry::DPDBuf4, &Lab,
-                                         DIISEntry::DPDBuf4, &Lbb);
-    diisManager.set_vector_size(5, DIISEntry::Matrix, Xtotal_a_.get(),
-                                   DIISEntry::Matrix, Xtotal_b_.get(),
-                                   DIISEntry::DPDBuf4, &Laa,
-                                   DIISEntry::DPDBuf4, &Lab,
-                                   DIISEntry::DPDBuf4, &Lbb);
+    global_dpd_->buf4_init(&Laa, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda <OO|VV>");
+    global_dpd_->buf4_init(&Lab, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda SF <OO|VV>");
+    global_dpd_->buf4_init(&Lbb, PSIF_LIBTRANS_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda <oo|vv>");
+    diisManager.set_error_vector_size(5, DIISEntry::Matrix, orbital_gradient_a_.get(), DIISEntry::Matrix,
+                                      orbital_gradient_b_.get(), DIISEntry::DPDBuf4, &Laa, DIISEntry::DPDBuf4, &Lab,
+                                      DIISEntry::DPDBuf4, &Lbb);
+    diisManager.set_vector_size(5, DIISEntry::Matrix, Xtotal_a_.get(), DIISEntry::Matrix, Xtotal_b_.get(),
+                                DIISEntry::DPDBuf4, &Laa, DIISEntry::DPDBuf4, &Lab, DIISEntry::DPDBuf4, &Lbb);
     global_dpd_->buf4_close(&Laa);
     global_dpd_->buf4_close(&Lab);
     global_dpd_->buf4_close(&Lbb);
 
-    while((!orbitalsDone_ || !cumulantDone_ || !densityConverged_ || !energyConverged_)
-            && cycle++ < maxiter_){
-
+    while ((!orbitalsDone_ || !cumulantDone_ || !densityConverged_ || !energyConverged_) && cycle++ < maxiter_) {
         std::string diisString;
         // Build new Tau from the density cumulant in the MO basis and transform it the SO basis
         build_tau_RHF();
@@ -99,7 +92,7 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         }
         transform_tau_RHF();
 
-        if(options_.get_str("DCFT_TYPE") == "DF" && options_.get_str("AO_BASIS") == "NONE"){
+        if (options_.get_str("DCFT_TYPE") == "DF" && options_.get_str("AO_BASIS") == "NONE") {
             build_DF_tensors_RHF();
 
             auto mo_h = std::make_shared<Matrix>("MO-based H", nirrep_, nmopi_, nmopi_);
@@ -108,8 +101,7 @@ DCFTSolver::run_simult_dcft_oo_RHF()
 
             moFa_->copy(mo_h);
             moFa_->add(mo_gbarGamma_A_);
-        }
-        else{
+        } else {
             // Copy core hamiltonian into the Fock matrix array: F = H
             Fa_->copy(so_h_);
             Fb_->copy(so_h_);
@@ -153,33 +145,32 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         energyConverged_ = std::fabs(old_total_energy_ - new_total_energy_) < energy_threshold_;
         // Compute the orbital rotation step using Jacobi method
         compute_orbital_rotation_jacobi_RHF();
-        if(orbitals_convergence_ < diis_start_thresh_ && cumulant_convergence_ < diis_start_thresh_){
-            //Store the DIIS vectors
+        if (orbitals_convergence_ < diis_start_thresh_ && cumulant_convergence_ < diis_start_thresh_) {
+            // Store the DIIS vectors
 
             // DIIS on orbitals (AA and BB) and cumulants (AA, AB, BB)
             dpdbuf4 Laa, Lab, Lbb, Raa, Rab, Rbb;
             // Compute R_OOVV and R_oovv from R_OoVv, used as DIIS error vectors
             compute_R_AA_and_BB();
 
-            global_dpd_->buf4_init(&Raa, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "R <OO|VV>");
-            global_dpd_->buf4_init(&Rab, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "R SF <OO|VV>"); // R <Oo|Vv>
-            global_dpd_->buf4_init(&Rbb, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "R <oo|vv>");
-            global_dpd_->buf4_init(&Laa, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "Lambda <OO|VV>");
-            global_dpd_->buf4_init(&Lab, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "Lambda SF <OO|VV>"); // Lambda <Oo|Vv>
-            global_dpd_->buf4_init(&Lbb, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                          ID("[O,O]"), ID("[V,V]"), 0, "Lambda <oo|vv>");
+            global_dpd_->buf4_init(&Raa, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "R <OO|VV>");
+            global_dpd_->buf4_init(&Rab, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "R SF <OO|VV>");  // R <Oo|Vv>
+            global_dpd_->buf4_init(&Rbb, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "R <oo|vv>");
+            global_dpd_->buf4_init(&Laa, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "Lambda <OO|VV>");
+            global_dpd_->buf4_init(&Lab, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "Lambda SF <OO|VV>");  // Lambda <Oo|Vv>
+            global_dpd_->buf4_init(&Lbb, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                                   "Lambda <oo|vv>");
 
-            if(diisManager.add_entry(10, orbital_gradient_a_.get(), orbital_gradient_b_.get(), &Raa, &Rab, &Rbb,
-                                     Xtotal_a_.get(), Xtotal_b_.get(), &Laa, &Lab, &Lbb)){
+            if (diisManager.add_entry(10, orbital_gradient_a_.get(), orbital_gradient_b_.get(), &Raa, &Rab, &Rbb,
+                                      Xtotal_a_.get(), Xtotal_b_.get(), &Laa, &Lab, &Lbb)) {
                 diisString += "S";
             }
-            if(diisManager.subspace_size() > mindiisvecs_){
-
+            if (diisManager.subspace_size() > mindiisvecs_) {
                 diisString += "/E";
                 diisManager.extrapolate(5, Xtotal_a_.get(), Xtotal_b_.get(), &Laa, &Lab, &Lbb);
             }
@@ -189,16 +180,16 @@ DCFTSolver::run_simult_dcft_oo_RHF()
             global_dpd_->buf4_close(&Laa);
             global_dpd_->buf4_close(&Lab);
             global_dpd_->buf4_close(&Lbb);
-
         }
         // Obtain new orbitals
         rotate_orbitals_RHF();
         dcft_timer_off("DCFTSolver::orbital_optimization");
 
         // Make sure that the orbital phase is retained
-        if(!correct_mo_phases(false)){
-            outfile->Printf("\t\tThere was a problem correcting the MO phases.\n"
-                            "\t\tIf this does not converge, try ALGORITHM=TWOSTEP\n");
+        if (!correct_mo_phases(false)) {
+            outfile->Printf(
+                "\t\tThere was a problem correcting the MO phases.\n"
+                "\t\tIf this does not converge, try ALGORITHM=TWOSTEP\n");
         }
         // Transform two-electron integrals to the MO basis using new orbitals, build denominators
         transform_integrals_RHF();
@@ -206,18 +197,15 @@ DCFTSolver::run_simult_dcft_oo_RHF()
         densityConverged_ = update_scf_density_RHF() < orbitals_threshold_;
         // If we've performed enough lambda updates since the last orbitals
         // update, reset the counter so another SCF update is performed
-        outfile->Printf( "\t* %-3d   %12.3e      %12.3e   %12.3e  %21.15f  %-3s *\n",
-                cycle, orbitals_convergence_, cumulant_convergence_, new_total_energy_ - old_total_energy_,
-                new_total_energy_, diisString.c_str());
-
+        outfile->Printf("\t* %-3d   %12.3e      %12.3e   %12.3e  %21.15f  %-3s *\n", cycle, orbitals_convergence_,
+                        cumulant_convergence_, new_total_energy_ - old_total_energy_, new_total_energy_,
+                        diisString.c_str());
     }
 
-    outfile->Printf( "\t*=================================================================================*\n");
+    outfile->Printf("\t*=================================================================================*\n");
 }
 
-
-double
-DCFTSolver::compute_orbital_residual_RHF() {
+double DCFTSolver::compute_orbital_residual_RHF() {
     dcft_timer_on("DCFTSolver::compute_orbital_residual_RHF()");
 
     dpdfile2 Xai, Xia;
@@ -242,10 +230,10 @@ DCFTSolver::compute_orbital_residual_RHF() {
 
     double maxGradient = 0.0;
     // Alpha spin
-    for(int h = 0; h < nirrep_; ++h){
-        #pragma omp parallel for
-        for(int i = 0; i < naoccpi_[h]; ++i){
-            for(int a = 0; a < navirpi_[h]; ++a){
+    for (int h = 0; h < nirrep_; ++h) {
+#pragma omp parallel for reduction(max:maxGradient)
+        for (int i = 0; i < naoccpi_[h]; ++i) {
+            for (int a = 0; a < navirpi_[h]; ++a) {
                 double value = 2.0 * (Xia.matrix[h][i][a] - Xai.matrix[h][a][i]);
                 maxGradient = (std::fabs(value) > maxGradient) ? std::fabs(value) : maxGradient;
                 orbital_gradient_a_->set(h, i, a + naoccpi_[h], value);
@@ -262,8 +250,7 @@ DCFTSolver::compute_orbital_residual_RHF() {
     return maxGradient;
 }
 
-void
-DCFTSolver::compute_orbital_gradient_OV_RHF() {
+void DCFTSolver::compute_orbital_gradient_OV_RHF() {
     psio_->open(PSIF_DCFT_DENSITY, PSIO_OPEN_OLD);
     psio_->open(PSIF_LIBTRANS_DPD, PSIO_OPEN_OLD);
 
@@ -299,13 +286,13 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     global_dpd_->file2_init(&Y2_OV, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "Y2 <O|V>");
 
     // Y2_IA = <IA|CD> Tau_CD
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 0, "MO Ints <OV|VV>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 0,
+                           "MO Ints <OV|VV>");
     global_dpd_->contract422(&I, &T_VV, &Y2_OV, 0, 0, 1.0, 0.0);
     global_dpd_->buf4_close(&I);
     // Y2_IA -= 2 * (IA|CD) Tau_CD
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V>=V]+"), 0, "MO Ints (OV|VV)");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V>=V]+"), 0,
+                           "MO Ints (OV|VV)");
     global_dpd_->contract422(&I, &T_VV, &Y2_OV, 0, 0, -2.0, 1.0);
     global_dpd_->buf4_close(&I);
 
@@ -321,24 +308,23 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     // 2. X_ia <-- 1/4 <ib||cd> lambda_abkl lambda_klcd
 
     // W_IBKL = <IB||CD> lambda_KLCD
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V>V]-"),
-                  ID("[O,V]"), ID("[V,V]"), 1, "MO Ints <OV|VV>");
-    global_dpd_->buf4_init(&L, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V>V]-"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Lambda <OO|VV>");
-    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O>O]-"), 0, "W <OV|OO>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V>V]-"), ID("[O,V]"), ID("[V,V]"), 1,
+                           "MO Ints <OV|VV>");
+    global_dpd_->buf4_init(&L, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V>V]-"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda <OO|VV>");
+    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O>O]-"), 0, "W <OV|OO>");
     global_dpd_->contract444(&I, &L, &W, 0, 0, 2.0, 0.0);
     global_dpd_->buf4_close(&I);
     global_dpd_->buf4_close(&L);
     global_dpd_->buf4_close(&W);
 
     // W_KlIb = 2 lambda_KlCd <Ib|Cd>
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                           ID("[O,V]"), ID("[V,V]"), 0, "MO Ints <OV|VV>"); // MO Ints <Ov|Vv>
-    global_dpd_->buf4_init(&L, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                           ID("[O,O]"), ID("[V,V]"), 0, "Lambda SF <OO|VV>"); // Lambda <Oo|Vv>
-    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[O,V]"),
-                  ID("[O,O]"), ID("[O,V]"), 0, "W SF <OO|OV>"); // W <Oo|Ov>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 0,
+                           "MO Ints <OV|VV>");  // MO Ints <Ov|Vv>
+    global_dpd_->buf4_init(&L, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda SF <OO|VV>");  // Lambda <Oo|Vv>
+    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), 0,
+                           "W SF <OO|OV>");  // W <Oo|Ov>
     global_dpd_->contract444(&L, &I, &W, 0, 0, 2.0, 0.0);
     global_dpd_->buf4_close(&I);
     global_dpd_->buf4_close(&L);
@@ -346,10 +332,9 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
 
     // X_IA +=  1/4 W_IBKL lambda_KLAB
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O>O]-"), 0, "W <OV|OO>");
-    global_dpd_->buf4_init(&LL, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Lambda <OO|VV>");
+    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O>O]-"), 0, "W <OV|OO>");
+    global_dpd_->buf4_init(&LL, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda <OO|VV>");
 
     global_dpd_->contract442(&W, &LL, &X, 0, 2, 0.25, 1.0);
     global_dpd_->buf4_close(&W);
@@ -358,10 +343,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
 
     // X_IA +=  1/2 W_KlIb lambda_KlAb
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[O,V]"),
-                  ID("[O,O]"), ID("[O,V]"), 0, "W SF <OO|OV>"); // W <Oo|Ov>
-    global_dpd_->buf4_init(&LL, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"),
-                           ID("[O,O]"), ID("[V,V]"), 0, "Lambda SF <OO|VV>"); // Lambda <Oo|Vv>
+    global_dpd_->buf4_init(&W, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), 0,
+                           "W SF <OO|OV>");  // W <Oo|Ov>
+    global_dpd_->buf4_init(&LL, PSIF_DCFT_DPD, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Lambda SF <OO|VV>");  // Lambda <Oo|Vv>
     global_dpd_->contract442(&W, &LL, &X, 2, 2, 0.5, 1.0);
     global_dpd_->buf4_close(&W);
     global_dpd_->buf4_close(&LL);
@@ -374,10 +359,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     // X_IA += <BI||JK> Г_BAJK
     dcft_timer_on("DCFTSolver::g_BiJk Gamma_BaJk");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 1, "MO Ints <OV|OO>");
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[V,V]"), ID("[O,O]"),
-                  ID("[V,V]"), ID("[O,O]"), 0, "Gamma <VV|OO>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 1,
+                           "MO Ints <OV|OO>");
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), 0,
+                           "Gamma <VV|OO>");
     global_dpd_->contract442(&I, &G, &X, 0, 0, 1.0, 1.0);
 
     global_dpd_->buf4_close(&G);
@@ -388,10 +373,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     // X_IA += 2 * <Ib|Jk> Г_AbJk
     dcft_timer_on("DCFTSolver::g_IbJk Gamma_AbJk");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 0, "MO Ints <OV|OO>"); // MO Ints <Ov|Oo>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[V,V]"), ID("[O,O]"),
-                  ID("[V,V]"), ID("[O,O]"), 0, "Gamma SF <VV|OO>"); // Gamma <Vv|Oo>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 0,
+                           "MO Ints <OV|OO>");  // MO Ints <Ov|Oo>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), 0,
+                           "Gamma SF <VV|OO>");  // Gamma <Vv|Oo>
 
     global_dpd_->contract442(&I, &G, &X, 0, 0, 2.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -406,10 +391,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     // X_IA += <JB||KI> Г_JBKA
     dcft_timer_on("DCFTSolver::g_JbKi Gamma_JbKa");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 1, "MO Ints <OV|OO>");
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma <OV|OV>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 1,
+                           "MO Ints <OV|OO>");
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma <OV|OV>");
 
     global_dpd_->contract442(&I, &G, &X, 3, 3, 1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -419,10 +404,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
 
     // X_IA += <kB|jI> Г_kBjA
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                           ID("[O,V]"), ID("[O,O]"), 0, "MO Ints <OV|OO>"); // MO Ints <oV|oO>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma SF <OV|OV>:<Ov|Ov>"); // Gamma <oV|oV>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 0,
+                           "MO Ints <OV|OO>");  // MO Ints <oV|oO>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma SF <OV|OV>:<Ov|Ov>");  // Gamma <oV|oV>
 
     global_dpd_->contract442(&I, &G, &X, 3, 3, 1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -433,10 +418,10 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     // Note: <Kb|jI> integrals are resorted <bK|jI> integrals.
     // <Kb||jI> Г_KbjA = (-1) * <bK|jI> * Г_KbjA
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('O'), ID('V'), "X <O|V>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 0, "MO Ints SF <OV|OO>"); // MO Ints <Ov|oO>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma SF <OV|OV>:<Ov|oV>"); // Gamma <Ov|oV>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 0,
+                           "MO Ints SF <OV|OO>");  // MO Ints <Ov|oO>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma SF <OV|OV>:<Ov|oV>");  // Gamma <Ov|oV>
 
     global_dpd_->contract442(&I, &G, &X, 3, 3, -1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -447,8 +432,7 @@ DCFTSolver::compute_orbital_gradient_OV_RHF() {
     psio_->close(PSIF_LIBTRANS_DPD, 1);
 }
 
-void
-DCFTSolver::compute_orbital_gradient_VO_RHF() {
+void DCFTSolver::compute_orbital_gradient_VO_RHF() {
     psio_->open(PSIF_DCFT_DENSITY, PSIO_OPEN_OLD);
     psio_->open(PSIF_LIBTRANS_DPD, PSIO_OPEN_OLD);
 
@@ -466,12 +450,12 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     global_dpd_->file2_mat_init(&T);
     global_dpd_->file2_mat_rd(&H);
     global_dpd_->file2_mat_rd(&T);
-    for(int h = 0; h < nirrep_; ++h){
-        #pragma omp parallel for
-        for(int i = 0 ; i < naoccpi_[h]; ++i){
-            for(int a = 0 ; a < navirpi_[h]; ++a){
+    for (int h = 0; h < nirrep_; ++h) {
+#pragma omp parallel for
+        for (int i = 0; i < naoccpi_[h]; ++i) {
+            for (int a = 0; a < navirpi_[h]; ++a) {
                 double value = 0.0;
-                for(int j = 0 ; j < naoccpi_[h]; ++j){
+                for (int j = 0; j < naoccpi_[h]; ++j) {
                     value += H.matrix[h][j][a] * (T.matrix[h][j][i] + (i == j ? 1.0 : 0.0));
                 }
                 X.matrix[h][a][i] = value;
@@ -492,10 +476,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     // X_AI += 2 * <AJ||KL> Г_IJKL
     dcft_timer_on("DCFTSolver::2 * g_AjKl Gamma_IjKl");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 1, "MO Ints <OV|OO>");
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[O,O]"),
-                  ID("[O,O]"), ID("[O,O]"), 0, "Gamma <OO|OO>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 1,
+                           "MO Ints <OV|OO>");
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[O,O]"), ID("[O,O]"), ID("[O,O]"), 0,
+                           "Gamma <OO|OO>");
 
     global_dpd_->contract442(&I, &G, &X, 1, 1, 2.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -505,10 +489,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
 
     // X_AI += 4 * <Aj|Kl> Г_IjKl
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"),
-                  ID("[O,V]"), ID("[O,O]"), 0, "MO Ints <OV|OO>"); // MO Ints <oV|oO>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[O,O]"),
-                  ID("[O,O]"), ID("[O,O]"), 0, "Gamma SF <OO|OO>"); // Gamma <Oo|Oo>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[O,O]"), ID("[O,V]"), ID("[O,O]"), 0,
+                           "MO Ints <OV|OO>");  // MO Ints <oV|oO>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[O,O]"), ID("[O,O]"), ID("[O,O]"), 0,
+                           "Gamma SF <OO|OO>");  // Gamma <Oo|Oo>
 
     global_dpd_->contract442(&I, &G, &X, 1, 1, 4.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -522,10 +506,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     // X_AI += <JA||BC> Г_JIBC
     dcft_timer_on("DCFTSolver::2 * g_JaBc Gamma_JiBc");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 1, "MO Ints <OV|VV>");
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Gamma <OO|VV>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 1,
+                           "MO Ints <OV|VV>");
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Gamma <OO|VV>");
 
     global_dpd_->contract442(&I, &G, &X, 1, 1, 1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -535,10 +519,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
 
     // X_AI += <Aj|Bc> Г_IjBc
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 0, "MO Ints <OV|VV>"); // MO Ints <oV|vV>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[V,V]"),
-                  ID("[O,O]"), ID("[V,V]"), 0, "Gamma SF <OO|VV>"); // Gamma <Oo|Vv>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 0,
+                           "MO Ints <OV|VV>");  // MO Ints <oV|vV>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,O]"), ID("[V,V]"), ID("[O,O]"), ID("[V,V]"), 0,
+                           "Gamma SF <OO|VV>");  // Gamma <Oo|Vv>
 
     global_dpd_->contract442(&I, &G, &X, 1, 1, 2.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -552,10 +536,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     // X_AI += <JB||AC> Г_JBIC
     dcft_timer_on("DCFTSolver::g_JbAc Gamma_JbIc");
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 1, "MO Ints <OV|VV>");
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma <OV|OV>");
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 1,
+                           "MO Ints <OV|VV>");
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma <OV|OV>");
 
     global_dpd_->contract442(&I, &G, &X, 2, 2, 1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -565,10 +549,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
 
     // X_AI += <Jb|Ac> Г_JbIc
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 0, "MO Ints <OV|VV>"); // MO Ints <Ov|Vv>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma SF <OV|OV>:<Ov|Ov>"); // Gamma <Ov|Ov>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 0,
+                           "MO Ints <OV|VV>");  // MO Ints <Ov|Vv>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma SF <OV|OV>:<Ov|Ov>");  // Gamma <Ov|Ov>
 
     global_dpd_->contract442(&I, &G, &X, 2, 2, 1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -579,10 +563,10 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     // Note: <jB|Ac> integrals are resorted <Bj|Ac> integrals.
     // <jB||Ac> Г_jBIc = (-1) * <Bj|Ac> Г_jBIc
     global_dpd_->file2_init(&X, PSIF_DCFT_DPD, 0, ID('V'), ID('O'), "X <V|O>");
-    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"),
-                  ID("[O,V]"), ID("[V,V]"), 0, "MO Ints SF <OV|VV>"); // MO Ints <oV|Vv>
-    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"),
-                  ID("[O,V]"), ID("[O,V]"), 0, "Gamma SF <OV|OV>:<Ov|oV>"); // Gamma <oV|Ov>
+    global_dpd_->buf4_init(&I, PSIF_LIBTRANS_DPD, 0, ID("[O,V]"), ID("[V,V]"), ID("[O,V]"), ID("[V,V]"), 0,
+                           "MO Ints SF <OV|VV>");  // MO Ints <oV|Vv>
+    global_dpd_->buf4_init(&G, PSIF_DCFT_DENSITY, 0, ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), ID("[O,V]"), 0,
+                           "Gamma SF <OV|OV>:<Ov|oV>");  // Gamma <oV|Ov>
 
     global_dpd_->contract442(&I, &G, &X, 2, 2, -1.0, 1.0);
     global_dpd_->buf4_close(&G);
@@ -593,17 +577,16 @@ DCFTSolver::compute_orbital_gradient_VO_RHF() {
     psio_->close(PSIF_LIBTRANS_DPD, 1);
 }
 
-void
-DCFTSolver::compute_orbital_rotation_jacobi_RHF() {
-
+void DCFTSolver::compute_orbital_rotation_jacobi_RHF() {
     dcft_timer_on("DCFTSolver::ccompute_orbital_rotation_jacobi_RHF()");
 
     // Determine the orbital rotation step
     // Alpha spin
-    for(int h = 0; h < nirrep_; ++h){
-        for(int i = 0; i < naoccpi_[h]; ++i){
-            for(int a = naoccpi_[h]; a < nmopi_[h]; ++a){
-                double value = orbital_gradient_a_->get(h, i, a) / (2.0 * (moFa_->get(h, i, i) - moFa_->get(h, a, a)) + orbital_level_shift_);
+    for (int h = 0; h < nirrep_; ++h) {
+        for (int i = 0; i < naoccpi_[h]; ++i) {
+            for (int a = naoccpi_[h]; a < nmopi_[h]; ++a) {
+                double value = orbital_gradient_a_->get(h, i, a) /
+                               (2.0 * (moFa_->get(h, i, i) - moFa_->get(h, a, a)) + orbital_level_shift_);
                 X_a_->set(h, i, a, value);
                 X_a_->set(h, a, i, (-1.0) * value);
             }
@@ -619,9 +602,7 @@ DCFTSolver::compute_orbital_rotation_jacobi_RHF() {
     dcft_timer_off("DCFTSolver::ccompute_orbital_rotation_jacobi_RHF()");
 }
 
-void
-DCFTSolver::rotate_orbitals_RHF() {
-
+void DCFTSolver::rotate_orbitals_RHF() {
     dcft_timer_on("DCFTSolver::rotate_orbitals_RHF()");
 
     // Initialize the orbital rotation matrix
@@ -643,7 +624,7 @@ DCFTSolver::rotate_orbitals_RHF() {
     int colA = U_a->ncol();
 
     double **U_a_block = block_matrix(rowA, colA);
-    memset(U_a_block[0], 0, sizeof(double)*rowA*colA);
+    memset(U_a_block[0], 0, sizeof(double) * rowA * colA);
     U_a_block = U_a->to_block_matrix();
     schmidt(U_a_block, rowA, colA, "outfile");
     U_a->set(U_a_block);
@@ -656,7 +637,7 @@ DCFTSolver::rotate_orbitals_RHF() {
     Cb_->copy(Ca_);
 
     dcft_timer_off("DCFTSolver::rotate_orbitals_RHF()");
-
 }
 
-}} // Namespace
+}  // namespace dcft
+}  // namespace psi
