@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,11 +29,11 @@
 #ifndef CIWAVE_H
 #define CIWAVE_H
 
- #include "psi4/pragma.h"
- PRAGMA_WARNING_PUSH
- PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
- #include <memory>
- PRAGMA_WARNING_POP
+#include "psi4/pragma.h"
+PRAGMA_WARNING_PUSH
+PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
+#include <memory>
+PRAGMA_WARNING_POP
 #include "psi4/libmints/dimension.h"
 #include "psi4/libmints/wavefunction.h"
 
@@ -50,10 +50,11 @@ class DFHelper;
 // Well this is not ideal
 struct _SlaterDetSet;
 typedef _SlaterDetSet SlaterDetSet;
-}
+}  // namespace psi
 
 // From the detci module
-namespace psi { namespace detci {
+namespace psi {
+namespace detci {
 class CIvect;
 class SlaterDeterminant;
 struct calcinfo;
@@ -63,21 +64,19 @@ struct ci_blks;
 struct olsen_graph;
 struct H_zero_block;
 typedef std::shared_ptr<psi::detci::CIvect> SharedCIVector;
-}}
+}  // namespace detci
+}  // namespace psi
 
-namespace psi { namespace detci {
+namespace psi {
+namespace detci {
 
-
-class CIWavefunction : public Wavefunction
-{
-
-public:
-    CIWavefunction(std::shared_ptr<Wavefunction> reference_wavefunction);
+class CIWavefunction : public Wavefunction {
+   public:
     CIWavefunction(std::shared_ptr<Wavefunction> reference_wavefunction, Options &options);
-    virtual ~CIWavefunction();
+    explicit CIWavefunction(std::shared_ptr<Wavefunction> reference_wavefunction);
+    ~CIWavefunction() override;
 
-
-    double compute_energy();
+    double compute_energy() override;
 
     /// Simple accessors
     size_t ndet();
@@ -96,19 +95,19 @@ public:
      * @param  orbital_name FZC, DRC, DOCC, ACT, RAS1, RAS2, RAS3, RAS4, POP, VIR, FZV, DRV, or ALL
      * @param  orbitals     SharedMatrix to set
      */
-    void set_orbitals(const std::string& orbital_name, SharedMatrix orbitals);
+    void set_orbitals(const std::string &orbital_name, SharedMatrix orbitals);
 
     /**!
      * Gets the dimension of the desired subspace.
      * @param  orbital_name FZC, DRC, DOCC, ACT, RAS1, RAS2, RAS3, RAS4, POP, VIR, FZV, DRV, or ALL
      * @return dim          Dimension object
      */
-    Dimension get_dimension(const std::string& orbital_name);
+    Dimension get_dimension(const std::string &orbital_name);
 
     /**!
      * Transform the one and two electron integrals for a CI computation.
      */
-    void transform_ci_integrals(void);
+    void transform_ci_integrals();
 
     /**!
      * Transform the one and two electron integrals for a MCSCF computation.
@@ -121,8 +120,7 @@ public:
      * @param onel_out  one-electron output vector
      * @param twoel_out two-electron output vector
      */
-    void rotate_mcscf_integrals(SharedMatrix K, SharedVector onel_out,
-                                SharedVector twoel_out);
+    void rotate_mcscf_integrals(SharedMatrix K, SharedVector onel_out, SharedVector twoel_out);
 
     /**
      * Takes a pitzer order act x act Matrix and converts it into a ci-ordered vector that
@@ -150,8 +148,7 @@ public:
      * @param full_space If false return only the active OPDM else return full OPDM
      * @return OPDM or TDM shared matrix
      **/
-    SharedMatrix get_opdm(int Iroot=-1, int Jroot=-1, const std::string& spin="SUM",
-                           bool full_space=false);
+    SharedMatrix get_opdm(int Iroot = -1, int Jroot = -1, const std::string &spin = "SUM", bool full_space = false);
 
     /**!
      * Compute the one-particle density matrix between two CIVectors
@@ -160,19 +157,19 @@ public:
      * @param Jroot      Jroot to use
      * @param Iroot      Iroot to use
      * @return           AA, BB, and summed OPDM's
-    **/
-    std::vector<SharedMatrix> opdm(SharedCIVector Ivec, SharedCIVector Jvec,
-                                    int Iroot, int Jroot);
+     **/
+    std::vector<SharedMatrix> opdm(SharedCIVector Ivec, SharedCIVector Jvec, int Iroot, int Jroot);
 
     /**!
      * Obtains the "special" TPDM, other TPDM roots are not held here.
-     * The AA (BB) order: \Gamma_{pqrs} & = \langle 0 | a_{p \alpha}^\dagger a_{r \alpha}^{\dagger} a_{s \alpha} a_{q \alpha} | 0 \rangle
-     * The AB order: \Gamma_{pqrs} & = \langle 0 | a_{p \alpha}^\dagger a_{r \beta}^{\dagger} a_{s \beta} a_{q \alpha} | 0 \rangle
+     * The AA (BB) order: \Gamma_{pqrs} & = \langle 0 | a_{p \alpha}^\dagger a_{r \alpha}^{\dagger} a_{s \alpha} a_{q
+     *\alpha} | 0 \rangle The AB order: \Gamma_{pqrs} & = \langle 0 | a_{p \alpha}^\dagger a_{r \beta}^{\dagger} a_{s
+     *\beta} a_{q \alpha} | 0 \rangle
      * @param spin       Selects which spin to return AA, AB, BB, or SUM
      * @param symmetrize Symmetrize the TPDM, only works for SUM currently
      * @return           The request 4D active TPDM
      **/
-    SharedMatrix get_tpdm(const std::string& spin = "SUM", bool symmetrize=true);
+    SharedMatrix get_tpdm(const std::string &spin = "SUM", bool symmetrize = true);
 
     /**!
      * Compute the two-particle density matrix between two CIVectors
@@ -181,9 +178,8 @@ public:
      * @param Jroot      Jroot to use
      * @param Iroot      Iroot to use
      * @return           AA, AB, BB, and summed TPDM's
-    **/
-    std::vector<SharedMatrix> tpdm(SharedCIVector Ivec, SharedCIVector Jvec, int Iroot,
-                                                   int Jroot);
+     **/
+    std::vector<SharedMatrix> tpdm(SharedCIVector Ivec, SharedCIVector Jvec, int Iroot, int Jroot);
 
     /**!
      Builds and returns a new CIvect object.
@@ -193,8 +189,7 @@ public:
      * @param buf_init  If true initializes the buffers internally
      * @return          SharedCIVector object
      **/
-    SharedCIVector new_civector(int maxnvect, int filenum, bool use_disk=true,
-                                bool buf_init=true);
+    SharedCIVector new_civector(int maxnvect, int filenum, bool use_disk = true, bool buf_init = true);
     /**
      * Returns the "D" vector that contains the current reference CI Wavefunction
      * @return The "D" vector
@@ -232,8 +227,7 @@ public:
      * @param oei  One-electron integrals to use
      * @param tei  Two-electron integrals to use
      */
-    void sigma(SharedCIVector C, SharedCIVector S, int cvec, int svec,
-               SharedVector oei, SharedVector tei);
+    void sigma(SharedCIVector C, SharedCIVector S, int cvec, int svec, SharedVector oei, SharedVector tei);
 
     /**
      * Prints the large values in a CIVector
@@ -245,8 +239,7 @@ public:
     /**
      * Compute the state-transfer operator. Currently in construction and not to be used.
      */
-    void compute_state_transfer(SharedCIVector ref, int ref_vec,
-                                SharedMatrix prop, SharedCIVector ret);
+    void compute_state_transfer(SharedCIVector ref, int ref_vec, SharedMatrix prop, SharedCIVector ret);
 
     // Compute functions
     void compute_cc();
@@ -306,8 +299,7 @@ public:
      */
     SharedMatrix hamiltonian(size_t hsize = 0);
 
-private:
-
+   private:
     /// => General Helper Functions <= ///
 
     /// Paramater and CalcInfo setters
@@ -328,7 +320,7 @@ private:
     bool cleaned_up_ci_;
 
     /// Find out which orbitals belong hwere
-    void orbital_locations(const std::string& orbital_name, int* start, int* end);
+    void orbital_locations(const std::string &orbital_name, int *start, int *end);
 
     /// Symmetry block a matrix
     SharedMatrix symm_block(SharedMatrix x, Dimension dim1, Dimension dim2);
@@ -338,10 +330,10 @@ private:
     bool df_ints_init_;
     bool mcscf_object_init_;
     bool fzc_fock_computed_;
-    std::shared_ptr<IntegralTransform> ints_; // Non-DF
+    std::shared_ptr<IntegralTransform> ints_;  // Non-DF
     std::shared_ptr<MOSpace> rot_space_;
     std::shared_ptr<MOSpace> act_space_;
-    std::shared_ptr<DFHelper> dfh_; // DF
+    std::shared_ptr<DFHelper> dfh_;  // DF
     std::shared_ptr<JK> jk_;
     std::shared_ptr<SOMCSCF> somcscf_;
 
@@ -386,22 +378,22 @@ private:
 
     /// => H0block functions <= //
     void H0block_init(size_t size);
-    void H0block_free(void);
-    void H0block_print(void);
-    int  H0block_calc(double E);
+    void H0block_free();
+    void H0block_print();
+    int H0block_calc(double E);
     void H0block_gather(double **mat, int al, int bl, int cscode, int mscode, int phase);
     void H0block_xy(double *x, double *y, double E);
     void H0block_setup(int num_blocks, int *Ia_code, int *Ib_code);
     void H0block_pairup(int guess);
-    void H0block_spin_cpl_chk(void);
-    void H0block_filter_setup(void);
-    void H0block_fill(void);
+    void H0block_spin_cpl_chk();
+    void H0block_filter_setup();
+    void H0block_fill();
     void H0block_coupling_calc(double E);
-    std::string print_config(int nbf, int num_alp_el, int num_bet_el,
-	  struct stringwr *stralp, struct stringwr *strbet, int num_drc_orbs);
+    std::string print_config(int nbf, int num_alp_el, int num_bet_el, struct stringwr *stralp, struct stringwr *strbet,
+                             int num_drc_orbs);
 
     /// => Slater Matrix Elements <= //
-    double matrix_element(SlaterDeterminant* I, SlaterDeterminant* J);
+    double matrix_element(SlaterDeterminant *I, SlaterDeterminant *J);
     int sme_first_call_;
     int *same_alpha_, *same_beta_;
     int *common_docc_, *common_alp_socc_, *common_bet_socc_;
@@ -409,74 +401,60 @@ private:
     int **I_diff_, **J_diff_;
 
     /// => CI Iterators <= //
-    void mitrush_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
-          **betlist, int nroots, double *evals, double conv_rms, double conv_e,
-          double enuc, double edrc, int maxiter, int maxnvect);
-    void olsen_update(CIvect &C, CIvect &S, CIvect &Hd, double E, double E_est,
-          double *norm, double *c1norm, double *ovrlap, double *buffer1,
-          double *buffer2,
-          int curr, int next, std::string out, int iter, struct stringwr **alplist,
-          struct stringwr **betlist);
-    void olsen_iter_xy(CIvect &C, CIvect &S, CIvect &Hd, double *x, double *y,
-          double *buffer1, double *buffer2, double E, int curvect, int L,
-          double **alpha, struct stringwr **alplist, struct stringwr **betlist);
-    void mitrush_update(CIvect &C, CIvect &S, double norm, double acur,
-       double alast, double *buffer1, double *buffer2, int curr, int next);
+    void mitrush_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr **betlist, int nroots, double *evals,
+                      double conv_rms, double conv_e, double enuc, double edrc, int maxiter, int maxnvect);
+    void olsen_update(CIvect &C, CIvect &S, CIvect &Hd, double E, double E_est, double *norm, double *c1norm,
+                      double *ovrlap, double *buffer1, double *buffer2, int curr, int next, std::string out, int iter,
+                      struct stringwr **alplist, struct stringwr **betlist);
+    void olsen_iter_xy(CIvect &C, CIvect &S, CIvect &Hd, double *x, double *y, double *buffer1, double *buffer2,
+                       double E, int curvect, int L, double **alpha, struct stringwr **alplist,
+                       struct stringwr **betlist);
+    void mitrush_update(CIvect &C, CIvect &S, double norm, double acur, double alast, double *buffer1, double *buffer2,
+                        int curr, int next);
 
-    void sem_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr
-      **betlist, double *evals, double conv_e,
-      double conv_rms, double enuc, double edrc,
-      int nroots, int maxiter, int maxnvect);
-    void parse_import_vector(SlaterDetSet *sdset, int *ialplist, int *ialpidx,
-      int *ibetlist, int *ibetidx, int *blknums);
-    void sem_test(double **A, int N, int M, int L, double **evecs, double *evals,
-          double **b, double conv_e, double conv_rms, int maxiter, double offst,
-          int *vu, int maxnvect);
+    void sem_iter(CIvect &Hd, struct stringwr **alplist, struct stringwr **betlist, double *evals, double conv_e,
+                  double conv_rms, double enuc, double edrc, int nroots, int maxiter, int maxnvect);
+    void parse_import_vector(SlaterDetSet *sdset, int *ialplist, int *ialpidx, int *ibetlist, int *ibetidx,
+                             int *blknums);
+    void sem_test(double **A, int N, int M, int L, double **evecs, double *evals, double **b, double conv_e,
+                  double conv_rms, int maxiter, double offst, int *vu, int maxnvect);
 
     /// => Sigma Calculations <= //
     struct sigma_data *SigmaData_;
-    void sigma_init(CIvect& C, CIvect &S);
-    void sigma_free(void);
-    void sigma(CIvect& C, CIvect& S, double *oei, double *tei, int ivec);
+    void sigma_init(CIvect &C, CIvect &S);
+    void sigma_free();
+    void sigma(CIvect &C, CIvect &S, double *oei, double *tei, int ivec);
 
-    void sigma_a(struct stringwr **alplist, struct stringwr **betlist,
-          CIvect& C, CIvect& S, double *oei, double *tei, int fci, int ivec);
-    void sigma_b(struct stringwr **alplist, struct stringwr **betlist,
-          CIvect& C, CIvect& S, double *oei, double *tei, int fci, int ivec);
-    void sigma_c(struct stringwr **alplist, struct stringwr **betlist,
-          CIvect& C, CIvect& S, double *oei, double *tei, int fci, int ivec);
+    void sigma_a(struct stringwr **alplist, struct stringwr **betlist, CIvect &C, CIvect &S, double *oei, double *tei,
+                 int fci, int ivec);
+    void sigma_b(struct stringwr **alplist, struct stringwr **betlist, CIvect &C, CIvect &S, double *oei, double *tei,
+                 int fci, int ivec);
+    void sigma_c(struct stringwr **alplist, struct stringwr **betlist, CIvect &C, CIvect &S, double *oei, double *tei,
+                 int fci, int ivec);
 
-    void sigma_block(struct stringwr **alplist, struct stringwr **betlist,
-          double **cmat, double **smat, double *oei, double *tei, int fci,
-          int cblock, int sblock, int nas, int nbs, int sac, int sbc,
-          int cac, int cbc, int cnas, int cnbs, int cnac, int cnbc,
-          int sbirr, int cbirr, int Ms0);
-    void sigma_get_contrib(struct stringwr **alplist, struct stringwr **betlist,
-          CIvect &C, CIvect &S, int **s1_contrib, int **s2_contrib,
-          int **s3_contrib);
-        void form_ov();
-    void sigma_get_contrib_rotf(CIvect &C, CIvect &S,
-          int **s1_contrib, int **s2_contrib, int **s3_contrib,
-          int *Cnt[2], int **Ij[2], int **Oij[2], int **Ridx[2],
-          signed char **Sgn[2], unsigned char **Toccs);
+    void sigma_block(struct stringwr **alplist, struct stringwr **betlist, double **cmat, double **smat, double *oei,
+                     double *tei, int fci, int cblock, int sblock, int nas, int nbs, int sac, int sbc, int cac, int cbc,
+                     int cnas, int cnbs, int cnac, int cnbc, int sbirr, int cbirr, int Ms0);
+    void sigma_get_contrib(struct stringwr **alplist, struct stringwr **betlist, CIvect &C, CIvect &S, int **s1_contrib,
+                           int **s2_contrib, int **s3_contrib);
+    void form_ov();
+    void sigma_get_contrib_rotf(CIvect &C, CIvect &S, int **s1_contrib, int **s2_contrib, int **s3_contrib, int *Cnt[2],
+                                int **Ij[2], int **Oij[2], int **Ridx[2], signed char **Sgn[2], unsigned char **Toccs);
 
-    void print_vec(size_t nprint, int *Ialist, int *Iblist,
-          int *Iaidx, int *Ibidx, double *coeff);
+    void print_vec(size_t nprint, int *Ialist, int *Iblist, int *Iaidx, int *Ibidx, double *coeff);
 
     /// => MCSCF helpers <= //
 
-
     /// => MPn helpers <= //
     void mpn_generator(CIvect &Hd);
 
     /// => Density Matrix helpers <= //
     std::vector<std::vector<SharedMatrix> > opdm(SharedCIVector Ivec, SharedCIVector Jvec,
-                                                std::vector<std::tuple<int, int> > states_vec);
-    SharedMatrix opdm_add_inactive(SharedMatrix opdm, double value, bool virt=false);
-    void opdm_block(struct stringwr **alplist, struct stringwr **betlist,
-            double **onepdm_a, double **onepdm_b, double **CJ, double **CI, int Ja_list,
-            int Jb_list, int Jnas, int Jnbs, int Ia_list, int Ib_list,
-            int Inas, int Inbs);
+                                                 std::vector<std::tuple<int, int> > states_vec);
+    SharedMatrix opdm_add_inactive(SharedMatrix opdm, double value, bool virt = false);
+    void opdm_block(struct stringwr **alplist, struct stringwr **betlist, double **onepdm_a, double **onepdm_b,
+                    double **CJ, double **CI, int Ja_list, int Jb_list, int Jnas, int Jnbs, int Ia_list, int Ib_list,
+                    int Inas, int Inbs);
 
     // OPDM holders, opdm_map holds lots of active-active opdms
     // opdm_, opdm_a_, etc are for "the" current OPDM
@@ -488,11 +466,9 @@ private:
 
     std::vector<SharedMatrix> tpdm(SharedCIVector Ivec, SharedCIVector Jvec,
                                    std::vector<std::tuple<int, int, double> > states_vec);
-    void tpdm_block(struct stringwr **alplist, struct stringwr **betlist,
-            int nbf, int nalplists, int nbetlists,
-            double *twopdm_aa, double *twopdm_bb, double *twopdm_ab, double **CJ, double **CI, int Ja_list,
-            int Jb_list, int Jnas, int Jnbs, int Ia_list, int Ib_list,
-            int Inas, int Inbs, double weight);
+    void tpdm_block(struct stringwr **alplist, struct stringwr **betlist, int nbf, int nalplists, int nbetlists,
+                    double *twopdm_aa, double *twopdm_bb, double *twopdm_ab, double **CJ, double **CI, int Ja_list,
+                    int Jb_list, int Jnas, int Jnbs, int Ia_list, int Ib_list, int Inas, int Inbs, double weight);
 
     bool tpdm_called_;
     SharedMatrix tpdm_;
@@ -500,8 +476,9 @@ private:
     SharedMatrix tpdm_ab_;
     SharedMatrix tpdm_bb_;
 
-}; // End CIWavefunction
+};  // End CIWavefunction
 
-}}
+}  // namespace detci
+}  // namespace psi
 
-#endif // CIWAVE_H
+#endif  // CIWAVE_H
