@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -45,72 +45,64 @@
 #include <cmath>
 #include <cstring>
 #include <sstream>
-#include <cctype> // for toupper()
+#include <cctype>  // for toupper()
 #include "psi4/libciomr/libciomr.h"
 #include "psi4/libqt/qt.h"
 
 #include "psi4/detci/structs.h"
 #include "psi4/detci/ciwave.h"
 
-namespace psi { namespace detci {
+namespace psi {
+namespace detci {
 
 #define FLAG_NONBLOCKS
 #define MIN_COEFF 1.0E-13
 
-std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr);
+std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int *orbs_per_irr);
 extern int str_rel2abs(int relidx, int listnum, struct olsen_graph *Graph);
 
-
 /*
 ** PRINT_VEC()
 **
 ** Print the Most Important Determinants in the CI vector
 ** David Sherrill, February 1995
 */
-void CIWavefunction::print_vec(size_t nprint, int *Ialist, int *Iblist,
-      int *Iaidx, int *Ibidx, double *coeff)
-{
-   int Ia_abs, Ib_abs;
+void CIWavefunction::print_vec(size_t nprint, int *Ialist, int *Iblist, int *Iaidx, int *Ibidx, double *coeff) {
+    int Ia_abs, Ib_abs;
 
-   /* print out the list of most important determinants */
-   outfile->Printf("\n   The %d most important determinants:\n\n", nprint) ;
-   for (size_t i=0; i<nprint; i++) {
-      if (std::fabs(coeff[i]) < MIN_COEFF) continue;
+    /* print out the list of most important determinants */
+    outfile->Printf("\n   The %d most important determinants:\n\n", nprint);
+    for (size_t i = 0; i < nprint; i++) {
+        if (std::fabs(coeff[i]) < MIN_COEFF) continue;
 
-      Ia_abs = str_rel2abs(Iaidx[i], Ialist[i], AlphaG_);
-      Ib_abs = str_rel2abs(Ibidx[i], Iblist[i], BetaG_);
+        Ia_abs = str_rel2abs(Iaidx[i], Ialist[i], AlphaG_);
+        Ib_abs = str_rel2abs(Ibidx[i], Iblist[i], BetaG_);
 
-      #ifdef FLAG_NONBLOCKS
-      int found_inblock=0;
-      for (size_t j=0, found_inblock=0; j<H0block_->size; j++) {
-         if (Iaidx[i] == H0block_->alpidx[j] &&
-             Ibidx[i] == H0block_->betidx[j] &&
-             Ialist[i] == H0block_->alplist[j] &&
-             Iblist[i] == H0block_->betlist[j]) {
-            found_inblock = 1;
-            break;
+#ifdef FLAG_NONBLOCKS
+        int found_inblock = 0;
+        for (size_t j = 0, found_inblock = 0; j < H0block_->size; j++) {
+            if (Iaidx[i] == H0block_->alpidx[j] && Ibidx[i] == H0block_->betidx[j] &&
+                Ialist[i] == H0block_->alplist[j] && Iblist[i] == H0block_->betlist[j]) {
+                found_inblock = 1;
+                break;
             }
-         }
-      outfile->Printf("    %c", found_inblock ? ' ' : '*');
-      #endif
+        }
+        outfile->Printf("    %c", found_inblock ? ' ' : '*');
+#endif
 
-      outfile->Printf("%4d  %10.6lf  (%5d,%5d)  ", i+1, coeff[i],
-         Ia_abs, Ib_abs);
+        outfile->Printf("%4d  %10.6lf  (%5d,%5d)  ", i + 1, coeff[i], Ia_abs, Ib_abs);
 
-      std::string configstring(print_config(AlphaG_->num_orb, AlphaG_->num_el_expl, BetaG_->num_el_expl,
-         alplist_[Ialist[i]] + Iaidx[i], betlist_[Iblist[i]] + Ibidx[i],
-         AlphaG_->num_drc_orbs));
+        std::string configstring(print_config(AlphaG_->num_orb, AlphaG_->num_el_expl, BetaG_->num_el_expl,
+                                              alplist_[Ialist[i]] + Iaidx[i], betlist_[Iblist[i]] + Ibidx[i],
+                                              AlphaG_->num_drc_orbs));
 
-      outfile->Printf("%s\n", configstring.c_str());
+        outfile->Printf("%s\n", configstring.c_str());
 
-      } /* end loop over important determinants */
-
-   outfile->Printf("\n");
+    } /* end loop over important determinants */
 
+    outfile->Printf("\n");
 }
 
-
-
 /*
 ** PRINT_CONFIG()
 **
@@ -120,41 +112,44 @@ void CIWavefunction::print_vec(size_t nprint, int *Ialist, int *Iblist,
 ** David Sherrill, February 1995
 **
 */
-std::string CIWavefunction::print_config(int nbf, int num_alp_el, int num_bet_el,
-	     struct stringwr *stralp, struct stringwr *strbet, int num_drc_orbs)
-{
-   int j,k;
-   int afound, bfound;
+std::string CIWavefunction::print_config(int nbf, int num_alp_el, int num_bet_el, struct stringwr *stralp,
+                                         struct stringwr *strbet, int num_drc_orbs) {
+    int j, k;
+    int afound, bfound;
 
-   std::ostringstream oss;
+    std::ostringstream oss;
 
-   /* loop over orbitals */
-   for (j=0; j<nbf; j++) {
+    /* loop over orbitals */
+    for (j = 0; j < nbf; j++) {
+        std::string olabel(orb2lbl(j + num_drc_orbs, CalcInfo_, nmopi_)); /* get label for orbital j */
 
-     std::string olabel(orb2lbl(j+num_drc_orbs, CalcInfo_, nmopi_)); /* get label for orbital j */
-
-      for (k=0,afound=0; k<num_alp_el; k++) {
-         if ((stralp->occs)[k] > j) break;
-         else if ((stralp->occs)[k] == j) {
-            afound = 1;
-            break;
+        for (k = 0, afound = 0; k < num_alp_el; k++) {
+            if ((stralp->occs)[k] > j)
+                break;
+            else if ((stralp->occs)[k] == j) {
+                afound = 1;
+                break;
             }
-         }
-      for (k=0, bfound=0; k<num_bet_el; k++) {
-         if ((strbet->occs)[k] > j) break;
-         else if ((strbet->occs)[k] == j) {
-            bfound = 1;
-            break;
+        }
+        for (k = 0, bfound = 0; k < num_bet_el; k++) {
+            if ((strbet->occs)[k] > j)
+                break;
+            else if ((strbet->occs)[k] == j) {
+                bfound = 1;
+                break;
             }
-         }
-      if (afound || bfound) oss << olabel;
+        }
+        if (afound || bfound) oss << olabel;
 
-      if (afound && bfound) oss << "X ";
-      else if (afound) oss << "A ";
-      else if (bfound) oss << "B ";
-      } /* end loop over orbitals */
+        if (afound && bfound)
+            oss << "X ";
+        else if (afound)
+            oss << "A ";
+        else if (bfound)
+            oss << "B ";
+    } /* end loop over orbitals */
 
-   return oss.str();
+    return oss.str();
 }
 
 /*
@@ -185,38 +180,36 @@ std::string CIWavefunction::print_config(int nbf, int num_alp_el, int num_bet_el
 **    Allow it to handle more complex spaces...don't assume QT orbital order.
 **    It was getting labels all mixed up for RAS's.
 */
-std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
-{
+std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int *orbs_per_irr) {
+    int ir, j, pitzer_orb, rel_orb;
 
-   int ir, j, pitzer_orb, rel_orb;
+    /* get Pitzer ordering */
+    pitzer_orb = Cinfo->order[orbnum];
 
-   /* get Pitzer ordering */
-   pitzer_orb = Cinfo->order[orbnum];
+    if (pitzer_orb > Cinfo->nmo) {
+        outfile->Printf("(orb2lbl): pitzer_orb > nmo!\n");
+    }
 
-   if (pitzer_orb > Cinfo->nmo) {
-      outfile->Printf( "(orb2lbl): pitzer_orb > nmo!\n");
-      }
+    for (ir = 0, j = 0; ir < Cinfo->nirreps; ir++) {
+        if (orbs_per_irr[ir] == 0) continue;
+        if (j + orbs_per_irr[ir] > pitzer_orb)
+            break;
+        else
+            j += orbs_per_irr[ir];
+    }
+    rel_orb = pitzer_orb - j;
 
-   for (ir=0,j=0; ir<Cinfo->nirreps; ir++) {
-      if (orbs_per_irr[ir] == 0) continue;
-      if (j + orbs_per_irr[ir] > pitzer_orb) break;
-      else j += orbs_per_irr[ir];
-      }
-   rel_orb = pitzer_orb - j;
+    if (rel_orb < 0) {
+        outfile->Printf("(orb2lbl): rel_orb < 0\n");
+    } else if (rel_orb > orbs_per_irr[ir]) {
+        outfile->Printf("(orb2lbl): rel_orb > orbs_per_irrep[ir]\n");
+    }
 
-   if (rel_orb < 0) {
-      outfile->Printf( "(orb2lbl): rel_orb < 0\n");
-      }
-   else if (rel_orb > orbs_per_irr[ir]) {
-      outfile->Printf( "(orb2lbl): rel_orb > orbs_per_irrep[ir]\n");
-      }
-
-   std::ostringstream oss;
-   oss << rel_orb+1 << Cinfo->labels[ir];
-   return oss.str();
+    std::ostringstream oss;
+    oss << rel_orb + 1 << Cinfo->labels[ir];
+    return oss.str();
 }
 
-
 /*
 ** lbl2orb(): Function converts a label such as 4A1, 2B2, etc., to
 **   an absolute orbital number.  The reverse of the above function
@@ -230,7 +223,7 @@ std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
 **    absolute orbital number for the correlated calc (less frozen)
 **
 */
-//int lbl2orb(char *orbstring)
+// int lbl2orb(char *orbstring)
 //{
 //
 //   int ir, i, j, pitzer_orb, rel_orb, corr_orb;
@@ -280,14 +273,13 @@ std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
 //
 //}
 
-
-//void eivout_t(double **a, double *b, int m, int n)
+// void eivout_t(double **a, double *b, int m, int n)
 //   {
 //      int ii,jj,kk,nn,ll;
 //      int i,j,k;
 //
 //      ii=0;jj=0;
-//L200:
+// L200:
 //      ii++;
 //      jj++;
 //      kk=10*jj;
@@ -315,7 +307,6 @@ std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
 //      ii=kk; goto L200;
 //}
 
-
 /*
 ** PRINT_CIBLK_SUMMARY()
 **
@@ -323,7 +314,7 @@ std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
 ** April 1996
 **
 */
-//void print_ciblk_summary(std::string out)
+// void print_ciblk_summary(std::string out)
 //{
 //   int blk;
 //
@@ -336,5 +327,5 @@ std::string orb2lbl(int orbnum, struct calcinfo *Cinfo, int* orbs_per_irr)
 //              (size_t) CIblks.Ib_size[blk]);
 //      }
 //}
-
-}} // namespace psi::detci
+}
+}  // namespace psi
