@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -47,7 +47,7 @@ void DFOCC::effective_mograd() {
         WvoB->form_vo(WorbB);
     }
 
-    if (freeze_core_ == "TRUE") {
+    if (nfrzc > 0) {
         z_vector_fc();
         fc_grad_terms();
     }
