@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -37,7 +37,7 @@
 #include <fstream>
 #include <algorithm>
 #include <utility>
-#include <ctype.h>
+#include <cctype>
 #include "psi4/libmints/matrix.h"
 #include "psi4/libmints/mintshelper.h"
 #include "psi4/libmints/basisset.h"
@@ -46,34 +46,32 @@
 
 namespace psi {
 
-DFTensor::DFTensor(std::shared_ptr<BasisSet> primary,
-                   std::shared_ptr<BasisSet> auxiliary,
-                   SharedMatrix C,
-                   int nocc,
-                   int nvir,
-                   int naocc,
-                   int navir,
-                   Options& options) :
-    primary_(primary), auxiliary_(auxiliary), C_(C), nocc_(nocc), nvir_(nvir),
-    naocc_(naocc), navir_(navir), options_(options)
-{
+DFTensor::DFTensor(std::shared_ptr<BasisSet> primary, std::shared_ptr<BasisSet> auxiliary, SharedMatrix C, int nocc,
+                   int nvir, int naocc, int navir, Options& options)
+    : primary_(primary),
+      auxiliary_(auxiliary),
+      C_(C),
+      nocc_(nocc),
+      nvir_(nvir),
+      naocc_(naocc),
+      navir_(navir),
+      options_(options) {
     common_init();
 }
-DFTensor::DFTensor(std::shared_ptr<BasisSet> primary,
-                   std::shared_ptr<BasisSet> auxiliary,
-                   SharedMatrix C,
-                   int nocc,
-                   int nvir) :
-    primary_(primary), auxiliary_(auxiliary), C_(C), nocc_(nocc), nvir_(nvir),
-    naocc_(nocc), navir_(nvir), options_(Process::environment.options)
-{
+DFTensor::DFTensor(std::shared_ptr<BasisSet> primary, std::shared_ptr<BasisSet> auxiliary, SharedMatrix C, int nocc,
+                   int nvir)
+    : primary_(primary),
+      auxiliary_(auxiliary),
+      C_(C),
+      nocc_(nocc),
+      nvir_(nvir),
+      naocc_(nocc),
+      navir_(nvir),
+      options_(Process::environment.options) {
     common_init();
 }
-DFTensor::~DFTensor()
-{
-}
-void DFTensor::common_init()
-{
+DFTensor::~DFTensor() {}
+void DFTensor::common_init() {
     print_ = options_.get_int("PRINT");
     debug_ = options_.get_int("DEBUG");
 
@@ -84,19 +82,19 @@ void DFTensor::common_init()
     nfocc_ = nocc_ - naocc_;
     nfvir_ = nvir_ - navir_;
 
-    nso_ = C_->rowspi()[0];
+    nbf_ = primary_->nbf();
     nmo_ = C_->colspi()[0];
 
-    Caocc_ = std::make_shared<Matrix>("C active occupied", nso_, naocc_);
-    Cavir_ = std::make_shared<Matrix>("C active virtual", nso_, navir_);
+    Caocc_ = std::make_shared<Matrix>("C active occupied", nbf_, naocc_);
+    Cavir_ = std::make_shared<Matrix>("C active virtual", nbf_, navir_);
 
     double** Cp = C_->pointer();
-    double** Cop  = Caocc_->pointer();
-    double** Cvp  = Cavir_->pointer();
+    double** Cop = Caocc_->pointer();
+    double** Cvp = Cavir_->pointer();
 
-    for (int m = 0; m < nso_; m++) {
-        C_DCOPY(naocc_, &Cp[m][nfocc_],1, Cop[m], 1);
-        C_DCOPY(navir_, &Cp[m][nocc_],1, Cvp[m], 1);
+    for (int m = 0; m < nbf_; m++) {
+        C_DCOPY(naocc_, &Cp[m][nfocc_], 1, Cop[m], 1);
+        C_DCOPY(navir_, &Cp[m][nocc_], 1, Cvp[m], 1);
     }
 
     if (debug_) {
@@ -109,39 +107,34 @@ void DFTensor::common_init()
 
     build_metric();
 }
-void DFTensor::print_header()
-{
+void DFTensor::print_header() {
     outfile->Printf("  ==> DF Tensor (by Rob Parrish) <==\n\n");
 
     outfile->Printf(" => Primary Basis Set <= \n\n");
-    primary_->print_by_level("outfile",print_);
-
+    primary_->print_by_level("outfile", print_);
 
     outfile->Printf(" => Auxiliary Basis Set <= \n\n");
-    auxiliary_->print_by_level("outfile",print_);
-
+    auxiliary_->print_by_level("outfile", print_);
 }
-void DFTensor::build_metric()
-{
+void DFTensor::build_metric() {
     auto met = std::make_shared<FittingMetric>(auxiliary_, true);
-    met->form_eig_inverse();
+    met->form_eig_inverse(options_.get_double("DF_FITTING_CONDITION"));
     metric_ = met->get_metric();
 
     if (debug_) {
         metric_->print();
     }
 }
-SharedMatrix DFTensor::Qso()
-{
-    auto B = std::make_shared<Matrix>("Bso", naux_, nso_ * nso_);
-    auto A = std::make_shared<Matrix>("Aso", naux_, nso_ * nso_);
+SharedMatrix DFTensor::Qso() {
+    auto B = std::make_shared<Matrix>("Bso", naux_, nbf_ * nbf_);
+    auto A = std::make_shared<Matrix>("Aso", naux_, nbf_ * nbf_);
     double** Ap = A->pointer();
     double** Bp = B->pointer();
     double** Jp = metric_->pointer();
 
     std::shared_ptr<BasisSet> zero = BasisSet::zero_ao_basis_set();
 
-    auto fact = std::make_shared<IntegralFactory>(auxiliary_,zero,primary_,primary_);
+    auto fact = std::make_shared<IntegralFactory>(auxiliary_, zero, primary_, primary_);
     std::shared_ptr<TwoBodyAOInt> eri(fact->eri());
     const double* buffer = eri->buffer();
 
@@ -155,12 +148,12 @@ SharedMatrix DFTensor::Qso()
                 int nn = primary_->shell(N).nfunction();
                 int nstart = primary_->shell(N).function_index();
 
-                eri->compute_shell(P,0,M,N);
+                eri->compute_shell(P, 0, M, N);
 
                 for (int p = 0, index = 0; p < np; p++) {
                     for (int m = 0; m < nm; m++) {
                         for (int n = 0; n < nn; n++, index++) {
-                            Bp[p + pstart][(m + mstart) * nso_ + (n + nstart)] = buffer[index];
+                            Bp[p + pstart][(m + mstart) * nbf_ + (n + nstart)] = buffer[index];
                         }
                     }
                 }
@@ -168,8 +161,7 @@ SharedMatrix DFTensor::Qso()
         }
     }
 
-    C_DGEMM('N','N',naux_, nso_ * nso_, naux_, 1.0, Jp[0], naux_, Bp[0], nso_ * nso_, 0.0,
-        Ap[0], nso_ * nso_);
+    C_DGEMM('N', 'N', naux_, nbf_ * nbf_, naux_, 1.0, Jp[0], naux_, Bp[0], nbf_ * nbf_, 0.0, Ap[0], nbf_ * nbf_);
 
     if (debug_) {
         metric_->print();
@@ -177,30 +169,28 @@ SharedMatrix DFTensor::Qso()
         A->print();
     }
     // Build numpy and final matrix shape
-    std::vector<int> nshape{naux_, nso_, nso_};
+    std::vector<int> nshape{naux_, nbf_, nbf_};
     A->set_numpy_shape(nshape);
 
     return A;
 }
-SharedMatrix DFTensor::Qoo()
-{
+SharedMatrix DFTensor::Qoo() {
     SharedMatrix Amn = Qso();
-    auto Ami = std::make_shared<Matrix>("Ami", naux_, naocc_ * (size_t) nso_);
+    auto Ami = std::make_shared<Matrix>("Ami", naux_, naocc_ * (size_t)nbf_);
 
     double** Amnp = Amn->pointer();
     double** Amip = Ami->pointer();
     double** Cop = Caocc_->pointer();
 
-    C_DGEMM('N','N', naux_ * (size_t) nso_, naocc_, nso_, 1.0, Amnp[0], nso_, Cop[0], naocc_,
-        0.0, Amip[0], naocc_);
+    C_DGEMM('N', 'N', naux_ * (size_t)nbf_, naocc_, nbf_, 1.0, Amnp[0], nbf_, Cop[0], naocc_, 0.0, Amip[0], naocc_);
 
     Amn.reset();
 
-    auto Aia = std::make_shared<Matrix>("Aij", naux_, naocc_ * (size_t) naocc_);
+    auto Aia = std::make_shared<Matrix>("Aij", naux_, naocc_ * (size_t)naocc_);
     double** Aiap = Aia->pointer();
 
     for (int Q = 0; Q < naux_; Q++) {
-        C_DGEMM('T','N',naocc_,naocc_,nso_,1.0,Amip[Q],naocc_,Cop[0],naocc_, 0.0, Aiap[Q], naocc_);
+        C_DGEMM('T', 'N', naocc_, naocc_, nbf_, 1.0, Amip[Q], naocc_, Cop[0], naocc_, 0.0, Aiap[Q], naocc_);
     }
 
     if (debug_) {
@@ -214,27 +204,25 @@ SharedMatrix DFTensor::Qoo()
 
     return Aia;
 }
-SharedMatrix DFTensor::Qov()
-{
+SharedMatrix DFTensor::Qov() {
     SharedMatrix Amn = Qso();
-    auto Ami = std::make_shared<Matrix>("Qmi", naux_, naocc_ * (size_t) nso_);
+    auto Ami = std::make_shared<Matrix>("Qmi", naux_, naocc_ * (size_t)nbf_);
 
     double** Amnp = Amn->pointer();
     double** Amip = Ami->pointer();
     double** Cop = Caocc_->pointer();
     double** Cvp = Cavir_->pointer();
 
-    C_DGEMM('N','N', naux_ * (size_t) nso_, naocc_, nso_, 1.0, Amnp[0], nso_, Cop[0], naocc_,
-        0.0, Amip[0], naocc_);
+    C_DGEMM('N', 'N', naux_ * (size_t)nbf_, naocc_, nbf_, 1.0, Amnp[0], nbf_, Cop[0], naocc_, 0.0, Amip[0], naocc_);
 
     Amn.reset();
 
-    outfile->Printf( "DFTensor::Qov: naux %d, naocc %d, navir %d\n", naux_, naocc_, navir_);
-    auto Aia = std::make_shared<Matrix>("Qia", naux_, naocc_ * (size_t) navir_);
+    outfile->Printf("DFTensor::Qov: naux %d, naocc %d, navir %d\n", naux_, naocc_, navir_);
+    auto Aia = std::make_shared<Matrix>("Qia", naux_, naocc_ * (size_t)navir_);
     double** Aiap = Aia->pointer();
 
     for (int Q = 0; Q < naux_; Q++) {
-        C_DGEMM('T','N',naocc_,navir_,nso_,1.0,Amip[Q],naocc_,Cvp[0],navir_, 0.0, Aiap[Q], navir_);
+        C_DGEMM('T', 'N', naocc_, navir_, nbf_, 1.0, Amip[Q], naocc_, Cvp[0], navir_, 0.0, Aiap[Q], navir_);
     }
 
     if (debug_) {
@@ -249,25 +237,23 @@ SharedMatrix DFTensor::Qov()
 
     return Aia;
 }
-SharedMatrix DFTensor::Qvv()
-{
+SharedMatrix DFTensor::Qvv() {
     SharedMatrix Amn = Qso();
-    auto Ami = std::make_shared<Matrix>("Qmi", naux_, navir_ * (size_t) nso_);
+    auto Ami = std::make_shared<Matrix>("Qmi", naux_, navir_ * (size_t)nbf_);
 
     double** Amnp = Amn->pointer();
     double** Amip = Ami->pointer();
     double** Cvp = Cavir_->pointer();
 
-    C_DGEMM('N','N', naux_ * (size_t) nso_, navir_, nso_, 1.0, Amnp[0], nso_, Cvp[0], navir_,
-        0.0, Amip[0], navir_);
+    C_DGEMM('N', 'N', naux_ * (size_t)nbf_, navir_, nbf_, 1.0, Amnp[0], nbf_, Cvp[0], navir_, 0.0, Amip[0], navir_);
 
     Amn.reset();
 
-    auto Aia = std::make_shared<Matrix>("Qab", naux_, navir_ * (size_t) navir_);
+    auto Aia = std::make_shared<Matrix>("Qab", naux_, navir_ * (size_t)navir_);
     double** Aiap = Aia->pointer();
 
     for (int Q = 0; Q < naux_; Q++) {
-        C_DGEMM('T','N',navir_,navir_,nso_,1.0,Amip[Q],navir_,Cvp[0],navir_, 0.0, Aiap[Q], navir_);
+        C_DGEMM('T', 'N', navir_, navir_, nbf_, 1.0, Amip[Q], navir_, Cvp[0], navir_, 0.0, Aiap[Q], navir_);
     }
 
     if (debug_) {
@@ -281,25 +267,23 @@ SharedMatrix DFTensor::Qvv()
 
     return Aia;
 }
-SharedMatrix DFTensor::Qmo()
-{
+SharedMatrix DFTensor::Qmo() {
     SharedMatrix Amn = Qso();
-    auto Ami = std::make_shared<Matrix>("Qmi", naux_, nmo_ * (size_t) nso_);
+    auto Ami = std::make_shared<Matrix>("Qmi", naux_, nmo_ * (size_t)nbf_);
 
     double** Amnp = Amn->pointer();
     double** Amip = Ami->pointer();
     double** Cvp = C_->pointer();
 
-    C_DGEMM('N','N', naux_ * (size_t) nso_, nmo_, nso_, 1.0, Amnp[0], nso_, Cvp[0], nmo_,
-        0.0, Amip[0], nmo_);
+    C_DGEMM('N', 'N', naux_ * (size_t)nbf_, nmo_, nbf_, 1.0, Amnp[0], nbf_, Cvp[0], nmo_, 0.0, Amip[0], nmo_);
 
     Amn.reset();
 
-    auto Aia = std::make_shared<Matrix>("Qmo", naux_, nmo_ * (size_t) nmo_);
+    auto Aia = std::make_shared<Matrix>("Qmo", naux_, nmo_ * (size_t)nmo_);
     double** Aiap = Aia->pointer();
 
     for (int Q = 0; Q < naux_; Q++) {
-        C_DGEMM('T','N',nmo_,nmo_,nso_,1.0,Amip[Q],nmo_,Cvp[0],nmo_, 0.0, Aiap[Q], nmo_);
+        C_DGEMM('T', 'N', nmo_, nmo_, nbf_, 1.0, Amip[Q], nmo_, Cvp[0], nmo_, 0.0, Aiap[Q], nmo_);
     }
 
     if (debug_) {
@@ -313,21 +297,19 @@ SharedMatrix DFTensor::Qmo()
 
     return Aia;
 }
-SharedMatrix DFTensor::Imo()
-{
+SharedMatrix DFTensor::Imo() {
     auto mints = std::make_shared<MintsHelper>(primary_, options_, 0);
-    return mints->mo_eri(C_,C_);
+    return mints->mo_eri(C_, C_);
 }
-SharedMatrix DFTensor::Idfmo()
-{
+SharedMatrix DFTensor::Idfmo() {
     SharedMatrix Amo = Qmo();
     double** Amop = Amo->pointer();
 
     auto Imo = std::make_shared<Matrix>("DF MO ERI Tensor", nmo_ * nmo_, nmo_ * nmo_);
     double** Imop = Imo->pointer();
 
-    C_DGEMM('T','N',nmo_ * nmo_, nmo_ * nmo_, naux_, 1.0, Amop[0], nmo_ * nmo_,
-        Amop[0], nmo_ * nmo_, 0.0, Imop[0], nmo_ * nmo_);
+    C_DGEMM('T', 'N', nmo_ * nmo_, nmo_ * nmo_, naux_, 1.0, Amop[0], nmo_ * nmo_, Amop[0], nmo_ * nmo_, 0.0, Imop[0],
+            nmo_ * nmo_);
 
     // Build numpy and final matrix shape
     std::vector<int> nshape{nmo_, nmo_, nmo_, nmo_};
@@ -335,5 +317,4 @@ SharedMatrix DFTensor::Idfmo()
 
     return Imo;
 }
-
 }
