@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -45,17 +45,15 @@ namespace psi {
 **
 ** \ingroup CIOMR
 */
-void tri_to_sq(double *amat, double **bmat, int size)
-{
-  int i, j, ij;
+void tri_to_sq(double *amat, double **bmat, int size) {
+    int i, j, ij;
 
-  ij=0;
-  for(i = 0 ; i < size ; i++) {
-    for(j = 0 ; j <= i ; j++) {
-      bmat[i][j] = amat[ij];
-      bmat[j][i] = amat[ij++];
+    ij = 0;
+    for (i = 0; i < size; i++) {
+        for (j = 0; j <= i; j++) {
+            bmat[i][j] = amat[ij];
+            bmat[j][i] = amat[ij++];
+        }
     }
-  }
 }
-
 }
