@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -51,8 +51,7 @@ namespace psi {
 ** TDC, September 1999
 */
 
-int DPD::buf4_copy(dpdbuf4 *InBuf, int outfilenum, const char *label)
-{
+int DPD::buf4_copy(dpdbuf4 *InBuf, int outfilenum, const char *label) {
     int h, row, col, my_irrep;
     long int rowtot, coltot;
     int nbuckets, incore, n;
@@ -61,96 +60,83 @@ int DPD::buf4_copy(dpdbuf4 *InBuf, int outfilenum, const char *label)
 
     my_irrep = InBuf->file.my_irrep;
 
-    buf4_init(&OutBuf, outfilenum, InBuf->file.my_irrep, InBuf->params->pqnum,
-                    InBuf->params->rsnum, InBuf->params->pqnum,
-                    InBuf->params->rsnum, 0, label);
+    buf4_init(&OutBuf, outfilenum, InBuf->file.my_irrep, InBuf->params->pqnum, InBuf->params->rsnum,
+              InBuf->params->pqnum, InBuf->params->rsnum, 0, label);
 
-    for(h=0; h < InBuf->params->nirreps; h++) {
-
-        memoryd = dpd_memfree()/2; /* use half the memory for each buf4 */
+    for (h = 0; h < InBuf->params->nirreps; h++) {
+        memoryd = dpd_memfree() / 2; /* use half the memory for each buf4 */
 
         rowtot = InBuf->params->rowtot[h];
-        coltot = InBuf->params->coltot[h^my_irrep];
+        coltot = InBuf->params->coltot[h ^ my_irrep];
 
-        if(rowtot && coltot) {
-
-            rows_per_bucket = memoryd/coltot;
+        if (rowtot && coltot) {
+            rows_per_bucket = memoryd / coltot;
             /* enough memory for the whole matrix? */
-            if(rows_per_bucket > rowtot)
-                rows_per_bucket = rowtot;
+            if (rows_per_bucket > rowtot) rows_per_bucket = rowtot;
 
-            if(!rows_per_bucket) dpd_error("buf4_scmcopy: Not enough memory for one row!", "outfile");
+            if (!rows_per_bucket) dpd_error("buf4_scmcopy: Not enough memory for one row!", "outfile");
 
-            nbuckets = (int) ceil(((double) rowtot)/((double) rows_per_bucket));
+            nbuckets = (int)ceil(((double)rowtot) / ((double)rows_per_bucket));
 
             rows_left = rowtot % rows_per_bucket;
 
             incore = 1;
-            if(nbuckets > 1) {
+            if (nbuckets > 1) {
                 incore = 0;
 #if DPD_DEBUG
-                outfile->Printf( "buf4_copy: memory information.\n");
-                outfile->Printf( "buf4_copy: rowtot[%d] = %d.\n", h, InBuf->params->rowtot[h]);
-                outfile->Printf( "buf4_copy: nbuckets = %d\n", nbuckets);
-                outfile->Printf( "buf4_copy: rows_per_bucket = %d\n", rows_per_bucket);
-                outfile->Printf( "buf4_copy: rows_left = %d\n", rows_left);
-                outfile->Printf( "buf4_copy: out-of-core algorithm used\n");
+                outfile->Printf("buf4_copy: memory information.\n");
+                outfile->Printf("buf4_copy: rowtot[%d] = %d.\n", h, InBuf->params->rowtot[h]);
+                outfile->Printf("buf4_copy: nbuckets = %d\n", nbuckets);
+                outfile->Printf("buf4_copy: rows_per_bucket = %d\n", rows_per_bucket);
+                outfile->Printf("buf4_copy: rows_left = %d\n", rows_left);
+                outfile->Printf("buf4_copy: out-of-core algorithm used\n");
 #endif
             }
 
-            if(incore) {
-
-
+            if (incore) {
                 buf4_mat_irrep_init(InBuf, h);
                 buf4_mat_irrep_rd(InBuf, h);
 
                 buf4_mat_irrep_init(&OutBuf, h);
 
-                if(rowtot && coltot)
-                    memcpy((void *) &(OutBuf.matrix[h][0][0]),
-                            (const void *) &(InBuf->matrix[h][0][0]),
-                            sizeof(double)*rowtot*coltot);
+                if (rowtot && coltot)
+                    memcpy((void *)&(OutBuf.matrix[h][0][0]), (const void *)&(InBuf->matrix[h][0][0]),
+                           sizeof(double) * rowtot * coltot);
 
                 buf4_mat_irrep_wrt(&OutBuf, h);
 
                 buf4_mat_irrep_close(&OutBuf, h);
                 buf4_mat_irrep_close(InBuf, h);
-            }
-            else {
-
+            } else {
                 buf4_mat_irrep_init_block(InBuf, h, rows_per_bucket);
                 buf4_mat_irrep_init_block(&OutBuf, h, rows_per_bucket);
 
-                coltot = InBuf->params->coltot[h^my_irrep];
-                size = ((long) rows_per_bucket)*((long) coltot);
+                coltot = InBuf->params->coltot[h ^ my_irrep];
+                size = ((long)rows_per_bucket) * ((long)coltot);
 
-                for(n=0; n < (rows_left ? nbuckets-1 : nbuckets); n++) {
+                for (n = 0; n < (rows_left ? nbuckets - 1 : nbuckets); n++) {
+                    buf4_mat_irrep_rd_block(InBuf, h, n * rows_per_bucket, rows_per_bucket);
 
-                    buf4_mat_irrep_rd_block(InBuf, h, n*rows_per_bucket, rows_per_bucket);
+                    memcpy((void *)&(OutBuf.matrix[h][0][0]), (const void *)&(InBuf->matrix[h][0][0]),
+                           ((long)sizeof(double)) * size);
 
-                    memcpy((void *) &(OutBuf.matrix[h][0][0]), (const void *) &(InBuf->matrix[h][0][0]),
-                            ((long) sizeof(double))*size);
-
-                    buf4_mat_irrep_wrt_block(&OutBuf, h, n*rows_per_bucket, rows_per_bucket);
+                    buf4_mat_irrep_wrt_block(&OutBuf, h, n * rows_per_bucket, rows_per_bucket);
                 }
-                if(rows_left) {
+                if (rows_left) {
+                    size = ((long)rows_left) * ((long)coltot);
 
-                    size = ((long) rows_left) * ((long) coltot);
+                    buf4_mat_irrep_rd_block(InBuf, h, n * rows_per_bucket, rows_left);
 
-                    buf4_mat_irrep_rd_block(InBuf, h, n*rows_per_bucket, rows_left);
+                    memcpy((void *)&(OutBuf.matrix[h][0][0]), (const void *)&(InBuf->matrix[h][0][0]),
+                           ((long)sizeof(double)) * size);
 
-                    memcpy((void *) &(OutBuf.matrix[h][0][0]), (const void *) &(InBuf->matrix[h][0][0]),
-                            ((long) sizeof(double))*size);
-
-                    buf4_mat_irrep_wrt_block(&OutBuf, h, n*rows_per_bucket, rows_left);
+                    buf4_mat_irrep_wrt_block(&OutBuf, h, n * rows_per_bucket, rows_left);
                 }
 
                 buf4_mat_irrep_close_block(InBuf, h, rows_per_bucket);
                 buf4_mat_irrep_close_block(&OutBuf, h, rows_per_bucket);
-
             }
         }
-
     }
 
     buf4_close(&OutBuf);
@@ -158,4 +144,4 @@ int DPD::buf4_copy(dpdbuf4 *InBuf, int outfilenum, const char *label)
     return 0;
 }
 
-}
+}  // namespace psi
