@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -48,26 +48,24 @@ namespace psi {
 **
 */
 
-int DPD::buf4_mat_irrep_close_block(dpdbuf4 *Buf, int irrep, int num_pq)
-{
+int DPD::buf4_mat_irrep_close_block(dpdbuf4 *Buf, int irrep, int num_pq) {
     int h, nirreps, all_buf_irrep;
 
     nirreps = Buf->params->nirreps;
     all_buf_irrep = Buf->file.my_irrep;
 
     /* Free the shift structure for this irrep if used */
-    if(Buf->shift.shift_type) {
-        for(h=0; h < nirreps; h++)
-            if(Buf->shift.rowtot[irrep][h])
-                free(Buf->shift.matrix[irrep][h]);
+    if (Buf->shift.shift_type) {
+        for (h = 0; h < nirreps; h++)
+            if (Buf->shift.rowtot[irrep][h]) free(Buf->shift.matrix[irrep][h]);
         free(Buf->shift.matrix[irrep]);
         Buf->shift.shift_type = 0;
     }
 
-    if(num_pq && Buf->params->coltot[irrep^all_buf_irrep])
-        free_dpd_block(Buf->matrix[irrep], num_pq, Buf->params->coltot[irrep^all_buf_irrep]);
+    if (num_pq && Buf->params->coltot[irrep ^ all_buf_irrep])
+        free_dpd_block(Buf->matrix[irrep], num_pq, Buf->params->coltot[irrep ^ all_buf_irrep]);
 
     return 0;
 }
 
-}
+}  // namespace psi
