@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -45,34 +45,30 @@ namespace psi {
 **   int irrep: The irrep number to be prepared.
 */
 
-int DPD::buf4_mat_irrep_init(dpdbuf4 *Buf, int irrep)
-{
+int DPD::buf4_mat_irrep_init(dpdbuf4 *Buf, int irrep) {
     int rowtot, coltot, all_buf_irrep;
     long int size;
 
     all_buf_irrep = Buf->file.my_irrep;
     rowtot = Buf->params->rowtot[irrep];
-    coltot = Buf->params->coltot[irrep^all_buf_irrep];
+    coltot = Buf->params->coltot[irrep ^ all_buf_irrep];
 
-    size = ((long) rowtot) * ((long) coltot);
+    size = ((long)rowtot) * ((long)coltot);
 
 #ifdef DPD_TIMER
     timer_on("buf4_init");
 #endif
 
-    if(size) {
-
+    if (size) {
         /* If the file member is already in cache and its ordering is the
        same as the parent buffer, don't malloc() memory, just assign
        the pointer */
-        if(Buf->file.incore && !(Buf->anti) &&
-                (Buf->params->pqnum == Buf->file.params->pqnum) &&
-                (Buf->params->rsnum == Buf->file.params->rsnum))
+        if (Buf->file.incore && !(Buf->anti) && (Buf->params->pqnum == Buf->file.params->pqnum) &&
+            (Buf->params->rsnum == Buf->file.params->rsnum))
             Buf->matrix[irrep] = Buf->file.matrix[irrep];
         else {
-            Buf->matrix[irrep] = dpd_block_matrix(rowtot,coltot);
+            Buf->matrix[irrep] = dpd_block_matrix(rowtot, coltot);
         }
-
     }
 
 #ifdef DPD_TIMER
@@ -80,7 +76,6 @@ int DPD::buf4_mat_irrep_init(dpdbuf4 *Buf, int irrep)
 #endif
 
     return 0;
-
 }
 
-}
+}  // namespace psi
