@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -37,59 +37,52 @@
 
 namespace psi {
 
-DPD::~DPD()
-{
-    int h,i,j,k,cnt;
+DPD::~DPD() {
+    int h, i, j, k, cnt;
     /*  dpd_file2_cache_print(stdout); */
     file2_cache_close();
     /*  dpd_file4_cache_print(stdout);*/
     file4_cache_close();
 
-    if(params4)
-        for(i=0; i < num_pairs; i++)
-            for(j=0; j < num_pairs; j++)
-                free_int_matrix(params4[i][j].start13);
+    if (params4)
+        for (i = 0; i < num_pairs; i++)
+            for (j = 0; j < num_pairs; j++) free_int_matrix(params4[i][j].start13);
 
-    if(orboff){
-        for(i=0; i < num_subspaces; i++)
-            free(orboff[i]);
+    if (orboff) {
+        for (i = 0; i < num_subspaces; i++) free(orboff[i]);
         free(orboff);
     }
 
-    if(pairidx && pairorb){
-        for(i=0; i < num_subspaces; i++) {
-            for(j=0; j < 5; j++) {
-                free_int_matrix(pairidx[5*i+j]);
-                for(k=0; k < nirreps; k++)
-                    if(pairtot[5*i+j][k])
-                        free_int_matrix(pairorb[5*i+j][k]);
-                free(pairorb[5*i+j]);
+    if (pairidx && pairorb) {
+        for (i = 0; i < num_subspaces; i++) {
+            for (j = 0; j < 5; j++) {
+                free_int_matrix(pairidx[5 * i + j]);
+                for (k = 0; k < nirreps; k++)
+                    if (pairtot[5 * i + j][k]) free_int_matrix(pairorb[5 * i + j][k]);
+                free(pairorb[5 * i + j]);
             }
         }
-        for(i=0,cnt=5*num_subspaces; i < num_subspaces; i++) {
-            for(j=i+1; j < num_subspaces; j++,cnt+=2) {
+        for (i = 0, cnt = 5 * num_subspaces; i < num_subspaces; i++) {
+            for (j = i + 1; j < num_subspaces; j++, cnt += 2) {
                 free_int_matrix(pairidx[cnt]);
-                free_int_matrix(pairidx[cnt+1]);
-                for(k=0; k < nirreps; k++) {
-                    if(pairtot[cnt][k])
-                        free_int_matrix(pairorb[cnt][k]);
-                    if(pairtot[cnt+1][k])
-                        free_int_matrix(pairorb[cnt+1][k]);
+                free_int_matrix(pairidx[cnt + 1]);
+                for (k = 0; k < nirreps; k++) {
+                    if (pairtot[cnt][k]) free_int_matrix(pairorb[cnt][k]);
+                    if (pairtot[cnt + 1][k]) free_int_matrix(pairorb[cnt + 1][k]);
                 }
                 free(pairorb[cnt]);
-                free(pairorb[cnt+1]);
+                free(pairorb[cnt + 1]);
             }
         }
         free(pairidx);
         free(pairorb);
     }
 
-    if(orbs2 && orbidx2){
-        for(i=0; i < num_subspaces; i++) {
+    if (orbs2 && orbidx2) {
+        for (i = 0; i < num_subspaces; i++) {
             free(orbidx2[i]);
-            for(j=0; j < nirreps; j++) {
-                if(orbspi[i][j])
-                    free(orbs2[i][j]);
+            for (j = 0; j < nirreps; j++) {
+                if (orbspi[i][j]) free(orbs2[i][j]);
             }
             free(orbs2[i]);
         }
@@ -97,8 +90,8 @@ DPD::~DPD()
         free(orbs2);
     }
 
-    if(orbspi and orbsym){
-        for(i=0; i < num_subspaces; i++) {
+    if (orbspi && orbsym) {
+        for (i = 0; i < num_subspaces; i++) {
             free(orbspi[i]);
             free(orbsym[i]);
         }
@@ -106,20 +99,16 @@ DPD::~DPD()
         free(orbsym);
     }
 
-    if(pairtot)
-        free_int_matrix(pairtot);
+    if (pairtot) free_int_matrix(pairtot);
 
-    if(numorbs)
-        free(numorbs);
+    if (numorbs) free(numorbs);
 
-    if(params4){
-        for(i=0; i < num_pairs; i++)
-            free(params4[i]);
+    if (params4) {
+        for (i = 0; i < num_pairs; i++) free(params4[i]);
         free(params4);
     }
-    if(params2){
-        for(i=0; i < num_subspaces; i++)
-            free(params2[i]);
+    if (params2) {
+        for (i = 0; i < num_subspaces; i++) free(params2[i]);
         free(params2);
     }
 
@@ -129,4 +118,4 @@ DPD::~DPD()
   */
 }
 
-}
+}  // namespace psi
