@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -39,9 +39,7 @@
 #include "psi4/libpsi4util/PsiOutStream.h"
 namespace psi {
 
-int DPD::contract222(dpdfile2 *X, dpdfile2 *Y, dpdfile2 *Z, int target_X,
-                     int target_Y, double alpha, double beta)
-{
+int DPD::contract222(dpdfile2 *X, dpdfile2 *Y, dpdfile2 *Z, int target_X, int target_Y, double alpha, double beta) {
     int h, nirreps, Xtrans, Ytrans, *numlinks;
     int GX, GY, GZ;
     int Hx, Hy, Hz;
@@ -61,51 +59,76 @@ int DPD::contract222(dpdfile2 *X, dpdfile2 *Y, dpdfile2 *Z, int target_X,
     file2_mat_init(Y);
     file2_mat_rd(Y);
     file2_mat_init(Z);
-    if(std::fabs(beta) > 0.0) file2_mat_rd(Z);
+    if (std::fabs(beta) > 0.0) file2_mat_rd(Z);
 
-    if(target_X == 0) { Xtrans = 0; numlinks = X->params->coltot; symlink = GX; }
-    else if(target_X == 1) { Xtrans = 1; numlinks = X->params->rowtot; symlink = 0; }
-    else {
-        outfile->Printf( "Junk X index %d in contract222\n", target_X);
+    if (target_X == 0) {
+        Xtrans = 0;
+        numlinks = X->params->coltot;
+        symlink = GX;
+    } else if (target_X == 1) {
+        Xtrans = 1;
+        numlinks = X->params->rowtot;
+        symlink = 0;
+    } else {
+        outfile->Printf("Junk X index %d in contract222\n", target_X);
         exit(PSI_RETURN_FAILURE);
     }
-    if(target_Y == 0) Ytrans = 1;
-    else if(target_Y == 1) Ytrans = 0;
+    if (target_Y == 0)
+        Ytrans = 1;
+    else if (target_Y == 1)
+        Ytrans = 0;
     else {
-        outfile->Printf( "Junk Y index %d in contract222\n", target_Y);
+        outfile->Printf("Junk Y index %d in contract222\n", target_Y);
         exit(PSI_RETURN_FAILURE);
     }
 
 #ifdef DPD_DEBUG
-    if(Xtrans) { xrow = X->params->coltot; xcol = X->params->rowtot; }
-    else { xrow = X->params->rowtot; xcol = X->params->coltot; }
+    if (Xtrans) {
+        xrow = X->params->coltot;
+        xcol = X->params->rowtot;
+    } else {
+        xrow = X->params->rowtot;
+        xcol = X->params->coltot;
+    }
 
-    if(Ytrans) { yrow = Y->params->coltot; ycol = Y->params->rowtot; }
-    else { yrow = Y->params->rowtot; ycol = Y->params->coltot; }
+    if (Ytrans) {
+        yrow = Y->params->coltot;
+        ycol = Y->params->rowtot;
+    } else {
+        yrow = Y->params->rowtot;
+        ycol = Y->params->coltot;
+    }
 
-    zrow = Z->params->rowtot; zcol = Z->params->coltot;
+    zrow = Z->params->rowtot;
+    zcol = Z->params->coltot;
 
-    if((zrow != xrow) || (zcol != ycol) || (xcol != yrow)) {
-        outfile->Printf( "** Alignment error in contract222 **\n");
+    if ((zrow != xrow) || (zcol != ycol) || (xcol != yrow)) {
+        outfile->Printf("** Alignment error in contract222 **\n");
         dpd_error("dpd_contract222", "outfile");
     }
 #endif
 
     /* loop over row irreps of X */
-    for(Hx=0; Hx < nirreps; Hx++) {
-        if      ((!Xtrans)&&(!Ytrans)) {Hy = Hx^GX;    Hz = Hx;    }
-        else if ((!Xtrans)&&( Ytrans)) {Hy = Hx^GX^GY; Hz = Hx;    }
-        else if (( Xtrans)&&(!Ytrans)) {Hy = Hx;       Hz = Hx^GX; }
-        else /*(( Xtrans)&&( Ytrans))*/{Hy = Hx^GY;    Hz = Hx^GX; }
+    for (Hx = 0; Hx < nirreps; Hx++) {
+        if ((!Xtrans) && (!Ytrans)) {
+            Hy = Hx ^ GX;
+            Hz = Hx;
+        } else if ((!Xtrans) && (Ytrans)) {
+            Hy = Hx ^ GX ^ GY;
+            Hz = Hx;
+        } else if ((Xtrans) && (!Ytrans)) {
+            Hy = Hx;
+            Hz = Hx ^ GX;
+        } else /*(( Xtrans)&&( Ytrans))*/ {
+            Hy = Hx ^ GY;
+            Hz = Hx ^ GX;
+        }
 
-        if(Z->params->rowtot[Hz] &&
-                Z->params->coltot[Hz^GZ] &&
-                numlinks[Hx^symlink]) {
-            C_DGEMM(Xtrans?'t':'n',Ytrans?'t':'n',Z->params->rowtot[Hz],
-                    Z->params->coltot[Hz^GZ],numlinks[Hx^symlink],alpha,
-                    &(X->matrix[Hx][0][0]),X->params->coltot[Hx^GX],
-                    &(Y->matrix[Hy][0][0]),Y->params->coltot[Hy^GY],beta,
-                    &(Z->matrix[Hz][0][0]),Z->params->coltot[Hz^GZ]);
+        if (Z->params->rowtot[Hz] && Z->params->coltot[Hz ^ GZ] && numlinks[Hx ^ symlink]) {
+            C_DGEMM(Xtrans ? 't' : 'n', Ytrans ? 't' : 'n', Z->params->rowtot[Hz], Z->params->coltot[Hz ^ GZ],
+                    numlinks[Hx ^ symlink], alpha, &(X->matrix[Hx][0][0]), X->params->coltot[Hx ^ GX],
+                    &(Y->matrix[Hy][0][0]), Y->params->coltot[Hy ^ GY], beta, &(Z->matrix[Hz][0][0]),
+                    Z->params->coltot[Hz ^ GZ]);
         }
         /*
     newmm(X->matrix[Hx], Xtrans, Y->matrix[Hy], Ytrans, Z->matrix[Hz],
@@ -122,4 +145,4 @@ int DPD::contract222(dpdfile2 *X, dpdfile2 *Y, dpdfile2 *Z, int target_X,
     return 0;
 }
 
-}
+}  // namespace psi
