@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,21 +36,18 @@
 
 namespace psi {
 
-int DPD::file4_mat_irrep_row_zero(dpdfile4 *File, int irrep, int row)
-{
+int DPD::file4_mat_irrep_row_zero(dpdfile4 *File, int irrep, int row) {
     int coltot, my_irrep;
 
-    if(File->incore) return 0;  /* Don't do this if the file is in core */
+    if (File->incore) return 0; /* Don't do this if the file is in core */
 
     my_irrep = File->my_irrep;
 
-    coltot = File->params->coltot[irrep^my_irrep];
+    coltot = File->params->coltot[irrep ^ my_irrep];
 
-    if(coltot)
-        zero_arr(File->matrix[irrep][0], coltot);
+    if (coltot) zero_arr(File->matrix[irrep][0], coltot);
 
     return 0;
-
 }
 
-}
+}  // namespace psi
