@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -37,30 +37,27 @@
 
 namespace psi {
 
-int DPD::trans4_mat_irrep_close(dpdtrans4 *Trans, int irrep)
-{
+int DPD::trans4_mat_irrep_close(dpdtrans4 *Trans, int irrep) {
     int h, nirreps, rowtot, coltot, all_buf_irrep;
     long int size;
 
     all_buf_irrep = Trans->buf.file.my_irrep;
     nirreps = Trans->buf.params->nirreps;
-    rowtot = Trans->buf.params->coltot[irrep^all_buf_irrep];
+    rowtot = Trans->buf.params->coltot[irrep ^ all_buf_irrep];
     coltot = Trans->buf.params->rowtot[irrep];
-    size = ((long) rowtot) * ((long) coltot);
+    size = ((long)rowtot) * ((long)coltot);
 
     /* Free the shift structure for this irrep if used */
-    if(Trans->shift.shift_type) {
-        for(h=0; h < nirreps; h++)
-            if(Trans->shift.rowtot[irrep][h])
-                free(Trans->shift.matrix[irrep][h]);
+    if (Trans->shift.shift_type) {
+        for (h = 0; h < nirreps; h++)
+            if (Trans->shift.rowtot[irrep][h]) free(Trans->shift.matrix[irrep][h]);
         free(Trans->shift.matrix[irrep]);
         Trans->shift.shift_type = 0;
     }
 
-    if(size)
-        free_dpd_block(Trans->matrix[irrep], rowtot, coltot);
+    if (size) free_dpd_block(Trans->matrix[irrep], rowtot, coltot);
 
     return 0;
 }
 
-}
+}  // namespace psi
