@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -35,34 +35,29 @@
 #include "psi4/libpsio/psio.h"
 #include "iwl.h"
 #include "iwl.hpp"
-#include "psi4/psi4-dec.h" //need outfile
+#include "psi4/psi4-dec.h"  //need outfile
 #include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/libpsi4util/process.h"
 
 namespace psi {
 
-IWL::IWL()
-{
+IWL::IWL() {
     /*! set up buffer info */
     itap_ = -1;
     bufpos_ = PSIO_ZERO;
     ints_per_buf_ = IWL_INTS_PER_BUF;
     cutoff_ = 1.e-14;
-    bufszc_ = 2 * sizeof(int) + ints_per_buf_ * 4 * sizeof(Label) +
-        ints_per_buf_ * sizeof(Value);
+    bufszc_ = 2 * sizeof(int) + ints_per_buf_ * 4 * sizeof(Label) + ints_per_buf_ * sizeof(Value);
     lastbuf_ = 0;
     inbuf_ = 0;
     idx_ = 0;
 }
 
-IWL::IWL(PSIO *psio, int it, double coff, int oldfile, int readflag):
-    keep_(true)
-{
+IWL::IWL(PSIO *psio, int it, double coff, int oldfile, int readflag) : keep_(true) {
     init(psio, it, coff, oldfile, readflag);
 }
 
-void IWL::init(PSIO *psio, int it, double coff, int oldfile, int readflag)
-{
+void IWL::init(PSIO *psio, int it, double coff, int oldfile, int readflag) {
     psio_ = psio;
 
     /*! set up buffer info */
@@ -70,8 +65,7 @@ void IWL::init(PSIO *psio, int it, double coff, int oldfile, int readflag)
     bufpos_ = PSIO_ZERO;
     ints_per_buf_ = IWL_INTS_PER_BUF;
     cutoff_ = coff;
-    bufszc_ = 2 * sizeof(int) + ints_per_buf_ * 4 * sizeof(Label) +
-        ints_per_buf_ * sizeof(Value);
+    bufszc_ = 2 * sizeof(int) + ints_per_buf_ * 4 * sizeof(Label) + ints_per_buf_ * sizeof(Value);
     lastbuf_ = 0;
     inbuf_ = 0;
     idx_ = 0;
@@ -87,7 +81,7 @@ void IWL::init(PSIO *psio, int it, double coff, int oldfile, int readflag)
     psio_->open(itap_, oldfile ? PSIO_OPEN_OLD : PSIO_OPEN_NEW);
     if (oldfile && (psio_->tocscan(itap_, IWL_KEY_BUF) == nullptr)) {
         outfile->Printf("iwl_buf_init: Can't open file %d\n", itap_);
-        psio_->close(itap_,0);
+        psio_->close(itap_, 0);
         return;
     }
 
@@ -113,37 +107,31 @@ void IWL::init(PSIO *psio, int it, double coff, int oldfile, int readflag)
 ** Revised 6/26/96 by CDS for new format
 ** \ingroup IWL
 */
-void PSI_API iwl_buf_init(struct iwlbuf *Buf, int itape, double cutoff,
-      int oldfile, int readflag)
-{
+void PSI_API iwl_buf_init(struct iwlbuf *Buf, int itape, double cutoff, int oldfile, int readflag) {
+    /*! set up buffer info */
+    Buf->itap = itape;
+    Buf->bufpos = PSIO_ZERO;
+    Buf->ints_per_buf = IWL_INTS_PER_BUF;
+    Buf->cutoff = cutoff;
+    Buf->bufszc = 2 * sizeof(int) + Buf->ints_per_buf * 4 * sizeof(Label) + Buf->ints_per_buf * sizeof(Value);
+    Buf->lastbuf = 0;
+    Buf->inbuf = 0;
+    Buf->idx = 0;
 
-  /*! set up buffer info */
-  Buf->itap = itape;
-  Buf->bufpos = PSIO_ZERO;
-  Buf->ints_per_buf = IWL_INTS_PER_BUF;
-  Buf->cutoff = cutoff;
-  Buf->bufszc = 2 * sizeof(int) + Buf->ints_per_buf * 4 * sizeof(Label) +
-    Buf->ints_per_buf * sizeof(Value);
-  Buf->lastbuf = 0;
-  Buf->inbuf = 0;
-  Buf->idx = 0;
+    /*! make room in the buffer */
+    Buf->labels = (Label *)malloc(4 * Buf->ints_per_buf * sizeof(Label));
+    Buf->values = (Value *)malloc(Buf->ints_per_buf * sizeof(Value));
 
-  /*! make room in the buffer */
-  Buf->labels = (Label *) malloc (4 * Buf->ints_per_buf * sizeof(Label));
-  Buf->values = (Value *) malloc (Buf->ints_per_buf * sizeof(Value));
-
-  /*! open the output file */
-  /*! Note that we assume that if oldfile isn't set, we O_CREAT the file */
-  psio_open(Buf->itap, oldfile ? PSIO_OPEN_OLD : PSIO_OPEN_NEW);
-  if (oldfile && (psio_tocscan(Buf->itap, IWL_KEY_BUF) == nullptr)) {
-    outfile->Printf("iwl_buf_init: Can't open file %d\n", Buf->itap);
-    psio_close(Buf->itap,0);
-    return;
-  }
-
-  /*! go ahead and read a buffer */
-  if (readflag) iwl_buf_fetch(Buf);
+    /*! open the output file */
+    /*! Note that we assume that if oldfile isn't set, we O_CREAT the file */
+    psio_open(Buf->itap, oldfile ? PSIO_OPEN_OLD : PSIO_OPEN_NEW);
+    if (oldfile && (psio_tocscan(Buf->itap, IWL_KEY_BUF) == nullptr)) {
+        outfile->Printf("iwl_buf_init: Can't open file %d\n", Buf->itap);
+        psio_close(Buf->itap, 0);
+        return;
+    }
 
+    /*! go ahead and read a buffer */
+    if (readflag) iwl_buf_fetch(Buf);
 }
-
 }
