@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -41,30 +41,25 @@
 using namespace psi;
 
 // Initialize potential_recur_ to +1 basis set angular momentum
-ElectrostaticInt::ElectrostaticInt(std::vector<SphericalTransform>& st, std::shared_ptr<BasisSet> bs1, std::shared_ptr<BasisSet> bs2, int deriv) :
-    PotentialInt(st, bs1, bs2, deriv)
-{
-}
+ElectrostaticInt::ElectrostaticInt(std::vector<SphericalTransform>& st, std::shared_ptr<BasisSet> bs1,
+                                   std::shared_ptr<BasisSet> bs2, int deriv)
+    : PotentialInt(st, bs1, bs2, deriv) {}
 
-ElectrostaticInt::~ElectrostaticInt()
-{
+ElectrostaticInt::~ElectrostaticInt() {}
 
-}
-
-void ElectrostaticInt::compute(SharedMatrix &result, const Vector3& C)
-{
+void ElectrostaticInt::compute(SharedMatrix& result, const Vector3& C) {
     // Do not worry about zeroing out result
     int ns1 = bs1_->nshell();
     int ns2 = bs2_->nshell();
 
-    int i_offset=0;
-    double *location;
+    int i_offset = 0;
+    double* location;
 
     // Leave as this full double for loop. We could be computing nonsymmetric integrals
-    for (int i=0; i<ns1; ++i) {
+    for (int i = 0; i < ns1; ++i) {
         int ni = force_cartesian_ ? bs1_->shell(i).ncartesian() : bs1_->shell(i).nfunction();
-        int j_offset=0;
-        for (int j=0; j<ns2; ++j) {
+        int j_offset = 0;
+        for (int j = 0; j < ns2; ++j) {
             int nj = force_cartesian_ ? bs2_->shell(j).ncartesian() : bs2_->shell(j).nfunction();
 
             // Compute the shell (automatically transforms to pure am in needed)
@@ -72,9 +67,9 @@ void ElectrostaticInt::compute(SharedMatrix &result, const Vector3& C)
 
             // For each integral that we got put in its contribution
             location = buffer_;
-            for (int p=0; p<ni; ++p) {
-                for (int q=0; q<nj; ++q) {
-                    result->add(0, i_offset+p, j_offset+q, *location);
+            for (int p = 0; p < ni; ++p) {
+                for (int q = 0; q < nj; ++q) {
+                    result->add(0, i_offset + p, j_offset + q, *location);
                     location++;
                 }
             }
@@ -85,8 +80,7 @@ void ElectrostaticInt::compute(SharedMatrix &result, const Vector3& C)
     }
 }
 
-void ElectrostaticInt::compute_shell(int sh1, int sh2, const Vector3& C)
-{
+void ElectrostaticInt::compute_shell(int sh1, int sh2, const Vector3& C) {
     const GaussianShell& s1 = bs1_->shell(sh1);
     const GaussianShell& s2 = bs2_->shell(sh2);
 
@@ -95,15 +89,14 @@ void ElectrostaticInt::compute_shell(int sh1, int sh2, const Vector3& C)
 
     // Normalize for angular momentum
     normalize_am(s1, s2, nchunk_);
-    if(!force_cartesian_){
+    if (!force_cartesian_) {
         // Pure angular momentum (6d->5d, ...) transformation
         pure_transform(s1, s2, nchunk_);
     }
 }
 
 // The engine only supports segmented basis sets
-void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell& s2, const Vector3& C)
-{
+void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell& s2, const Vector3& C) {
     int ao12;
     int am1 = s1.am();
     int am2 = s2.am();
@@ -132,23 +125,23 @@ void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell
 
     memset(buffer_, 0, s1.ncartesian() * s2.ncartesian() * sizeof(double));
 
-    double ***vi = potential_recur_->vi();
+    double*** vi = potential_recur_->vi();
 
-    for (int p1=0; p1<nprim1; ++p1) {
+    for (int p1 = 0; p1 < nprim1; ++p1) {
         double a1 = s1.exp(p1);
         double c1 = s1.coef(p1);
-        for (int p2=0; p2<nprim2; ++p2) {
+        for (int p2 = 0; p2 < nprim2; ++p2) {
             double a2 = s2.exp(p2);
             double c2 = s2.coef(p2);
             double gamma = a1 + a2;
-            double oog = 1.0/gamma;
+            double oog = 1.0 / gamma;
 
             double PA[3], PB[3];
             double P[3];
 
-            P[0] = (a1*A[0] + a2*B[0])*oog;
-            P[1] = (a1*A[1] + a2*B[1])*oog;
-            P[2] = (a1*A[2] + a2*B[2])*oog;
+            P[0] = (a1 * A[0] + a2 * B[0]) * oog;
+            P[1] = (a1 * A[1] + a2 * B[1]) * oog;
+            P[2] = (a1 * A[2] + a2 * B[2]) * oog;
             PA[0] = P[0] - A[0];
             PA[1] = P[1] - A[1];
             PA[2] = P[2] - A[2];
@@ -156,7 +149,7 @@ void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell
             PB[1] = P[1] - B[1];
             PB[2] = P[2] - B[2];
 
-            double over_pf = exp(-a1*a2*AB2*oog) * sqrt(M_PI*oog) * M_PI * oog * c1 * c2;
+            double over_pf = exp(-a1 * a2 * AB2 * oog) * sqrt(M_PI * oog) * M_PI * oog * c1 * c2;
 
             // Loop over atoms of basis set 1 (only works if bs1_ and bs2_ are on the same
             // molecule)
@@ -170,15 +163,15 @@ void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell
             potential_recur_->compute(PA, PB, PC, gamma, am1, am2);
 
             ao12 = 0;
-            for(int ii = 0; ii <= am1; ii++) {
+            for (int ii = 0; ii <= am1; ii++) {
                 int l1 = am1 - ii;
-                for(int jj = 0; jj <= ii; jj++) {
+                for (int jj = 0; jj <= ii; jj++) {
                     int m1 = ii - jj;
                     int n1 = jj;
                     /*--- create all am components of sj ---*/
-                    for(int kk = 0; kk <= am2; kk++) {
+                    for (int kk = 0; kk <= am2; kk++) {
                         int l2 = am2 - kk;
-                        for(int ll = 0; ll <= kk; ll++) {
+                        for (int ll = 0; ll <= kk; ll++) {
                             int m2 = kk - ll;
                             int n2 = ll;
 
@@ -195,24 +188,23 @@ void ElectrostaticInt::compute_pair(const GaussianShell& s1, const GaussianShell
     }
 }
 
-SharedVector ElectrostaticInt::nuclear_contribution(std::shared_ptr<Molecule> mol)
-{
+SharedVector ElectrostaticInt::nuclear_contribution(std::shared_ptr<Molecule> mol) {
     auto sret = std::make_shared<Vector>(mol->natom());
-    double *ret = sret->pointer();
+    double* ret = sret->pointer();
 
     int natom = mol->natom();
-    for(int k=0;k<natom;k++) {
+    for (int k = 0; k < natom; k++) {
         Vector3 kgeom = mol->xyz(k);
-        for(int i=0;i<natom;i++) {
+        for (int i = 0; i < natom; i++) {
             if (i != k) {
                 Vector3 igeom = mol->xyz(i);
 
                 double x = kgeom[0] - igeom[0];
                 double y = kgeom[1] - igeom[1];
                 double z = kgeom[2] - igeom[2];
-                double r2 = x*x+y*y+z*z;
+                double r2 = x * x + y * y + z * z;
                 double r = std::sqrt(r2);
-                ret[k]  += mol->Z(i)/r;
+                ret[k] += mol->Z(i) / r;
             }
         }
     }
