@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,21 +29,20 @@
 #ifndef _psi_src_lib_libmints_kinetic_h_
 #define _psi_src_lib_libmints_kinetic_h_
 
- #include "psi4/pragma.h"
- PRAGMA_WARNING_PUSH
- PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
- #include <memory>
- PRAGMA_WARNING_POP
+#include "psi4/pragma.h"
+PRAGMA_WARNING_PUSH
+PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
+#include <memory>
+PRAGMA_WARNING_POP
 #include <vector>
 #include "psi4/libmints/osrecur.h"
 #include "psi4/libmints/onebody.h"
 
-
 namespace psi {
 
-    class BasisSet;
-    class GaussianShell;
-    class SphericalTransform;
+class BasisSet;
+class GaussianShell;
+class SphericalTransform;
 
 /*! \ingroup MINTS
  *  \class KineticInt
@@ -51,30 +50,29 @@ namespace psi {
  *
  * Use an IntegralFactory to create this object.
  */
-class KineticInt : public OneBodyAOInt
-{
+class KineticInt : public OneBodyAOInt {
     //! Obara and Saika recursion object to be used.
     ObaraSaikaTwoCenterRecursion overlap_recur_;
 
     //! Computes the kinetic integral between two gaussian shells.
-    void compute_pair(const GaussianShell&, const GaussianShell&);
+    void compute_pair(const GaussianShell&, const GaussianShell&) override;
     //! Computes the kinetic derivatve between two gaussian shells.
-    void compute_pair_deriv1(const GaussianShell&, const GaussianShell&);
-    void compute_pair_deriv2(const GaussianShell&, const GaussianShell&);
+    void compute_pair_deriv1(const GaussianShell&, const GaussianShell&) override;
+    void compute_pair_deriv2(const GaussianShell&, const GaussianShell&) override;
 
-public:
+   public:
     //! Constructor. Do not call directly, use an IntegralFactory.
-    KineticInt(std::vector<SphericalTransform>&, std::shared_ptr<BasisSet>, std::shared_ptr<BasisSet>, int deriv=0);
+    KineticInt(std::vector<SphericalTransform>&, std::shared_ptr<BasisSet>, std::shared_ptr<BasisSet>, int deriv = 0);
     //! Virtual destructor.
-    virtual ~KineticInt();
+    ~KineticInt() override;
 
     /// Does the method provide first derivatives?
-    bool has_deriv1() { return true; }
+    bool has_deriv1() override { return true; }
 
     /// Does the method provide first derivatives?
-    bool has_deriv2() { return true; }
+    bool has_deriv2() override { return true; }
 };
 
-}
+}  // namespace psi
 
 #endif
