@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -45,9 +45,9 @@ class ThreeCenterOverlapInt;
 class OneBodyAOInt;
 
 /**
-* The MintsHelper object, places molecular integrals
-* (and later derivative integrals) on disk
-**/
+ * The MintsHelper object, places molecular integrals
+ * (and later derivative integrals) on disk
+ **/
 class PSI_API MintsHelper {
    private:
     /// The Options reference for basis sets and things
@@ -144,23 +144,22 @@ class PSI_API MintsHelper {
     SharedMatrix ao_eri_shell(int M, int N, int P, int Q);
 
     // Derivatives of OEI in AO and MO basis
-    std::vector<SharedMatrix> ao_oei_deriv1(const std::string & oei_type, int atom);
-    std::vector<SharedMatrix> ao_oei_deriv2(const std::string & oei_type, int atom1, int atom2);
-    std::vector<SharedMatrix> ao_overlap_kinetic_deriv1_helper(const std::string & type, int atom);
+    std::vector<SharedMatrix> ao_oei_deriv1(const std::string& oei_type, int atom);
+    std::vector<SharedMatrix> ao_oei_deriv2(const std::string& oei_type, int atom1, int atom2);
+    std::vector<SharedMatrix> ao_overlap_kinetic_deriv1_helper(const std::string& type, int atom);
     std::vector<SharedMatrix> ao_potential_deriv1_helper(int atom);
-    std::vector<SharedMatrix> ao_overlap_kinetic_deriv2_helper(const std::string & type, int atom1, int atom2);
+    std::vector<SharedMatrix> ao_overlap_kinetic_deriv2_helper(const std::string& type, int atom1, int atom2);
     std::vector<SharedMatrix> ao_potential_deriv2_helper(int atom1, int atom2);
-    std::vector<SharedMatrix> mo_oei_deriv1(const std::string & oei_type, int atom,
-                                             SharedMatrix C1, SharedMatrix C2);
-    std::vector<SharedMatrix> mo_oei_deriv2(const std::string & oei_type, int atom1,
-                                             int atom2, SharedMatrix C1, SharedMatrix C2);
+    std::vector<SharedMatrix> mo_oei_deriv1(const std::string& oei_type, int atom, SharedMatrix C1, SharedMatrix C2);
+    std::vector<SharedMatrix> mo_oei_deriv2(const std::string& oei_type, int atom1, int atom2, SharedMatrix C1,
+                                            SharedMatrix C2);
     // Derivatives of TEI in AO and MO basis
-    std::vector<SharedMatrix>  ao_tei_deriv1(int atom, double omega = 0.0, std::shared_ptr<IntegralFactory> = nullptr);
-    std::vector<SharedMatrix>  ao_tei_deriv2(int atom1, int atom2);
-    std::vector<SharedMatrix>  mo_tei_deriv1(int atom, SharedMatrix C1, SharedMatrix C2,
-                                             SharedMatrix C3, SharedMatrix C4);
-    std::vector<SharedMatrix>  mo_tei_deriv2(int atom1, int atom2, SharedMatrix C1, SharedMatrix C2,
-                                             SharedMatrix C3, SharedMatrix C4);
+    std::vector<SharedMatrix> ao_tei_deriv1(int atom, double omega = 0.0, std::shared_ptr<IntegralFactory> = nullptr);
+    std::vector<SharedMatrix> ao_tei_deriv2(int atom1, int atom2);
+    std::vector<SharedMatrix> mo_tei_deriv1(int atom, SharedMatrix C1, SharedMatrix C2, SharedMatrix C3,
+                                            SharedMatrix C4);
+    std::vector<SharedMatrix> mo_tei_deriv2(int atom1, int atom2, SharedMatrix C1, SharedMatrix C2, SharedMatrix C3,
+                                            SharedMatrix C4);
 
     /// AO ERF Integrals
     SharedMatrix ao_erf_eri(double omega, std::shared_ptr<IntegralFactory> = nullptr);
@@ -287,12 +286,12 @@ class PSI_API MintsHelper {
 
     SharedMatrix kinetic_grad(SharedMatrix D);
     SharedMatrix potential_grad(SharedMatrix D);
+    SharedMatrix dipole_grad(SharedMatrix D);
     SharedMatrix perturb_grad(SharedMatrix D);
-    SharedMatrix perturb_grad(SharedMatrix D, double xlambda, double ylambda, double zlambda);
 
     /// Play function
     void play();
 };
-}
+}  // namespace psi
 
 #endif
