@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -29,14 +29,15 @@
 #ifndef _psi_src_lib_libmints_osrecur_h
 #define _psi_src_lib_libmints_osrecur_h
 
+#include "psi4/pragma.h"
+
 namespace psi {
 
 /*! \ingroup MINTS
  *  \class ObaraSaikaTwoCenterRecursion
  *  \brief Generic Obara and Saika recursion object.
  */
-class ObaraSaikaTwoCenterRecursion
-{
+class ObaraSaikaTwoCenterRecursion {
     int max_am1_;
     int max_am2_;
 
@@ -47,9 +48,9 @@ class ObaraSaikaTwoCenterRecursion
     // No default constructor
     ObaraSaikaTwoCenterRecursion();
     // No assignment operator
-    ObaraSaikaTwoCenterRecursion& operator=(const ObaraSaikaTwoCenterRecursion&);
+    ObaraSaikaTwoCenterRecursion &operator=(const ObaraSaikaTwoCenterRecursion &);
 
-public:
+   public:
     /// Constructor, max_am1 and max_am2 are the max angular momentum on center 1 and 2.
     /// Needed to allocate enough memory.
     ObaraSaikaTwoCenterRecursion(int max_am1, int max_am2);
@@ -71,8 +72,7 @@ public:
  *  \brief Obara and Saika recursion object for moment integrals. Currently not used by DipoleInt, hopefully soon.
  *  THIS CLASS HAS NOT BEEN TESTED!!!
  */
-class ObaraSaikaTwoCenterMIRecursion
-{
+class ObaraSaikaTwoCenterMIRecursion {
     int max_am1_;
     int max_am2_;
     int max_m_;
@@ -84,9 +84,9 @@ class ObaraSaikaTwoCenterMIRecursion
     // No default constructor
     ObaraSaikaTwoCenterMIRecursion();
     // No assignment operator
-    ObaraSaikaTwoCenterMIRecursion& operator=(const ObaraSaikaTwoCenterMIRecursion&);
+    ObaraSaikaTwoCenterMIRecursion &operator=(const ObaraSaikaTwoCenterMIRecursion &);
 
-public:
+   public:
     ObaraSaikaTwoCenterMIRecursion(int max_am1, int max_am2, int max_m);
     ~ObaraSaikaTwoCenterMIRecursion();
 
@@ -100,9 +100,8 @@ public:
  *  \class ObaraSaikaTwoCenterVIRecursion
  *  \brief Obara and Saika recursion object for potential integrals.
  */
-class ObaraSaikaTwoCenterVIRecursion
-{
-protected:
+class ObaraSaikaTwoCenterVIRecursion {
+   protected:
     int max_am1_;
     int max_am2_;
     int size_;
@@ -112,13 +111,13 @@ protected:
     // Forms Fm(U) from A20 (OS 1986)
     void calculate_f(double *F, int n, double t);
 
-private:
+   private:
     // No default constructor
     ObaraSaikaTwoCenterVIRecursion();
     // No assignment operator
-    ObaraSaikaTwoCenterVIRecursion& operator=(const ObaraSaikaTwoCenterVIRecursion&);
+    ObaraSaikaTwoCenterVIRecursion &operator=(const ObaraSaikaTwoCenterVIRecursion &);
 
-public:
+   public:
     /// Constructor, max_am1 and max_am2 are the max angular momentum on center 1 and 2.
     /// Needed to allocate enough memory.
     ObaraSaikaTwoCenterVIRecursion(int max_am1, int max_am2);
@@ -127,16 +126,16 @@ public:
     /// Returns the potential integral 3D matrix
     double ***vi() const { return vi_; }
 
-    virtual double ***vx() const { return 0; }
-    virtual double ***vy() const { return 0; }
-    virtual double ***vz() const { return 0; }
+    virtual double ***vx() const { return nullptr; }
+    virtual double ***vy() const { return nullptr; }
+    virtual double ***vz() const { return nullptr; }
 
-    virtual double ***vxx() const { return 0; }
-    virtual double ***vxy() const { return 0; }
-    virtual double ***vxz() const { return 0; }
-    virtual double ***vyy() const { return 0; }
-    virtual double ***vyz() const { return 0; }
-    virtual double ***vzz() const { return 0; }
+    virtual double ***vxx() const { return nullptr; }
+    virtual double ***vxy() const { return nullptr; }
+    virtual double ***vxz() const { return nullptr; }
+    virtual double ***vyy() const { return nullptr; }
+    virtual double ***vyz() const { return nullptr; }
+    virtual double ***vzz() const { return nullptr; }
 
     /// Computes the potential integral 3D matrix using the data provided.
     virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
@@ -148,37 +147,35 @@ public:
  *  \class ObaraSaikaTwoCenterVIDerivRecursion
  *  \brief Obara and Saika recursion object for computing potential derivatives.
  */
-class ObaraSaikaTwoCenterVIDerivRecursion : public ObaraSaikaTwoCenterVIRecursion
-{
-protected:
+class ObaraSaikaTwoCenterVIDerivRecursion : public ObaraSaikaTwoCenterVIRecursion {
+   protected:
     double ***vx_;
     double ***vy_;
     double ***vz_;
 
-private:
+   private:
     // No default constructor();
     ObaraSaikaTwoCenterVIDerivRecursion();
     // No assignment operator
-    ObaraSaikaTwoCenterVIDerivRecursion& operator=(const ObaraSaikaTwoCenterVIDerivRecursion&);
+    ObaraSaikaTwoCenterVIDerivRecursion &operator=(const ObaraSaikaTwoCenterVIDerivRecursion &);
 
-public:
+   public:
     ObaraSaikaTwoCenterVIDerivRecursion(int max_am1, int max_am2);
-    virtual ~ObaraSaikaTwoCenterVIDerivRecursion();
+    ~ObaraSaikaTwoCenterVIDerivRecursion() override;
 
-    double ***vx() const { return vx_; }
-    double ***vy() const { return vy_; }
-    double ***vz() const { return vz_; }
+    double ***vx() const override { return vx_; }
+    double ***vy() const override { return vy_; }
+    double ***vz() const override { return vz_; }
 
-    virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
+    void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2) override;
 };
 
 /*! \ingroup MINTS
  *  \class ObaraSaikaTwoCenterVIDerivRecursion
  *  \brief Obara and Saika recursion object for computing potential derivatives.
  */
-class ObaraSaikaTwoCenterVIDeriv2Recursion : public ObaraSaikaTwoCenterVIDerivRecursion
-{
-protected:
+class ObaraSaikaTwoCenterVIDeriv2Recursion : public ObaraSaikaTwoCenterVIDerivRecursion {
+   protected:
     double ***vxx_;
     double ***vxy_;
     double ***vxz_;
@@ -186,63 +183,61 @@ protected:
     double ***vyz_;
     double ***vzz_;
 
-private:
+   private:
     // No default constructor();
     ObaraSaikaTwoCenterVIDeriv2Recursion();
     // No assignment operator
-    ObaraSaikaTwoCenterVIDeriv2Recursion& operator=(const ObaraSaikaTwoCenterVIDeriv2Recursion&);
+    ObaraSaikaTwoCenterVIDeriv2Recursion &operator=(const ObaraSaikaTwoCenterVIDeriv2Recursion &);
 
-public:
+   public:
     ObaraSaikaTwoCenterVIDeriv2Recursion(int max_am1, int max_am2);
-    virtual ~ObaraSaikaTwoCenterVIDeriv2Recursion();
+    ~ObaraSaikaTwoCenterVIDeriv2Recursion() override;
 
-    double ***vxx() const { return vxx_; }
-    double ***vxy() const { return vxy_; }
-    double ***vxz() const { return vxz_; }
-    double ***vyy() const { return vyy_; }
-    double ***vyz() const { return vyz_; }
-    double ***vzz() const { return vzz_; }
+    double ***vxx() const override { return vxx_; }
+    double ***vxy() const override { return vxy_; }
+    double ***vxz() const override { return vxz_; }
+    double ***vyy() const override { return vyy_; }
+    double ***vyz() const override { return vyz_; }
+    double ***vzz() const override { return vzz_; }
 
-    virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
+    void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2) override;
 };
 
 /*! \ingroup MINTS
  *  \class ObaraSaikaTwoCenterElectricField
  *  \brief Obara and Saika recursion object for computing electric field integrals.
  */
-class ObaraSaikaTwoCenterElectricField : public ObaraSaikaTwoCenterVIRecursion
-{
-protected:
+class ObaraSaikaTwoCenterElectricField : public ObaraSaikaTwoCenterVIRecursion {
+   protected:
     double ***q_;
     double ***x_;
     double ***y_;
     double ***z_;
 
-private:
+   private:
     // No default constructor
     ObaraSaikaTwoCenterElectricField();
     // No assignment operator
-    ObaraSaikaTwoCenterElectricField& operator=(const ObaraSaikaTwoCenterElectricField&);
+    ObaraSaikaTwoCenterElectricField &operator=(const ObaraSaikaTwoCenterElectricField &);
 
-public:
+   public:
     ObaraSaikaTwoCenterElectricField(int max_am1, int max_am2);
-    virtual ~ObaraSaikaTwoCenterElectricField();
+    ~ObaraSaikaTwoCenterElectricField() override;
 
     // We could also add the getter for the q_ (potential ints here)
     double ***x() const { return x_; }
     double ***y() const { return y_; }
     double ***z() const { return z_; }
 
-    virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
+    void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2) override;
 };
 
 /*! \ingroup MINTS
  *  \class ObaraSaikaTwoCenterElectricFieldGradient
  *  \brief Obara and Saika recursion object for computing electric field gradient integrals.
  */
-class ObaraSaikaTwoCenterElectricFieldGradient : public ObaraSaikaTwoCenterElectricField
-{
-protected:
+class ObaraSaikaTwoCenterElectricFieldGradient : public ObaraSaikaTwoCenterElectricField {
+   protected:
     double ***exx_;
     double ***eyy_;
     double ***ezz_;
@@ -250,104 +245,99 @@ protected:
     double ***exz_;
     double ***eyz_;
 
-private:
+   private:
     // No default constructor
     ObaraSaikaTwoCenterElectricFieldGradient();
     // No assignment operator
-    ObaraSaikaTwoCenterElectricFieldGradient& operator=(const ObaraSaikaTwoCenterElectricFieldGradient&);
+    ObaraSaikaTwoCenterElectricFieldGradient &operator=(const ObaraSaikaTwoCenterElectricFieldGradient &);
 
-public:
+   public:
     ObaraSaikaTwoCenterElectricFieldGradient(int max_am1, int max_am2);
-    virtual ~ObaraSaikaTwoCenterElectricFieldGradient();
+    ~ObaraSaikaTwoCenterElectricFieldGradient() override;
 
     double ***ex() const { return x_; }
     double ***ey() const { return y_; }
     double ***ez() const { return z_; }
 
-    virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
+    void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2) override;
 };
 
-
 /*! \ingroup MINTS
  *  \class ObaraSaikaTwoCenterEFPRecursion
  *  \brief Obara and Saika recursion object for potential integrals, and electric derivatives thereof, required in EFP.
  */
-class ObaraSaikaTwoCenterEFPRecursion
-{
-protected:
+class ObaraSaikaTwoCenterEFPRecursion {
+   protected:
     int max_am1_;
     int max_am2_;
     int size_;
 
-    double*** q_;
-    double*** x_;
-    double*** y_;
-    double*** z_;
-    double*** xx_;
-    double*** xy_;
-    double*** xz_;
-    double*** yy_;
-    double*** yz_;
-    double*** zz_;
-    double*** xxx_;
-    double*** xxy_;
-    double*** xxz_;
-    double*** xyy_;
-    double*** xyz_;
-    double*** xzz_;
-    double*** yyy_;
-    double*** yyz_;
-    double*** yzz_;
-    double*** zzz_;
+    double ***q_;
+    double ***x_;
+    double ***y_;
+    double ***z_;
+    double ***xx_;
+    double ***xy_;
+    double ***xz_;
+    double ***yy_;
+    double ***yz_;
+    double ***zz_;
+    double ***xxx_;
+    double ***xxy_;
+    double ***xxz_;
+    double ***xyy_;
+    double ***xyz_;
+    double ***xzz_;
+    double ***yyy_;
+    double ***yyz_;
+    double ***yzz_;
+    double ***zzz_;
 
     // Forms Fm(U) from A20 (OS 1986)
     void calculate_f(double *F, int n, double t);
 
-private:
+   private:
     // No default constructor
     ObaraSaikaTwoCenterEFPRecursion();
     // No assignment operator
-    ObaraSaikaTwoCenterEFPRecursion& operator=(const ObaraSaikaTwoCenterEFPRecursion&);
+    ObaraSaikaTwoCenterEFPRecursion &operator=(const ObaraSaikaTwoCenterEFPRecursion &);
 
-public:
+   public:
     /// Constructor, max_am1 and max_am2 are the max angular momentum on center 1 and 2.
     /// Needed to allocate enough memory.
     ObaraSaikaTwoCenterEFPRecursion(int max_am1, int max_am2);
     virtual ~ObaraSaikaTwoCenterEFPRecursion();
 
     /// Returns the potential integral 3D matrix
-    double*** q  () const { return q_;   }
-    double*** x  () const { return x_;   }
-    double*** y  () const { return y_;   }
-    double*** z  () const { return z_;   }
-    double*** xx () const { return xx_;  }
-    double*** yy () const { return yy_;  }
-    double*** zz () const { return zz_;  }
-    double*** xy () const { return xy_;  }
-    double*** xz () const { return xz_;  }
-    double*** yz () const { return yz_;  }
-    double*** xxx() const { return xxx_; }
-    double*** yyy() const { return yyy_; }
-    double*** zzz() const { return zzz_; }
-    double*** xxy() const { return xxy_; }
-    double*** xxz() const { return xxz_; }
-    double*** xyy() const { return xyy_; }
-    double*** yyz() const { return yyz_; }
-    double*** xzz() const { return xzz_; }
-    double*** yzz() const { return yzz_; }
-    double*** xyz() const { return xyz_; }
+    double ***q() const { return q_; }
+    double ***x() const { return x_; }
+    double ***y() const { return y_; }
+    double ***z() const { return z_; }
+    double ***xx() const { return xx_; }
+    double ***yy() const { return yy_; }
+    double ***zz() const { return zz_; }
+    double ***xy() const { return xy_; }
+    double ***xz() const { return xz_; }
+    double ***yz() const { return yz_; }
+    double ***xxx() const { return xxx_; }
+    double ***yyy() const { return yyy_; }
+    double ***zzz() const { return zzz_; }
+    double ***xxy() const { return xxy_; }
+    double ***xxz() const { return xxz_; }
+    double ***xyy() const { return xyy_; }
+    double ***yyz() const { return yyz_; }
+    double ***xzz() const { return xzz_; }
+    double ***yzz() const { return yzz_; }
+    double ***xyz() const { return xyz_; }
 
     /// Computes the potential integral 3D matrix using the data provided.
     virtual void compute(double PA[3], double PB[3], double PC[3], double zeta, int am1, int am2);
-
 };
 
-
 /*! \ingroup MINTS
     \class ObaraSaikaThreeCenterRecursion
  */
-class ObaraSaikaThreeCenterRecursion
-{
+class ObaraSaikaThreeCenterRecursion {
     int max_am1_;
     int max_am2_;
     int max_am3_;
@@ -360,9 +350,9 @@ class ObaraSaikaThreeCenterRecursion
     ObaraSaikaThreeCenterRecursion();
 
     // No assignment operator
-    ObaraSaikaThreeCenterRecursion& operator=(const ObaraSaikaThreeCenterRecursion&);
+    ObaraSaikaThreeCenterRecursion &operator=(const ObaraSaikaThreeCenterRecursion &);
 
-public:
+   public:
     ObaraSaikaThreeCenterRecursion(int max_am1, int max_am2, int max_am3);
     ~ObaraSaikaThreeCenterRecursion();
 
@@ -374,13 +364,9 @@ public:
     double ***z() const { return z_; }
 
     /// Computes the recursion matrices for the data provided.
-    void compute(double GA[3],
-                 double GB[3],
-                 double GC[3],
-                 double gammac,
-                 int amA, int amB, int amC);
+    void compute(double GA[3], double GB[3], double GC[3], double gammac, int amA, int amB, int amC);
 };
 
-}
+}  // namespace psi
 
 #endif
