@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -30,41 +30,40 @@
 #define _psi_src_lib_libmints_overlap_h_
 
 #include <vector>
-#include "psi4/libmints/onebody.h" // needed because we derive from OneBodyAOInt
+#include "psi4/libmints/onebody.h"  // needed because we derive from OneBodyAOInt
 #include "psi4/libmints/osrecur.h"
 
 namespace psi {
 
-    class BasisSet;
-    class GaussianShell;
-    class SphericalTransform;
+class BasisSet;
+class GaussianShell;
+class SphericalTransform;
 
 /*! \ingroup MINTS
  *  \class OverlapInt
  *  \brief This class computes overlap integrals and soon overlap integral derivatives.
  *  Use an IntegralFactory to create this object.
  */
-class OverlapInt : public OneBodyAOInt
-{
+class OverlapInt : public OneBodyAOInt {
     /// Generic Obara Saika recursion object.
     ObaraSaikaTwoCenterRecursion overlap_recur_;
 
     /// Computes the overlap between a given shell pair.
-    void compute_pair(const GaussianShell& , const GaussianShell&);
-    void compute_pair_deriv1(const GaussianShell& s1, const GaussianShell& s2);
-    void compute_pair_deriv2(const GaussianShell&, const GaussianShell&);
+    void compute_pair(const GaussianShell&, const GaussianShell&) override;
+    void compute_pair_deriv1(const GaussianShell& s1, const GaussianShell& s2) override;
+    void compute_pair_deriv2(const GaussianShell&, const GaussianShell&) override;
 
-public:
+   public:
     /// Constructor, it assumes you are not computing derivatives by default
-    OverlapInt(std::vector<SphericalTransform>&, std::shared_ptr<BasisSet>, std::shared_ptr<BasisSet>, int deriv=0);
-    virtual ~OverlapInt();
+    OverlapInt(std::vector<SphericalTransform>&, std::shared_ptr<BasisSet>, std::shared_ptr<BasisSet>, int deriv = 0);
+    ~OverlapInt() override;
 
     /// Does the method provide first derivatives?
-    bool has_deriv1() { return true; }
+    bool has_deriv1() override { return true; }
     /// Does the method provide second derivatives?
-    bool has_deriv2() { return true; }
+    bool has_deriv2() override { return true; }
 };
 
-}
+}  // namespace psi
 
 #endif
