@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -34,33 +34,27 @@
 
 #include <map>
 #include <cstdio>
-#include <stdint.h>
+#include <cstdint>
 
- #include "psi4/pragma.h"
- PRAGMA_WARNING_PUSH
- PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
- #include <memory>
- PRAGMA_WARNING_POP
+#include "psi4/pragma.h"
+PRAGMA_WARNING_PUSH
+PRAGMA_WARNING_IGNORE_DEPRECATED_DECLARATIONS
+#include <memory>
+PRAGMA_WARNING_POP
 
 namespace psi {
 
-
-
 class BasisSet;
 class Molecule;
 class IntegralFactory;
 class Matrix;
 class Dimension;
 
-inline int64_t ij_offset64(int64_t i, int64_t j)
-{
-    return (i>j) ? (((i*(i+1)) >> 1) + j) : (((j*(j+1)) >> 1) + i);
+inline int64_t ij_offset64(int64_t i, int64_t j) {
+    return (i > j) ? (((i * (i + 1)) >> 1) + j) : (((j * (j + 1)) >> 1) + i);
 }
 
-inline int64_t i_offset64(int64_t i)
-{
-    return ((i*(i+1)) >> 1);
-}
+inline int64_t i_offset64(int64_t i) { return ((i * (i + 1)) >> 1); }
 
 /////////////////////////////////////////////////////////////////////////////
 // These are helper functions for PetiteList and GenericPetiteList4
@@ -73,7 +67,7 @@ inline int64_t i_offset64(int64_t i)
  *  \returns Integer matrix of dimension natoms X nirreps.
  */
 int **compute_atom_map(const std::shared_ptr<Molecule> &mol, double tol = 0.1, bool suppress_mol_print_in_exc = false);
-int **compute_atom_map(const Molecule* mol, double tol = 0.1, bool suppress_mol_print_in_exc = false);
+int **compute_atom_map(const Molecule *mol, double tol = 0.1, bool suppress_mol_print_in_exc = false);
 /// @}
 
 /*! @{
@@ -83,7 +77,7 @@ int **compute_atom_map(const Molecule* mol, double tol = 0.1, bool suppress_mol_
  *  \param mol Molecule used to create atom_map.
  */
 void delete_atom_map(int **atom_map, const std::shared_ptr<Molecule> &mol);
-void delete_atom_map(int **atom_map, const Molecule* mol);
+void delete_atom_map(int **atom_map, const Molecule *mol);
 /// @}
 
 int **compute_shell_map(int **atom_map, const std::shared_ptr<BasisSet> &);
@@ -109,13 +103,13 @@ struct SO {
     SO(int);
     ~SO();
 
-    SO& operator=(const SO&);
+    SO &operator=(const SO &);
 
     void set_length(int);
     void reset_length(int);
 
     // is this equal to so to within a sign
-    int equiv(const SO& so);
+    int equiv(const SO &so);
 };
 
 struct SO_block {
@@ -129,21 +123,21 @@ struct SO_block {
     void set_length(int);
     void reset_length(int);
 
-    int add(SO& s, int i);
+    int add(SO &s, int i);
     void print(const char *title);
 };
 
-struct SOCoefficients{
+struct SOCoefficients {
     std::map<int, double> coefficients;
     int irrep;
     //        Contribution(std::map<int, double> coefficients_, int irrep_):
     //            coefficients(coefficients_), irrep(irrep_){}
-    SOCoefficients(): irrep(-1){}
+    SOCoefficients() : irrep(-1) {}
     void add_contribution(int bf, double coeff, int symm);
 
     void print() const;
 
-    size_t size() const {return(coefficients.size());}
+    size_t size() const { return (coefficients.size()); }
 
     void scale_coefficients(double factor);
 
@@ -151,8 +145,7 @@ struct SOCoefficients{
 };
 /////////////////////////////////////////////////////////////////////////////
 
-class PetiteList
-{
+class PSI_API PetiteList {
     int natom_;
     int nshell_;
     int nunique_shell_;
@@ -162,7 +155,7 @@ class PetiteList
     bool c1_;
 
     std::shared_ptr<BasisSet> basis_;
-    const IntegralFactory* integral_;
+    const IntegralFactory *integral_;
 
     bool include_pure_transform_;
 
@@ -177,19 +170,20 @@ class PetiteList
     unsigned short *stablizer_;
     int max_stablizer_;
 
-    void init(double tol=0.05);
+    void init(double tol = 0.05);
 
-public:
-    PetiteList(const std::shared_ptr<BasisSet>&, const std::shared_ptr<IntegralFactory>&, bool include_pure_transform = false);
-    PetiteList(const std::shared_ptr<BasisSet>&, const IntegralFactory*, bool include_pure_transform = false);
+   public:
+    PetiteList(const std::shared_ptr<BasisSet> &, const std::shared_ptr<IntegralFactory> &,
+               bool include_pure_transform = false);
+    PetiteList(const std::shared_ptr<BasisSet> &, const IntegralFactory *, bool include_pure_transform = false);
     ~PetiteList();
 
-    bool include_pure_transform() const {return include_pure_transform_;}
+    bool include_pure_transform() const { return include_pure_transform_; }
 
     /// The AO basis set used to create this petite list
     std::shared_ptr<BasisSet> basis() { return basis_; }
     /// The integral factory used to create this petite list
-    const IntegralFactory* integral() { return integral_; }
+    const IntegralFactory *integral() { return integral_; }
     /// Create a clone of this petite list
     std::shared_ptr<PetiteList> clone();
 
@@ -226,14 +220,14 @@ public:
      */
     int nblocks() const { return nblocks_; }
 
-    void print(std::string out="outfile");
+    void print(std::string out = "outfile");
 
     /** The symmetry operations that keep the atom unchanged in bit representation.
      *  \param atom The atom of interest.
      */
     unsigned short stablizer(int atom) const { return (c1_) ? group_ : stablizer_[atom]; }
 
-    int max_stablizer() const { return (c1_) ? 1 : max_stablizer_;}
+    int max_stablizer() const { return (c1_) ? 1 : max_stablizer_; }
 
     /** The bit representation of the symmetry operation in the point group.
      */
@@ -242,16 +236,16 @@ public:
     /** Returns the bit representation of the double coset representation.
      */
     unsigned short dcr(unsigned short subgroup1, unsigned short subgroup2) const {
-        std::map<unsigned short,bool> uniqueCosets;
-        for(int g = 0; g < 8; ++g){
+        std::map<unsigned short, bool> uniqueCosets;
+        for (int g = 0; g < 8; ++g) {
             int coset = 0;
-            if(SKIP_THIS_OPERATOR(group_, g)) continue;
-            for(int mu = 0; mu < 8; ++mu){
-                if(SKIP_THIS_OPERATOR(subgroup1, mu)) continue;
-                for(int nu = 0; nu < 8; ++nu){
-                    if(SKIP_THIS_OPERATOR(subgroup2, nu)) continue;
-                    coset |= NUM_TO_OPERATOR_ID(mu^g^nu);
-                    if(!NUM_TO_OPERATOR_ID(mu^g^nu)) coset |= SymmOps::ID;
+            if (SKIP_THIS_OPERATOR(group_, g)) continue;
+            for (int mu = 0; mu < 8; ++mu) {
+                if (SKIP_THIS_OPERATOR(subgroup1, mu)) continue;
+                for (int nu = 0; nu < 8; ++nu) {
+                    if (SKIP_THIS_OPERATOR(subgroup2, nu)) continue;
+                    coset |= NUM_TO_OPERATOR_ID(mu ^ g ^ nu);
+                    if (!NUM_TO_OPERATOR_ID(mu ^ g ^ nu)) coset |= SymmOps::ID;
                 }
             }
             uniqueCosets[coset] = 1;
@@ -259,10 +253,10 @@ public:
         std::map<unsigned short, bool>::const_iterator iter = uniqueCosets.begin();
         std::map<unsigned short, bool>::const_iterator stop = uniqueCosets.end();
         int rOperators = 0;
-        for(; iter != stop; ++iter){
+        for (; iter != stop; ++iter) {
             int coset = iter->first;
-            for(int op = 1; op < 9; ++op){
-                if(SKIP_THIS_OPERATOR(coset, op)) continue;
+            for (int op = 1; op < 9; ++op) {
+                if (SKIP_THIS_OPERATOR(coset, op)) continue;
                 rOperators |= (coset & SymmOps::ID ? SymmOps::E : NUM_TO_OPERATOR_ID(op));
                 break;
             }
@@ -275,25 +269,22 @@ public:
      */
     int dcr_degeneracy(unsigned short group) const {
         int degeneracy = 0;
-        for(int op = 0; op < 8; ++op){
-            if(SKIP_THIS_OPERATOR(group, op)) continue;
+        for (int op = 0; op < 8; ++op) {
+            if (SKIP_THIS_OPERATOR(group, op)) continue;
             ++degeneracy;
         }
         return degeneracy;
     }
-    unsigned short GnG(unsigned short group1, unsigned short group2) const {
-         return group1 & group2;
-    }
+    unsigned short GnG(unsigned short group1, unsigned short group2) const { return group1 & group2; }
 
     std::vector<int> bits_to_operator_list(unsigned short list) {
         std::vector<int> positions;
         int position = 1;
         unsigned short g = group_;
         positions.push_back(0);
-        for (int n=1; n<9; n++) {
+        for (int n = 1; n < 9; n++) {
             if (g & 1) {
-                if (g & (list & 1))
-                    positions.push_back(position);
+                if (g & (list & 1)) positions.push_back(position);
                 position += 1;
             }
 
@@ -312,9 +303,9 @@ public:
 
     /// Return the basis function rotation matrix R(g)
     /// @param g index of the group operation
-    Matrix* r(int g);
+    Matrix *r(int g);
 
-    SO_block* compute_aotoso_info();
+    SO_block *compute_aotoso_info();
 
     /** @return the AO->SO coefficient matrix. The columns correspond to SOs (see SO_basisdim() )
         and rows to AOs (see AO_basisdim() ).
@@ -346,6 +337,6 @@ public:
     SharedMatrix evecs_to_AO_basis(SharedMatrix soevecs);
 };
 
-}
+}  // namespace psi
 
-#endif // _psi_src_lib_libmints_petitelist_h_
+#endif  // _psi_src_lib_libmints_petitelist_h_
