@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -85,13 +85,12 @@
 
 #include <cstdlib>
 #include <cstring>
-#include <ctype.h>
+#include <cctype>
 #include <cmath>
 
 namespace psi {
 namespace PointGroups {
-void similar(unsigned char bits, unsigned char *sim, char &cnt)
-{
+void similar(unsigned char bits, unsigned char *sim, char &cnt) {
     static unsigned char cs[3] = {CsX, CsY, CsZ};
     static unsigned char c2v[3] = {C2vZ, C2vY, C2vX};
     static unsigned char c2h[3] = {C2hZ, C2hY, C2hX};
@@ -146,72 +145,50 @@ void similar(unsigned char bits, unsigned char *sim, char &cnt)
             throw PSIEXCEPTION("Should not have reaced here.");
     }
 }
-}
+}  // namespace PointGroups
 
 ////////////////////////////////////////////////////////////////////////
 
-PointGroup::PointGroup()
-{
+PointGroup::PointGroup() {
     set_symbol("c1");
     origin_[0] = origin_[1] = origin_[2] = 0;
 }
 
-PointGroup::PointGroup(const std::string &s)
-{
-    if (full_name_to_bits(s, bits_) == false)
-        throw PSIEXCEPTION("PointGroup: Unknown point group name provided.");
+PointGroup::PointGroup(const std::string &s) {
+    if (full_name_to_bits(s, bits_) == false) throw PSIEXCEPTION("PointGroup: Unknown point group name provided.");
     set_symbol(bits_to_basic_name(bits_));
     origin_[0] = origin_[1] = origin_[2] = 0;
 }
 
-PointGroup::PointGroup(const std::string &s,
-                       const Vector3 &origin)
-{
-    if (full_name_to_bits(s, bits_) == false)
-        throw PSIEXCEPTION("PointGroup: Unknown point group name provided.");
+PointGroup::PointGroup(const std::string &s, const Vector3 &origin) {
+    if (full_name_to_bits(s, bits_) == false) throw PSIEXCEPTION("PointGroup: Unknown point group name provided.");
     set_symbol(bits_to_basic_name(bits_));
     origin_ = origin;
 }
 
-PointGroup::PointGroup(unsigned char bits)
-        : bits_(bits)
-{
+PointGroup::PointGroup(unsigned char bits) : bits_(bits) {
     set_symbol(bits_to_basic_name(bits));
     origin_[0] = origin_[1] = origin_[2] = 0;
 }
 
-PointGroup::PointGroup(unsigned char bits, const Vector3 &origin)
-        : bits_(bits)
-{
+PointGroup::PointGroup(unsigned char bits, const Vector3 &origin) : bits_(bits) {
     set_symbol(bits_to_basic_name(bits));
     origin_ = origin;
 }
 
-PointGroup::PointGroup(const PointGroup &pg)
-{
-    *this = pg;
-}
+PointGroup::PointGroup(const PointGroup &pg) { *this = pg; }
 
-PointGroup::PointGroup(const std::shared_ptr<PointGroup> &pg)
-{
-    *this = *pg.get();
-}
+PointGroup::PointGroup(const std::shared_ptr<PointGroup> &pg) { *this = *pg.get(); }
 
-PointGroup::~PointGroup()
-{
-}
+PointGroup::~PointGroup() {}
 
-PointGroup &
-PointGroup::operator=(const PointGroup &pg)
-{
+PointGroup &PointGroup::operator=(const PointGroup &pg) {
     set_symbol(pg.symb);
     origin_ = pg.origin_;
     return *this;
 }
 
-void
-PointGroup::set_symbol(const std::string &sym)
-{
+void PointGroup::set_symbol(const std::string &sym) {
     if (sym.length()) {
         symb = sym;
     } else {
@@ -219,24 +196,18 @@ PointGroup::set_symbol(const std::string &sym)
     }
 }
 
-CharacterTable
-PointGroup::char_table() const
-{
+CharacterTable PointGroup::char_table() const {
     CharacterTable ret(bits_);
     return ret;
 }
 
-int
-PointGroup::equiv(const std::shared_ptr<PointGroup> &grp, double /*tol*/) const
-{
-    if (symb != grp->symb)
-        return 0;
+int PointGroup::equiv(const std::shared_ptr<PointGroup> &grp, double /*tol*/) const {
+    if (symb != grp->symb) return 0;
 
     return 1;
 }
 
-bool PointGroup::full_name_to_bits(const std::string &pg, unsigned char &bits)
-{
+bool PointGroup::full_name_to_bits(const std::string &pg, unsigned char &bits) {
     bool retvalue = true;
 
     if (iequals(pg, std::string("C1")))
@@ -257,22 +228,28 @@ bool PointGroup::full_name_to_bits(const std::string &pg, unsigned char &bits)
         bits = PointGroups::CsZ;
     else if (iequals(pg, std::string("D2")))
         bits = PointGroups::D2;
-    else if (iequals(pg, std::string("C2v(X)")) || iequals(pg, std::string("C2vx")) || iequals(pg, std::string("C2v_x")))
+    else if (iequals(pg, std::string("C2v(X)")) || iequals(pg, std::string("C2vx")) ||
+             iequals(pg, std::string("C2v_x")))
         bits = PointGroups::C2vX;
-    else if (iequals(pg, std::string("C2v(Y)")) || iequals(pg, std::string("C2vy")) || iequals(pg, std::string("C2v_y")))
+    else if (iequals(pg, std::string("C2v(Y)")) || iequals(pg, std::string("C2vy")) ||
+             iequals(pg, std::string("C2v_y")))
         bits = PointGroups::C2vY;
-    else if (iequals(pg, std::string("C2v(Z)")) || iequals(pg, std::string("C2vz")) || iequals(pg, std::string("C2v_z")))
+    else if (iequals(pg, std::string("C2v(Z)")) || iequals(pg, std::string("C2vz")) ||
+             iequals(pg, std::string("C2v_z")))
         bits = PointGroups::C2vZ;
-    else if (iequals(pg, std::string("C2h(X)")) || iequals(pg, std::string("C2hx")) || iequals(pg, std::string("C2h_x")))
+    else if (iequals(pg, std::string("C2h(X)")) || iequals(pg, std::string("C2hx")) ||
+             iequals(pg, std::string("C2h_x")))
         bits = PointGroups::C2hX;
-    else if (iequals(pg, std::string("C2h(Y)")) || iequals(pg, std::string("C2hy")) || iequals(pg, std::string("C2h_y")))
+    else if (iequals(pg, std::string("C2h(Y)")) || iequals(pg, std::string("C2hy")) ||
+             iequals(pg, std::string("C2h_y")))
         bits = PointGroups::C2hY;
-    else if (iequals(pg, std::string("C2h(Z)")) || iequals(pg, std::string("C2hz")) || iequals(pg, std::string("C2h_z")))
+    else if (iequals(pg, std::string("C2h(Z)")) || iequals(pg, std::string("C2hz")) ||
+             iequals(pg, std::string("C2h_z")))
         bits = PointGroups::C2hZ;
     else if (iequals(pg, std::string("D2h")))
         bits = PointGroups::D2h;
 
-        // Ok, the user gave us Cs, C2v, C2h, C2, but no directionality
+    // Ok, the user gave us Cs, C2v, C2h, C2, but no directionality
     else if (iequals(pg, std::string("Cs")))
         bits = PointGroups::CsX;
     else if (iequals(pg, std::string("C2v")))
@@ -288,8 +265,7 @@ bool PointGroup::full_name_to_bits(const std::string &pg, unsigned char &bits)
     return retvalue;
 }
 
-const char *PointGroup::bits_to_full_name(unsigned char bits)
-{
+const char *PointGroup::bits_to_full_name(unsigned char bits) {
     switch (bits) {
         case PointGroups::C1:
             return "C1";
@@ -329,8 +305,7 @@ const char *PointGroup::bits_to_full_name(unsigned char bits)
     }
 }
 
-const char *PointGroup::bits_to_basic_name(unsigned char bits)
-{
+const char *PointGroup::bits_to_basic_name(unsigned char bits) {
     switch (bits) {
         case PointGroups::C1:
             return "c1";
@@ -362,11 +337,8 @@ const char *PointGroup::bits_to_basic_name(unsigned char bits)
     }
 }
 
-void
-PointGroup::print(std::string out) const
-{
-    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile :
-                                                   std::make_shared<PsiOutStream>(out));
+void PointGroup::print(std::string out) const {
+    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
     printer->Printf("PointGroup: %s\n", symb.c_str());
 }
 
@@ -383,7 +355,7 @@ std::string PointGroup::irrep_bits_to_string(int irrep_bits) const {
     }
     return irrep_str;
 }
-}
+}  // namespace psi
 
 /////////////////////////////////////////////////////////////////////////////
 
