@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,17 +26,19 @@
  * @END LICENSE
  */
 
-#include "psi4/libqt/qt.h"
-#include "matrix.h"
 #include "vector.h"
-#include "dimension.h"
-#include "psi4/libpsi4util/PsiOutStream.h"
 
 #include <algorithm>
 #include <numeric>
 #include <cstdlib>
-#include <string.h>
-#include <math.h>
+#include <cstring>
+#include <cmath>
+
+#include "psi4/libqt/qt.h"
+#include "psi4/libpsi4util/PsiOutStream.h"
+
+#include "dimension.h"
+#include "matrix.h"
 
 namespace psi {
 
@@ -97,10 +99,6 @@ Vector::Vector(const std::string &name, const Dimension &v) {
 
 Vector::~Vector() { release(); }
 
-SharedVector Vector::create(const std::string &name, const Dimension &dim) {
-    return std::make_shared<Vector>(name, dim);
-}
-
 void Vector::init(int nirreps, int *dimpi) {
     dimpi_.init(nirreps);
     nirrep_ = nirreps;
@@ -170,8 +168,6 @@ void Vector::copy(const Vector *rhs) { copy_from(*rhs); }
 
 void Vector::copy(const Vector &rhs) { copy_from(rhs); }
 
-void Vector::set(double *vec) { std::copy(vec, vec + dimpi_.sum(), v_.begin()); }
-
 SharedVector Vector::get_block(const Slice &slice) {
     // check if slice is within bounds
     for (int h = 0; h < nirrep_; h++) {
@@ -217,47 +213,30 @@ void Vector::set_block(const Slice &slice, SharedVector block) {
 void Vector::zero() { std::fill(v_.begin(), v_.end(), 0.0); }
 
 void Vector::print(std::string out, const char *extra) const {
-    std::shared_ptr<psi::PsiOutStream> printer =
-        (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
-    int h;
+    std::shared_ptr<psi::PsiOutStream> printer = (out == "outfile" ? outfile : std::make_shared<PsiOutStream>(out));
     if (extra == nullptr) {
         printer->Printf("\n # %s #\n", name_.c_str());
     } else {
         printer->Printf("\n # %s %s #\n", name_.c_str(), extra);
     }
-    for (h = 0; h < nirrep_; ++h) {
+    for (int h = 0; h < nirrep_; ++h) {
         printer->Printf(" Irrep: %d\n", h + 1);
         for (int i = 0; i < dimpi_[h]; ++i) printer->Printf("   %4d: %10.7f\n", i + 1, vector_[h][i]);
         printer->Printf("\n");
     }
 }
 
-double *Vector::to_block_vector() {
-    size_t size = 0;
-    for (int h = 0; h < nirrep_; ++h) size += dimpi_[h];
-
-    double *temp = new double[size];
-    size_t offset = 0;
-    for (int h = 0; h < nirrep_; ++h) {
-        for (int i = 0; i < dimpi_[h]; ++i) {
-            temp[i + offset] = vector_[h][i];
-        }
-        offset += dimpi_[h];
-    }
-
-    return temp;
-}
-
 void Vector::gemv(bool transa, double alpha, Matrix *A, Vector *X, double beta) {
     char trans = transa ? 't' : 'n';
 
     for (int h = 0; h < nirrep_; ++h) {
-        C_DGEMV(trans, A->rowspi_[h], A->colspi_[h], alpha, &(A->matrix_[h][0][0]), A->rowspi_[h], &(X->vector_[h][0]),
+        C_DGEMV(trans, A->rowspi(h), A->colspi(h), alpha, A->get_pointer(h), A->rowspi(h), &(X->vector_[h][0]),
                 1, beta, &(vector_[h][0]), 1);
     }
 }
 
 double Vector::vector_dot(const SharedVector &other) { return vector_dot(*other.get()); }
+
 double Vector::vector_dot(const Vector &other) {
     if (v_.size() != other.v_.size()) {
         throw PSIEXCEPTION("Vector::vector_dot: Vector sizes do not match!");
@@ -265,6 +244,7 @@ double Vector::vector_dot(const Vector &other) {
 
     return C_DDOT(v_.size(), v_.data(), 1, const_cast<double *>(other.v_.data()), 1);
 }
+
 double Vector::dot(Vector *X) {
     if (v_.size() != X->v_.size()) {
         throw PSIEXCEPTION("Vector::vector_dot: Vector sizes do not match!");
@@ -274,18 +254,23 @@ double Vector::dot(Vector *X) {
 }
 
 double Vector::sum_of_squares() { return C_DDOT(v_.size(), v_.data(), 1, v_.data(), 1); }
+
 double Vector::norm() { return sqrt(sum_of_squares()); }
+
 double Vector::rms() { return sqrt(sum_of_squares() / v_.size()); }
 
-void Vector::scale(const double &sc) { C_DSCAL(v_.size(), sc, v_.data(), 1); }
+void Vector::scale(double sc) { C_DSCAL(v_.size(), sc, v_.data(), 1); }
 
 void Vector::add(const SharedVector &other) { axpy(1.0, *other.get()); }
+
 void Vector::add(const Vector &other) { axpy(1.0, other); }
 
 void Vector::subtract(const SharedVector &other) { axpy(-1.0, *other.get()); }
+
 void Vector::subtract(const Vector &other) { axpy(-1.0, other); }
 
 void Vector::axpy(double scale, const SharedVector &other) { axpy(scale, *other.get()); }
+
 void Vector::axpy(double scale, const Vector &other) {
     if (v_.size() != other.v_.size()) {
         throw PSIEXCEPTION("Vector::axpy: Vector sizes do not match!");
@@ -293,5 +278,4 @@ void Vector::axpy(double scale, const Vector &other) {
 
     C_DAXPY(v_.size(), scale, const_cast<double *>(other.v_.data()), 1, v_.data(), 1);
 }
-
 }  // namespace psi
