@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,46 +36,33 @@
 
 namespace psi {
 
-
-
-ModelSpace::ModelSpace(MOInfo* moinfo_obj_) : moinfo_obj(moinfo_obj_)
-{
-  startup();
-  build();
-  classify();
-//  print();
+ModelSpace::ModelSpace(MOInfo* moinfo_obj_) : moinfo_obj(moinfo_obj_) {
+    startup();
+    build();
+    classify();
+    //  print();
 }
 
-ModelSpace::~ModelSpace()
-{
-  cleanup();
+ModelSpace::~ModelSpace() { cleanup(); }
+
+void ModelSpace::startup() { wfn_sym = moinfo_obj->get_wfn_sym(); }
+
+void ModelSpace::cleanup() {}
+
+void ModelSpace::print() {
+    outfile->Printf("\n\n  Model space:");
+    outfile->Printf("\n  ------------------------------------------------------------------------------");
+    for (size_t mu = 0; mu < determinants.size(); ++mu) {
+        outfile->Printf("\n  %2d %s", mu, determinants[mu].get_label().c_str());
+    }
+    outfile->Printf("\n\n  Closed-shell to model space mapping");
+    for (size_t mu = 0; mu < closed_to_all.size(); ++mu) {
+        outfile->Printf("\n  %d -> %d", mu, closed_to_all[mu]);
+    }
+    outfile->Printf("\n\n  Open-shell to model space mapping");
+    for (size_t mu = 0; mu < opensh_to_all.size(); ++mu) {
+        outfile->Printf("\n  %d -> %d", mu, opensh_to_all[mu]);
+    }
 }
 
-void ModelSpace::startup()
-{
-  wfn_sym = moinfo_obj->get_wfn_sym();
-}
-
-void ModelSpace::cleanup()
-{
-}
-
-void ModelSpace::print()
-{
-  outfile->Printf("\n\n  Model space:");
-  outfile->Printf("\n  ------------------------------------------------------------------------------");
-  for(size_t mu = 0; mu < determinants.size(); ++mu){
-    outfile->Printf("\n  %2d %s",mu,determinants[mu].get_label().c_str());
-  }
-  outfile->Printf("\n\n  Closed-shell to model space mapping");
-  for(size_t mu = 0; mu < closed_to_all.size(); ++mu){
-    outfile->Printf("\n  %d -> %d",mu,closed_to_all[mu]);
-  }
-  outfile->Printf("\n\n  Open-shell to model space mapping");
-  for(size_t mu = 0; mu < opensh_to_all.size(); ++mu){
-    outfile->Printf("\n  %d -> %d",mu,opensh_to_all[mu]);
-  }
-
-}
-
-}
+}  // namespace psi
