@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -26,8 +26,6 @@
  * @END LICENSE
  */
 
-
-
 #include "plugin.h"
 
 namespace psi {
@@ -36,17 +34,11 @@ namespace psi {
 
 #include <dlfcn.h>
 
-void plugin_close(const plugin_info& info)
-{
-    dlclose(info.plugin_handle);
-}
+void plugin_close(const plugin_info& info) { dlclose(info.plugin_handle); }
 
 #else
 
-void plugin_close(const plugin_info& info)
-{
-}
+void plugin_close(const plugin_info& info) {}
 
 #endif
-
 }
