@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -36,13 +36,12 @@
 
 namespace psi {
 
-psio_tocentry*PSIO::toclast(size_t unit) {
-  psio_tocentry *this_entry = psio_unit[unit].toc;
+psio_tocentry *PSIO::toclast(size_t unit) {
+    psio_tocentry *this_entry = psio_unit[unit].toc;
 
-  while (this_entry->next != nullptr)
-    this_entry = this_entry->next;
+    while (this_entry->next != nullptr) this_entry = this_entry->next;
 
-  return (this_entry);
+    return (this_entry);
 }
 
-}
+}  // namespace psi
