@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -33,36 +33,36 @@
 */
 
 namespace psi {
-	
+
 /*!
- 
+
    dirprd_block()
- 
+
    This function takes two block matrices A and B and multiplies
    each element of B by the corresponding element of A
- 
+
    \param A     = block matrix A
-   \param B     = block matrix B 
+   \param B     = block matrix B
    \param nrows = number of rows of A and B
    \param ncols = number of columns of A and B
- 
+
    Returns: none
 
    \ingroup QT
 */
-void dirprd_block(double **A, double **B, int rows, int cols)
-{
-  long int i;
-  double *a, *b;
-  long size;
+void dirprd_block(double **A, double **B, int rows, int cols) {
+    long int i;
+    double *a, *b;
+    long size;
 
-  size = ((long) rows) * ((long) cols);
+    size = ((long)rows) * ((long)cols);
 
-  if(!size) return;
+    if (!size) return;
 
-  a = A[0]; b= B[0];
+    a = A[0];
+    b = B[0];
 
-  for(i=0; i < size; i++, a++, b++) (*b) = (*a) * (*b);
+    for (i = 0; i < size; i++, a++, b++) (*b) = (*a) * (*b);
 }
 
-}
+}  // namespace psi
