@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -38,10 +38,7 @@
 #include "psi4/libmints/wavefunction.h"
 #include "psi4/libpsi4util/PsiOutStream.h"
 #include "psi4/libpsi4util/process.h"
-#define EXTERN
-#include "psi4/libdpd/dpd.gbl"
 
-;
 using namespace psi;
 
 IntegralTransform::IntegralTransform(std::shared_ptr<Wavefunction> wfn, SpaceVec spaces,
@@ -63,7 +60,7 @@ IntegralTransform::IntegralTransform(std::shared_ptr<Wavefunction> wfn, SpaceVec
       nTriMo_(0),
       nfzc_(0),
       nfzv_(0),
-      spaces_(0),
+      spaces_(nullptr),
       labels_(0),
       tolerance_(1.0E-16),
       moIntFileAA_(0),
@@ -71,13 +68,13 @@ IntegralTransform::IntegralTransform(std::shared_ptr<Wavefunction> wfn, SpaceVec
       moIntFileBB_(0),
       myDPDNum_(1),
       print_(1),
-      zeros_(0),
-      sosym_(0),
-      mosym_(0),
-      aQT_(0),
-      bQT_(0),
-      cacheFiles_(0),
-      cacheList_(0),
+      zeros_(nullptr),
+      sosym_(nullptr),
+      mosym_(nullptr),
+      aQT_(nullptr),
+      bQT_(nullptr),
+      cacheFiles_(nullptr),
+      cacheList_(nullptr),
       Ca_(wfn->Ca()),
       Cb_(wfn->Cb()),
       H_(wfn->H()),
@@ -87,6 +84,7 @@ IntegralTransform::IntegralTransform(std::shared_ptr<Wavefunction> wfn, SpaceVec
       keepDpdMoTpdm_(true),
       keepHtInts_(true),
       keepHtTpdm_(true),
+      buildMOFock_(true),
       tpdmAlreadyPresorted_(false),
       soIntTEIFile_(PSIF_SO_TEI) {
     // Implement set/get functions to customize any of this stuff.  Delayed initialization
@@ -133,7 +131,7 @@ IntegralTransform::IntegralTransform(SharedMatrix H, SharedMatrix c, SharedMatri
       nTriMo_(0),
       nfzc_(0),
       nfzv_(0),
-      spaces_(0),
+      spaces_(nullptr),
       labels_(0),
       tolerance_(1.0E-16),
       memory_(250 * 1024 * 1024),
@@ -142,27 +140,28 @@ IntegralTransform::IntegralTransform(SharedMatrix H, SharedMatrix c, SharedMatri
       moIntFileBB_(0),
       myDPDNum_(1),
       print_(1),
-      zeros_(0),
+      zeros_(nullptr),
       sopi_(0),
-      sosym_(0),
-      mosym_(0),
+      sosym_(nullptr),
+      mosym_(nullptr),
       mopi_(0),
       clsdpi_(0),
       openpi_(0),
       frzcpi_(0),
       frzvpi_(0),
-      aQT_(0),
-      bQT_(0),
-      cacheFiles_(0),
-      cacheList_(0),
-      aCorrToPitzer_(0),
-      bCorrToPitzer_(0),
+      aQT_(nullptr),
+      bQT_(nullptr),
+      cacheFiles_(nullptr),
+      cacheList_(nullptr),
+      aCorrToPitzer_(nullptr),
+      bCorrToPitzer_(nullptr),
       keepIwlSoInts_(false),
       keepIwlMoTpdm_(true),
       keepDpdSoInts_(false),
       keepDpdMoTpdm_(true),
       keepHtInts_(true),
       keepHtTpdm_(true),
+      buildMOFock_(true),
       tpdmAlreadyPresorted_(false),
       soIntTEIFile_(PSIF_SO_TEI) {
     memory_ = Process::environment.get_memory();
@@ -186,7 +185,7 @@ IntegralTransform::IntegralTransform(SharedMatrix H, SharedMatrix c, SharedMatri
     Cs.push_back(i);
     Cs.push_back(a);
     Cs.push_back(v);
-    Ca_ = Matrix::horzcat(Cs);
+    Ca_ = linalg::horzcat(Cs);
     Cb_ = Ca_;
     H_ = H;
 
@@ -207,7 +206,7 @@ void IntegralTransform::initialize() {
     iwlABIntFile_ = transformationType_ == TransformationType::Restricted ? PSIF_MO_TEI : PSIF_MO_AB_TEI;
     iwlBBIntFile_ = transformationType_ == TransformationType::Restricted ? PSIF_MO_TEI : PSIF_MO_BB_TEI;
 
-    tpdm_buffer_ = 0;
+    tpdm_buffer_ = nullptr;
 
     aQT_ = init_int_array(nmo_);
     if (transformationType_ == TransformationType::Restricted) {
