@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -161,6 +161,6 @@ class PSI_API MOSpace {
     bool placeholder_;
 };
 
-}  // End namespaces
+}  // namespace psi
 
 #endif  // Header guard
