@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -46,27 +46,27 @@ class CART : public SIMPLE_COORDINATE {
 
     CART(int A_in, int xyz_in, bool freeze_in=false);
 
-    ~CART() { } // also calls ~SIMPLE_COORDINATE()
+    ~CART() override { } // also calls ~SIMPLE_COORDINATE()
 
-    double value(GeomType geom) const;
+    double value(GeomType geom) const override;
 
     // compute and return array of first derivative (B matrix elements)
     // returned matrix is [atom][x,y,z]
-    double **DqDx(GeomType geom) const;
+    double **DqDx(GeomType geom) const override;
 
-    int g_xyz(void) const { return xyz; }
+    int g_xyz() const override { return xyz; }
 
     // compute and return array of second derivative (B' matrix elements)
     // returned matrix is order 3N cart by 3N cart
-    double **Dq2Dx2(GeomType geom) const;
+    double **Dq2Dx2(GeomType geom) const override;
 
-    void print(std::string psi_fp, FILE *qc_fp, GeomType geom, int atom_offset=0) const;
-    void print_intco_dat(std::string psi_fp, FILE *qc_fp, int atom_offset=0) const;
-    void print_s(std::string psi_fp, FILE *qc_fp, GeomType geom) const;
+    void print(std::string psi_fp, FILE *qc_fp, GeomType geom, int atom_offset=0) const override;
+    void print_intco_dat(std::string psi_fp, FILE *qc_fp, int atom_offset=0) const override;
+    void print_s(std::string psi_fp, FILE *qc_fp, GeomType geom) const override;
     void print_disp(std::string psi_fp, FILE *qc_fp, const double old_q, const double f_q,
-      const double dq, const double new_q, int atom_offset = 0) const;
-    bool operator==(const SIMPLE_COORDINATE & s2) const;
-    std::string get_definition_string(int atom_offset=0) const;
+      const double dq, const double new_q, int atom_offset = 0) const override;
+    bool operator==(const SIMPLE_COORDINATE & s2) const override;
+    std::string get_definition_string(int atom_offset=0) const override;
 
 };
 
