@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -57,7 +57,7 @@ inline double DE_nr_energy(double step, double grad, double hess) {
   return (step * grad + 0.5 * step * step * hess);
 }
 
-void MOLECULE::nr_step(void) {
+void MOLECULE::nr_step() {
   int Nintco = Ncoord();
   double **H_inv;
 
@@ -74,8 +74,8 @@ void MOLECULE::nr_step(void) {
   oprintf_out("\tTaking NR optimization step.\n");
 
   // Hinv fq = dq
-  H_inv = symm_matrix_inv(H, Nintco, 1);
-  opt_matrix_mult(H_inv, 0, &fq, 1, &dq, 1, Nintco, Nintco, 1, 0);
+  H_inv = symm_matrix_inv(H, Nintco, true);
+  opt_matrix_mult(H_inv, false, &fq, true, &dq, true, Nintco, Nintco, 1, false);
   free_matrix(H_inv);
 
   // Zero steps for frozen fragment
