@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -48,7 +48,7 @@
 
 namespace opt {
 
-void print_params_out(void);
+void print_params_out();
 
 #if defined(OPTKING_PACKAGE_PSI)
 void set_params(psi::Options & options)
@@ -904,7 +904,7 @@ void set_params(void)
 
 }
 
-void print_params_out(void) {
+void print_params_out() {
 
   oprintf_out( "dynamic level          = %18d\n", Opt_params.dynamic);
   oprintf_out( "conv_max_force         = %18.2e\n", Opt_params.conv_max_force);
