@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -28,7 +28,8 @@
 
 #include "algebra_interface.h"
 
-namespace psi{ namespace psimrcc{
+namespace psi {
+namespace psimrcc {
 
 /*
 ** C_DGEMM_12()
@@ -39,17 +40,15 @@ namespace psi{ namespace psimrcc{
 ** ncb = number of columns in B
 ** ncc = number of columns in C
 */
-void C_DGEMM_12(int m, int n, int k, double alpha,
-           double *A, int nra, double *B, int ncb, double beta, double *C,
-           int ncc)
-{
-  //  the only strange thing we need to do is reverse everything
-  //  since the stride runs differently in C vs. Fortran
+void C_DGEMM_12(int m, int n, int k, double alpha, double *A, int nra, double *B, int ncb, double beta, double *C,
+                int ncc) {
+    //  the only strange thing we need to do is reverse everything
+    //  since the stride runs differently in C vs. Fortran
 
-  /* also, do nothing if a dimension is 0 */
-  if (m == 0 || n == 0 || k == 0) return;
+    /* also, do nothing if a dimension is 0 */
+    if (m == 0 || n == 0 || k == 0) return;
 
-  F_DGEMM("t","t",&n,&m,&k,&alpha,B,&ncb,A,&nra,&beta,C,&ncc);
+    F_DGEMM("t", "t", &n, &m, &k, &alpha, B, &ncb, A, &nra, &beta, C, &ncc);
 }
 
 /*
@@ -61,18 +60,16 @@ void C_DGEMM_12(int m, int n, int k, double alpha,
 ** ncb = number of columns in B
 ** ncc = number of columns in C
 */
-void C_DGEMM_22(int m, int n, int k, double alpha,
-           double *A, int nca, double *B, int ncb, double beta, double *C,
-           int ncc)
-{
-  //  the only strange thing we need to do is reverse everything
-  //  since the stride runs differently in C vs. Fortran
+void C_DGEMM_22(int m, int n, int k, double alpha, double *A, int nca, double *B, int ncb, double beta, double *C,
+                int ncc) {
+    //  the only strange thing we need to do is reverse everything
+    //  since the stride runs differently in C vs. Fortran
 
-  /* also, do nothing if a dimension is 0 */
-  if (m == 0 || n == 0 || k == 0) return;
+    /* also, do nothing if a dimension is 0 */
+    if (m == 0 || n == 0 || k == 0) return;
 
-  F_DGEMM("t","n",&n,&m,&k,&alpha,B,&ncb,A,&nca,&beta,C,&ncc);
+    F_DGEMM("t", "n", &n, &m, &k, &alpha, B, &ncb, A, &nca, &beta, C, &ncc);
 }
 
-
-}} /* End Namespaces */
+}  // namespace psimrcc
+}  // namespace psi
