@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -34,42 +34,45 @@
  *   SR/MRCC Code
  ***************************************************************************/
 
-
-namespace psi{ namespace psimrcc{
+namespace psi {
+namespace psimrcc {
 
 class CCMatrix;
 
-enum DiskOpt {none,dump,release};
+enum DiskOpt { none, dump, release };
 
 /**
-	@author Francesco A. Evangelista and Andrew C. Simmonett <frank@ccc.uga.edu>
+        @author Francesco A. Evangelista and Andrew C. Simmonett <frank@ccc.uga.edu>
 */
-class CCMatTmp{
-public:
-  CCMatTmp(CCMatrix* Matrix, DiskOpt disk_option = none);
-  CCMatrix* operator->()   const {return(Matrix_);}
-  CCMatrix* get_CCMatrix() const {return(Matrix_);}
-  ~CCMatTmp();
-private:
-  DiskOpt     disk_option_;
-  CCMatrix*   Matrix_;
+class CCMatTmp {
+   public:
+    CCMatTmp(CCMatrix* Matrix, DiskOpt disk_option = none);
+    CCMatrix* operator->() const { return (Matrix_); }
+    CCMatrix* get_CCMatrix() const { return (Matrix_); }
+    ~CCMatTmp();
+
+   private:
+    DiskOpt disk_option_;
+    CCMatrix* Matrix_;
 };
 
 /**
-	@author Francesco A. Evangelista and Andrew C. Simmonett <frank@ccc.uga.edu>
+        @author Francesco A. Evangelista and Andrew C. Simmonett <frank@ccc.uga.edu>
 */
-class CCMatIrTmp{
-public:
-  CCMatIrTmp(CCMatrix* Matrix, int irrep, DiskOpt disk_option = none);
-  CCMatrix* operator->()   const {return(Matrix_);}
-  CCMatrix* get_CCMatrix() const {return(Matrix_);}
-  ~CCMatIrTmp();
-private:
-  DiskOpt     disk_option_;
-  int         irrep_;
-  CCMatrix*   Matrix_;
+class CCMatIrTmp {
+   public:
+    CCMatIrTmp(CCMatrix* Matrix, int irrep, DiskOpt disk_option = none);
+    CCMatrix* operator->() const { return (Matrix_); }
+    CCMatrix* get_CCMatrix() const { return (Matrix_); }
+    ~CCMatIrTmp();
+
+   private:
+    DiskOpt disk_option_;
+    int irrep_;
+    CCMatrix* Matrix_;
 };
 
-}} /* End Namespaces */
+}  // namespace psimrcc
+}  // namespace psi
 
-#endif // _psi_src_bin_psimrcc_ccmatrixtmp_h
+#endif  // _psi_src_bin_psimrcc_ccmatrixtmp_h
