@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -38,28 +38,29 @@
 
 extern FILE* outfile;
 
-namespace psi{ namespace psimrcc{
+namespace psi {
+namespace psimrcc {
 
-void CCMRCC::build_Z_intermediates()
-{
-  // I am rewriting
-  //   blas->append("Z_ijam[oov][o]{u} = #1234#  1/2 tau[oo][vv]{u} 2@2 <[vo]:[vv]>");
-  // as
-  blas->append("Z_ijam[oov][o]{u} = #1234#   tau[oo][vv]{u} 2@2 <[vo]|[vv]>");
-  //
+void CCMRCC::build_Z_intermediates() {
+    // I am rewriting
+    //   blas->append("Z_ijam[oov][o]{u} = #1234#  1/2 tau[oo][vv]{u} 2@2 <[vo]:[vv]>");
+    // as
+    blas->append("Z_ijam[oov][o]{u} = #1234#   tau[oo][vv]{u} 2@2 <[vo]|[vv]>");
+    //
 
-  blas->append("Z_iJaM[oOv][O]{u} = #1234#   tau[oO][vV]{u} 2@2 <[vo]|[vv]>");
+    blas->append("Z_iJaM[oOv][O]{u} = #1234#   tau[oO][vV]{u} 2@2 <[vo]|[vv]>");
 
-  // I am rewriting
-  //   blas->append("Z_iJAm[oOV][o]{u} = #1243# - tau[oO][vV]{u} 2@2 <[ov]|[vv]>");
-  // as
-  blas->append("Z_iJAm[oOV][o]{u} = #1234# - tau[oO][Vv]{u} 2@2 <[vo]|[vv]>");
+    // I am rewriting
+    //   blas->append("Z_iJAm[oOV][o]{u} = #1243# - tau[oO][vV]{u} 2@2 <[ov]|[vv]>");
+    // as
+    blas->append("Z_iJAm[oOV][o]{u} = #1234# - tau[oO][Vv]{u} 2@2 <[vo]|[vv]>");
 
-  // I am rewriting
-  // blas->append("Z_IJAM[OOV][O]{u} = #1234#  1/2 tau[OO][VV]{u} 2@2 <[vo]:[vv]>");
-  // as
-  blas->append("Z_IJAM[OOV][O]{u} = #1234#   tau[OO][VV]{u} 2@2 <[vo]|[vv]>");
-  //
+    // I am rewriting
+    // blas->append("Z_IJAM[OOV][O]{u} = #1234#  1/2 tau[OO][VV]{u} 2@2 <[vo]:[vv]>");
+    // as
+    blas->append("Z_IJAM[OOV][O]{u} = #1234#   tau[OO][VV]{u} 2@2 <[vo]|[vv]>");
+    //
 }
 
-}} /* End Namespaces */
+}  // namespace psimrcc
+}  // namespace psi
