@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -30,25 +30,21 @@
 
 #include "mrccsd_t.h"
 
-namespace psi{ namespace psimrcc{
+namespace psi {
+namespace psimrcc {
 
-MRCCSD_T::MRCCSD_T(Options &options, Hamiltonian* h_eff_) :
-        options_(options),
-        h_eff(h_eff_)
-{
-  startup();
-  check_intruders();
-  if(triples_algorithm == SpinAdaptedTriples)
-    compute_spin_adapted();
-  else if(triples_algorithm == RestrictedTriples)
-    compute_restricted();
-  else
-    compute();
+MRCCSD_T::MRCCSD_T(Options& options, Hamiltonian* h_eff_) : options_(options), h_eff(h_eff_) {
+    startup();
+    check_intruders();
+    if (triples_algorithm == SpinAdaptedTriples)
+        compute_spin_adapted();
+    else if (triples_algorithm == RestrictedTriples)
+        compute_restricted();
+    else
+        compute();
 }
 
-MRCCSD_T::~MRCCSD_T()
-{
-  cleanup();
-}
+MRCCSD_T::~MRCCSD_T() { cleanup(); }
 
-}} /* End Namespaces */
+}  // namespace psimrcc
+}  // namespace psi
