@@ -3,7 +3,7 @@
  *
  * Psi4: an open-source quantum chemistry software package
  *
- * Copyright (c) 2007-2018 The Psi4 Developers.
+ * Copyright (c) 2007-2019 The Psi4 Developers.
  *
  * The copyrights for code used from other parties are included in
  * the corresponding files.
@@ -31,7 +31,7 @@
  *  @file psimrcc.cpp
  *  @ingroup (PSIMRCC)
  *  @brief Contains main() and global variables
-*/
+ */
 
 #include "psi4/liboptions/liboptions.h"
 #include "psi4/libmoinfo/libmoinfo.h"
@@ -100,7 +100,7 @@ void mrpt2(SharedWavefunction ref_wfn, Options& options) {
     // Initialize the mp2 module (integrals,fock matrix(ces),denominators)
     IDMRPT2 idmrpt2(ref_wfn, options);
 
-    Updater* updater = dynamic_cast<Updater*>(new MkUpdater(options));
+    auto* updater = dynamic_cast<Updater*>(new MkUpdater(options));
 
     // Compute the initial amplitudes and MP2 energy
     idmrpt2.compute_mrpt2_energy(updater);
@@ -118,5 +118,5 @@ void transform_integrals() {
     //   CCTransform transf;
     //   transf.read_so_integrals();
 }
-}
-} /* End Namespaces */
+}  // namespace psimrcc
+}  // namespace psi
