@@ -1,5 +1,11 @@
+import pytest
+
 import psi4
 
+pytestmark = pytest.mark.quick
+
+
+@pytest.mark.smoke
 def test_psi4_basic():
     """tu1-h2o-energy"""
     #! Sample HF/cc-pVDZ H2O computation
@@ -13,9 +19,10 @@ def test_psi4_basic():
     psi4.set_options({'basis': "cc-pVDZ"})
     psi4.energy('scf')
 
-    assert psi4.compare_values(-76.0266327341067125, psi4.get_variable('SCF TOTAL ENERGY'), 6, 'SCF energy')
+    assert psi4.compare_values(-76.0266327341067125, psi4.variable('SCF TOTAL ENERGY'), 6, 'SCF energy')
 
 
+@pytest.mark.smoke
 def test_psi4_cc():
     """cc1"""
     #! RHF-CCSD 6-31G** all-electron optimization of the H2O molecule
@@ -37,11 +44,12 @@ def test_psi4_cc():
     reftotal = -76.2311784355056
 
     assert psi4.compare_values(refnuc,   h2o.nuclear_repulsion_energy(), 3, "Nuclear repulsion energy")
-    assert psi4.compare_values(refscf,   psi4.get_variable("SCF total energy"), 5, "SCF energy")
-    assert psi4.compare_values(refccsd,  psi4.get_variable("CCSD correlation energy"), 4, "CCSD contribution")
-    assert psi4.compare_values(reftotal, psi4.get_variable("Current energy"), 7, "Total energy")
+    assert psi4.compare_values(refscf,   psi4.variable("SCF total energy"), 5, "SCF energy")
+    assert psi4.compare_values(refccsd,  psi4.variable("CCSD correlation energy"), 4, "CCSD contribution")
+    assert psi4.compare_values(reftotal, psi4.variable("Current energy"), 7, "Total energy")
 
 
+@pytest.mark.smoke
 def test_psi4_cas():
     """casscf-sp"""
     #! CASSCF/6-31G** energy point
@@ -73,12 +81,13 @@ def test_psi4_cas():
     assert psi4.compare_values(-76.073865006902, casscf_energy, 6, 'CASSCF Energy')
 
 
+@pytest.mark.smoke
 def test_psi4_dfmp2():
     """dfmp2-1"""
     #! Density fitted MP2 cc-PVDZ/cc-pVDZ-RI computation of formic acid dimer binding energy
     #! using automatic counterpoise correction.  Monomers are specified using Cartesian coordinates.
 
-    Enuc = 235.946620315069168
+    Enuc = 235.94662124
     Ecp  = -0.0224119246
 
     formic_dim = psi4.geometry("""
@@ -115,12 +124,13 @@ def test_psi4_dfmp2():
     assert psi4.compare_values(Ecp, e_cp, 5, "CP Corrected cc-pVDZ/cc-pVDZ-RI DFMP2")
 
 
+@pytest.mark.smoke
 def test_psi4_sapt():
     """sapt1"""
     #! SAPT0 cc-pVDZ computation of the ethene-ethyne interaction energy, using the cc-pVDZ-JKFIT RI basis for SCF
     #! and cc-pVDZ-RI for SAPT.  Monomer geometries are specified using Cartesian coordinates.
 
-    Eref = [ 85.189064196429101,  -0.00359915058,  0.00362911158,
+    Eref = [ 85.1890645313,  -0.00359915058,  0.00362911158,
              -0.00083137117,      -0.00150542374, -0.00230683391 ]
 
     ethene_ethyne = psi4.geometry("""
@@ -157,11 +167,11 @@ def test_psi4_sapt():
 
     psi4.energy('sapt0', molecule=ethene_ethyne)
 
-    Eelst = psi4.get_variable("SAPT ELST ENERGY")
-    Eexch = psi4.get_variable("SAPT EXCH ENERGY")
-    Eind  = psi4.get_variable("SAPT IND ENERGY")
-    Edisp = psi4.get_variable("SAPT DISP ENERGY")
-    ET    = psi4.get_variable("SAPT0 TOTAL ENERGY")
+    Eelst = psi4.variable("SAPT ELST ENERGY")
+    Eexch = psi4.variable("SAPT EXCH ENERGY")
+    Eind  = psi4.variable("SAPT IND ENERGY")
+    Edisp = psi4.variable("SAPT DISP ENERGY")
+    ET    = psi4.variable("SAPT0 TOTAL ENERGY")
 
     assert psi4.compare_values(Eref[0], ethene_ethyne.nuclear_repulsion_energy(), 9, "Nuclear Repulsion Energy")
     assert psi4.compare_values(Eref[1], Eelst, 6, "SAPT0 Eelst")
@@ -171,6 +181,7 @@ def test_psi4_sapt():
     assert psi4.compare_values(Eref[5], ET, 6, "SAPT0 Etotal")
 
 
+@pytest.mark.smoke
 def test_psi4_scfproperty():
     """scf-property"""
     #! UFH and B3LYP cc-pVQZ properties for the CH2 molecule.
@@ -201,7 +212,7 @@ def test_psi4_scfproperty():
         "reference": "uhf"})
 
     ch2.update_geometry()
-    assert psi4.compare_values(6.648418918908746, ch2.nuclear_repulsion_energy(), 9, "Nuclear repulsion energy")
+    assert psi4.compare_values(6.6484189450, ch2.nuclear_repulsion_energy(), 9, "Nuclear repulsion energy")
 
     props = ['DIPOLE', 'QUADRUPOLE', 'MULLIKEN_CHARGES', 'LOWDIN_CHARGES',
              'WIBERG_LOWDIN_INDICES', 'MAYER_INDICES', 'MAYER_INDICES',
@@ -210,26 +221,26 @@ def test_psi4_scfproperty():
 
     psi4.properties('scf', properties=props)
 
-    assert psi4.compare_values(psi4.get_variable("CURRENT ENERGY"), -38.91591819679808, 6, "SCF energy")
-    assert psi4.compare_values(psi4.get_variable('SCF DIPOLE X'), 0.000000000000, 4, "SCF DIPOLE X")
-    assert psi4.compare_values(psi4.get_variable('SCF DIPOLE Y'), 0.000000000000, 4, "SCF DIPOLE Y")
-    assert psi4.compare_values(psi4.get_variable('SCF DIPOLE Z'), 0.572697798348, 4, "SCF DIPOLE Z")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE XX'), -7.664066833060, 4, "SCF QUADRUPOLE XX")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE YY'), -6.097755074075, 4, "SCF QUADRUPOLE YY")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE ZZ'), -7.074596012050, 4, "SCF QUADRUPOLE ZZ")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE XY'), 0.000000000000, 4, "SCF QUADRUPOLE XY")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE XZ'), 0.000000000000, 4, "SCF QUADRUPOLE XZ")
-    assert psi4.compare_values(psi4.get_variable('SCF QUADRUPOLE YZ'), 0.000000000000, 4, "SCF QUADRUPOLE YZ")
+    assert psi4.compare_values(psi4.variable("CURRENT ENERGY"), -38.91591819679808, 6, "SCF energy")
+    assert psi4.compare_values(psi4.variable('SCF DIPOLE X'), 0.000000000000, 4, "SCF DIPOLE X")
+    assert psi4.compare_values(psi4.variable('SCF DIPOLE Y'), 0.000000000000, 4, "SCF DIPOLE Y")
+    assert psi4.compare_values(psi4.variable('SCF DIPOLE Z'), 0.572697798348, 4, "SCF DIPOLE Z")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE XX'), -7.664066833060, 4, "SCF QUADRUPOLE XX")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE YY'), -6.097755074075, 4, "SCF QUADRUPOLE YY")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE ZZ'), -7.074596012050, 4, "SCF QUADRUPOLE ZZ")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE XY'), 0.000000000000, 4, "SCF QUADRUPOLE XY")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE XZ'), 0.000000000000, 4, "SCF QUADRUPOLE XZ")
+    assert psi4.compare_values(psi4.variable('SCF QUADRUPOLE YZ'), 0.000000000000, 4, "SCF QUADRUPOLE YZ")
 
     psi4.properties('B3LYP', properties=props)
 
-    assert psi4.compare_values(psi4.get_variable('CURRENT ENERGY'), -39.14134740550916, 6, "B3LYP energy")
-    assert psi4.compare_values(psi4.get_variable('B3LYP DIPOLE X'), 0.000000000000, 4, "B3LYP DIPOLE X")
-    assert psi4.compare_values(psi4.get_variable('B3LYP DIPOLE Y'), -0.000000000000, 4, "B3LYP DIPOLE Y")
-    assert psi4.compare_values(psi4.get_variable('B3LYP DIPOLE Z'), 0.641741521158, 4, "B3LYP DIPOLE Z")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE XX'), -7.616483183211, 4, "B3LYP QUADRUPOLE XX")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE YY'), -6.005896804551, 4, "B3LYP QUADRUPOLE YY")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE ZZ'), -7.021817489904, 4, "B3LYP QUADRUPOLE ZZ")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE XY'), 0.000000000000, 4, "B3LYP QUADRUPOLE XY")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE XZ'), 0.000000000000, 4, "B3LYP QUADRUPOLE XZ")
-    assert psi4.compare_values(psi4.get_variable('B3LYP QUADRUPOLE YZ'), -0.000000000000, 4, "B3LYP QUADRUPOLE YZ")
+    assert psi4.compare_values(psi4.variable('CURRENT ENERGY'), -39.14134740550916, 6, "B3LYP energy")
+    assert psi4.compare_values(psi4.variable('B3LYP DIPOLE X'), 0.000000000000, 4, "B3LYP DIPOLE X")
+    assert psi4.compare_values(psi4.variable('B3LYP DIPOLE Y'), -0.000000000000, 4, "B3LYP DIPOLE Y")
+    assert psi4.compare_values(psi4.variable('B3LYP DIPOLE Z'), 0.641741521158, 4, "B3LYP DIPOLE Z")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE XX'), -7.616483183211, 4, "B3LYP QUADRUPOLE XX")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE YY'), -6.005896804551, 4, "B3LYP QUADRUPOLE YY")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE ZZ'), -7.021817489904, 4, "B3LYP QUADRUPOLE ZZ")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE XY'), 0.000000000000, 4, "B3LYP QUADRUPOLE XY")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE XZ'), 0.000000000000, 4, "B3LYP QUADRUPOLE XZ")
+    assert psi4.compare_values(psi4.variable('B3LYP QUADRUPOLE YZ'), -0.000000000000, 4, "B3LYP QUADRUPOLE YZ")
